/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.databaseAdmin.wizard;

import java.util.List;

import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.wizard.IWizard;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.TabFolder;
import org.eclipse.swt.widgets.TabItem;

import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportConfigurator;
import eu.etaxonomy.cdm.model.metadata.CdmPreference;
import eu.etaxonomy.cdm.model.name.NomenclaturalCode;
import eu.etaxonomy.taxeditor.l10n.Messages;
import eu.etaxonomy.taxeditor.model.NomenclaturalCodeHelper;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.NameDetailsConfigurator;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;

/**
 * @author k.luther
 * @date 01.11.2016
 *
 */
public class DatabasePreferencesPage extends WizardPage implements IWizardPage{

    CdmPreference preferedNomenclaturalCode;
    NameDetailsConfigurator config ;
    CdmPreference isRedListPreference;
    CdmPreference determinationOnlyForFieldUnitsPreference;
    CdmPreference showCollectingAreaInGeneralSectionPreference;
    CdmPreference showTaxonAssociationsPreference;


    TabFolder tabFolder;

    IPreferenceStore preferenceStore;
    Composite composite;
    boolean isSimpleDetailsViewActivated;

    Composite child ;
    NameDetailsViewComposite nameDetailsConfig;
    protected NameDetailsViewComposite getNameDetailsConfig() {
        return nameDetailsConfig;
    }

    String selectedPreferenceKey = null;

    ListComponent biocaseProviderList;
    Abcd206ImportConfigurator abcdImportConfigurator;


//    private UriWithLabelElement nomenclaturalCodeCombo;
//    private Label nomenclaturalCodeLabel;

    String[][] labelAndValues;

    /*
     *
     */
    public DatabasePreferencesPage(String pageName) {
        super(pageName);
        this.preferedNomenclaturalCode = PreferencesUtil.setPreferredNomenclaturalCode(null, false);
        this.config = PreferencesUtil.setPreferredNameDetailsConfiguration( false);
        if (config == null){
            config = new NameDetailsConfigurator(false);
        }
        setPreferenceStore(PreferencesUtil.getPreferenceStore());

    }

    protected void setPreferenceStore(IPreferenceStore store){
        this.preferenceStore = store;
    }




    /***
    * Adds a tab to the page.
    * @param text the tab label
    */
    public Composite addTab(String text)    {
        if (tabFolder == null){
            // initialize tab folder
            if (composite == null) {
                composite = new Composite(getShell(), SWT.NONE);
            }
            tabFolder = new TabFolder(composite, SWT.NONE);
            tabFolder.setLayoutData(new GridData(GridData.FILL_BOTH));
        }

        TabItem item = new TabItem(tabFolder, SWT.NONE);
        item.setText(text);

        Composite currentTab = new Composite(tabFolder, SWT.NULL);
        GridLayout layout = new GridLayout();
        currentTab.setLayout(layout);
        currentTab.setFont(composite.getFont());
       // currentTab.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));

        item.setControl(currentTab);
        return currentTab;

    }




    protected IPreferenceStore doGetPreferenceStore() {
        return PreferencesUtil.getPreferenceStore();
    }

    /**
     * @return
     */
    private String[][] getLabelAndValues() {
        List<NomenclaturalCode> supportedCodes = NomenclaturalCodeHelper
                .getSupportedCodes();
        labelAndValues = new String[supportedCodes.size()][2];
        for (int i = 0; i < supportedCodes.size(); i++) {
            labelAndValues[i][0] = NomenclaturalCodeHelper
                    .getDescription(supportedCodes.get(i));
            labelAndValues[i][1] = PreferencesUtil
                    .getPreferenceKey(supportedCodes.get(i));
        }
        return labelAndValues;
    }




    public void createNomenclaturalCodeTab(Composite parent){

        Combo nomenclaturalCodeCombo;
        Label nomenclaturalCodeLabel;

        composite = addTab(Messages.DatabasePreferencesPage_Define_Default_NomenclaturalCode);
        nomenclaturalCodeCombo = new Combo(composite, SWT.READ_ONLY);
        List<NomenclaturalCode> supportedCodes = NomenclaturalCodeHelper
              .getSupportedCodes();
        for (NomenclaturalCode code: supportedCodes) {
           nomenclaturalCodeCombo.add(NomenclaturalCodeHelper
                   .getDescription(code));

       }
       getLabelAndValues();
       //get the actual nomenclatural code and set it as selection: doGetPreferenceStore().getString(IPreferenceKeys.CDM_NOMENCLATURAL_CODE_KEY);
       nomenclaturalCodeCombo.addSelectionListener(new SelectionAdapter() {
           @Override
        public void widgetSelected(SelectionEvent evt) {

               String name = nomenclaturalCodeCombo.getText();

               for (String[] labelAndValue: labelAndValues){
                   if (labelAndValue[0].equals(name)){
                       selectedPreferenceKey = labelAndValue[1];
                   }
               }


               PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.CDM_NOMENCLATURAL_CODE_KEY, selectedPreferenceKey);

           }
       });
       nomenclaturalCodeLabel = new Label(composite, SWT.READ_ONLY);


        final Button useLocalPreference = new Button(composite, SWT.CHECK);
        boolean isUseLocalPreference = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.ALLOW_OVERRIDE_NOMENCLATURAL_CODE_KEY);
        useLocalPreference.setText(Messages.DatabasePreferencesPage_UseLocalPreferences);
        useLocalPreference.setSelection(isUseLocalPreference);
        useLocalPreference.addSelectionListener(new SelectionAdapter(){
             @Override
             public void widgetSelected(SelectionEvent e) {
                 boolean isUseLocalPreference = useLocalPreference.getSelection();
                 PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.ALLOW_OVERRIDE_NOMENCLATURAL_CODE_KEY, isUseLocalPreference);
              }
         });




}

    public void createBiocaseProviderTab(Composite parent){
        composite = addTab(Messages.DatabasePreferencesPage_Biocase_Provider);
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 2;
        composite.setLayout(gridLayout);
        biocaseProviderList = new ListComponent(composite, SWT.SCROLL_LINE);

 }

    public ListComponent getBiocaseProviderList() {
        return biocaseProviderList;
    }

    public void createNameDetailsViewConfigurationTab(Composite parent, NameDetailsConfigurator config){
        composite = parent;
        composite = addTab(Messages.DatabasePreferencesPage_details_view_configuration);
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 2;
        composite.setLayout(gridLayout);
        nameDetailsConfig = new NameDetailsViewComposite(composite, SWT.SCROLL_LINE, config);
    }


    public void createSpecimenOrObservationTab(Composite parent){
        composite = addTab(Messages.DatabasePreferencesPage_Specimen_Or_Observation);

        final Button showCollectingAreaInGeneralSectionButton = new Button(composite, SWT.CHECK);
        boolean isShowCollectingAreaInGeneralSection = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_COLLECTING_AREAS_IN_GENERAL_SECTION);
        showCollectingAreaInGeneralSectionButton.setText(Messages.DatabasePreferncesPage_Show_Collecting_Areas_in_general_section);
        showCollectingAreaInGeneralSectionButton.setSelection(isShowCollectingAreaInGeneralSection);
        showCollectingAreaInGeneralSectionButton.addSelectionListener(new SelectionAdapter(){
             @Override
             public void widgetSelected(SelectionEvent e) {
                 boolean isShowCollectingAreaInGeneralSection = showCollectingAreaInGeneralSectionButton.getSelection();
                 PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_COLLECTING_AREAS_IN_GENERAL_SECTION, isShowCollectingAreaInGeneralSection);
              }
         });

        final Button determinationOnlyForFieldUnitsButton = new Button(composite, SWT.CHECK);
        boolean isDeterminationOnlyForFieldUnits = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.DETERMINATION_ONLY_FOR_FIELD_UNITS);
        determinationOnlyForFieldUnitsButton.setText(Messages.DatabasePreferncesPage_Determination_only_for_field_unnits);
        determinationOnlyForFieldUnitsButton.setSelection(isDeterminationOnlyForFieldUnits);
        determinationOnlyForFieldUnitsButton.addSelectionListener(new SelectionAdapter(){
             @Override
             public void widgetSelected(SelectionEvent e) {
                 boolean isDeterminationOnlyForFieldUnits = determinationOnlyForFieldUnitsButton.getSelection();
                 PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.DETERMINATION_ONLY_FOR_FIELD_UNITS, isDeterminationOnlyForFieldUnits);
              }
         });

        final Button showTaxonAssociationButton = new Button(composite, SWT.CHECK);
        boolean isShowTaxonAssociation = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_TAXON_ASSOCIATIONS);
        showTaxonAssociationButton.setText(Messages.DatabasePreferncesPage_Taxon_Associations);
        showTaxonAssociationButton.setSelection(isShowTaxonAssociation);
        showTaxonAssociationButton.addSelectionListener(new SelectionAdapter(){
             @Override
             public void widgetSelected(SelectionEvent e) {
                 boolean isShowTaxonAssociation = showTaxonAssociationButton.getSelection();
                 PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_TAXON_ASSOCIATIONS, isShowTaxonAssociation);
              }
         });



 }

/**
 * {@inheritDoc}
 */
@Override
public boolean canFlipToNextPage() {
    // TODO Auto-generated method stub
    return false;
}



/**
 * {@inheritDoc}
 */
@Override
public String getName() {
    // TODO Auto-generated method stub
    return null;
}



/**
 * {@inheritDoc}
 */
@Override
public IWizardPage getNextPage() {
    // TODO Auto-generated method stub
    return null;
}



/**
 * {@inheritDoc}
 */
@Override
public IWizardPage getPreviousPage() {
    // TODO Auto-generated method stub
    return null;
}



/**
 * {@inheritDoc}
 */
@Override
public IWizard getWizard() {
    // TODO Auto-generated method stub
    return null;
}



/**
 * {@inheritDoc}
 */
@Override
public boolean isPageComplete() {

    return true;
}



/**
 * {@inheritDoc}
 */
@Override
public void setPreviousPage(IWizardPage page) {
    // TODO Auto-generated method stub

}



/**
 * {@inheritDoc}
 */
@Override
public void setWizard(IWizard newWizard) {
    // TODO Auto-generated method stub

}

/**
 * {@inheritDoc}
 */
@Override
public void createControl(Composite parent) {
    createNameDetailsViewConfigurationTab(parent, config);
    createNomenclaturalCodeTab(parent);

    createSpecimenOrObservationTab(parent);
    createBiocaseProviderTab(parent);
    setControl(parent);
}

/**
 * @return
 */
public NameDetailsConfigurator getConfig() {
    return config;
}

/**
 *
 */
public Abcd206ImportConfigurator getAbcdImportConfig() {
    return abcdImportConfigurator;

}

/**
 * @return
 */
public void createAbcdImportConfig() {
    this.abcdImportConfigurator.setAddIndividualsAssociationsSuchAsSpecimenAndObservations(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_ADD_INDIVIDUALS_ASSOCIATIONS_SUCH_AS_SPECIMEN_AND_OBSERVATIONS));
    this.abcdImportConfigurator.setAddMediaAsMediaSpecimen(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_ADD_MEDIA_AS_MEDIASPECIMEN));
    this.abcdImportConfigurator.setAllowReuseOtherClassifications(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_ALLOW_REUSE_OTHER_CLASSIFICATIONS));
    //this.abcdImportConfigurator.setClassificationUuid(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_CLASSIFICATION_UUID));
    this.abcdImportConfigurator.setDeduplicateClassifications(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_DEDUPLICATE_CLASSIFICATIONS));
    this.abcdImportConfigurator.setDeduplicateReferences(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_DEDUPLICATE_REFERENCES));
   // this.abcdImportConfigurator.setDefaultAuthor(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_DEFAULT_AUTHOR));
    this.abcdImportConfigurator.setGetSiblings(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_DO_SIBLINGS));
    this.abcdImportConfigurator.setIgnoreAuthorship(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_IGNORE_AUTHORSHIP));
    this.abcdImportConfigurator.setIgnoreImportOfExistingSpecimen(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_IGNORE_IMPORT_OF_EXISTING_SPECIMEN));
    this.abcdImportConfigurator.setMapUnitIdToAccessionNumber(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_MAP_UNIT_ID_TO_ACCESSION_NUMBER));
    this.abcdImportConfigurator.setMapUnitIdToBarcode(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_MAP_UNIT_ID_TO_BARCODE));
    this.abcdImportConfigurator.setMapUnitIdToCatalogNumber(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_MAP_UNIT_ID_TOCATALOG_NUMBER));
    this.abcdImportConfigurator.setMoveNewTaxaToDefaultClassification(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_MOVE_NEW_TAXA_TO_DEFAULT_CLASSIFICATION));
    this.abcdImportConfigurator.setReuseExistingDescriptiveGroups(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_REUSE_EXISTING_DESCRIPTIVE_GROUPS));
    this.abcdImportConfigurator.setReuseExistingTaxaWhenPossible(doGetPreferenceStore().getBoolean(IPreferenceKeys.ABCD_IMPORT_CONFIGURATOR_REUSE_EXISTING_TAXA_WHEN_POSSIBLE));

}







}
