/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.databaseAdmin.wizard;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;

import eu.etaxonomy.cdm.api.application.ICdmRepository;
import eu.etaxonomy.cdm.api.service.IPreferenceService;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportConfigurator;
import eu.etaxonomy.cdm.model.metadata.CdmPreference;
import eu.etaxonomy.cdm.model.metadata.PreferencePredicate;
import eu.etaxonomy.taxeditor.io.wizard.AbcdImportConfiguratorWizardPage;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author k.luther
 * @date 18.11.2016
 *
 */
public class DatabasePreferencesWizard extends Wizard {


    public DatabasePreferencesPage preferencePage;
    public AbcdImportConfiguratorWizardPage configAbcdImport;


    public DatabasePreferencesWizard() {
        setWindowTitle("Database Preferences Wizard");

        preferencePage = new DatabasePreferencesPage("Database Preferences");
        configAbcdImport = AbcdImportConfiguratorWizardPage.createPage(Abcd206ImportConfigurator.NewInstance(null, null));

    }



    /**
     * @return the preferencePage
     */
    public DatabasePreferencesPage getPreferencePage() {
        return preferencePage;
    }
    /**
     * {@inheritDoc}
     */
    @Override
    public boolean performFinish() {

//       getPreferencePage().performOk();
        String value =getPreferencePage().doGetPreferenceStore().getString(IPreferenceKeys.CDM_NOMENCLATURAL_CODE_KEY);

        boolean allowOverride =  getPreferencePage().doGetPreferenceStore().getBoolean(IPreferenceKeys.ALLOW_OVERRIDE_NOMENCLATURAL_CODE_KEY);
        CdmPreference pref = CdmPreference.NewDatabaseInstance( PreferencePredicate.NomenclaturalCode, value);
        pref.setAllowOverride(allowOverride);

        ICdmRepository controller = CdmStore.getCurrentApplicationConfiguration();
        if (controller == null){
            return false;
        }
        IPreferenceService service = controller.getPreferenceService();
        service.set(pref);

        value = getPreferencePage().getNameDetailsConfig().createNameDetailsViewConfig().toString();
        allowOverride = getPreferencePage().doGetPreferenceStore().getBoolean(IPreferenceKeys.ALLOW_OVERRIDE_NAMEDETAILS);
        pref = CdmPreference.NewDatabaseInstance( PreferencePredicate.NameDetailsView, value);
        pref.setAllowOverride(allowOverride);
        service.set(pref);


        boolean isDeterminationOnlyForFieldUnit= getPreferencePage().doGetPreferenceStore().getBoolean(IPreferenceKeys.DETERMINATION_ONLY_FOR_FIELD_UNITS );
        pref = CdmPreference.NewDatabaseInstance( PreferencePredicate.DeterminationOnlyForFieldUnits, String.valueOf(isDeterminationOnlyForFieldUnit));
        pref.setAllowOverride(false);
        service.set(pref);

        boolean isShowCollectingAreasInGeneralsecion= getPreferencePage().doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_COLLECTING_AREAS_IN_GENERAL_SECTION );
        pref = CdmPreference.NewDatabaseInstance( PreferencePredicate.ShowCollectingAreasInGeneralSection, String.valueOf(isShowCollectingAreasInGeneralsecion));
        pref.setAllowOverride(false);
        service.set(pref);

        boolean isShowTaxonAssociations= getPreferencePage().doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_TAXON_ASSOCIATIONS);
        pref = CdmPreference.NewDatabaseInstance( PreferencePredicate.ShowTaxonAssociations, String.valueOf(isShowTaxonAssociations));
        pref.setAllowOverride(false);
        service.set(pref);

        String biocaseProviderList = this.getPreferencePage().getBiocaseProviderList().createAllProviderString();
        if (biocaseProviderList == null){
            getPreferencePage().doGetPreferenceStore().setValue(IPreferenceKeys.BIOCASE_PROVIDER_LIST,"");
        }else{
            getPreferencePage().doGetPreferenceStore().setValue(IPreferenceKeys.BIOCASE_PROVIDER_LIST, biocaseProviderList);

        }
        pref = CdmPreference.NewDatabaseInstance( PreferencePredicate.BioCaseProvider, String.valueOf(biocaseProviderList));
        pref.setAllowOverride(false);
        service.set(pref);
//        getPreferencePage().createAbcdImportConfig();
//        value = getPreferencePage().getAbcdImportConfig().toString();
//        allowOverride = getPreferencePage().doGetPreferenceStore().getBoolean(IPreferenceKeys.ALLOW_OVERRIDE_ABCD_IMPORT_CONFIG);
//        pref = CdmPreference.NewDatabaseInstance( PreferencePredicate.AbcdImportConfig, value);
//        pref.setAllowOverride(allowOverride);
//        service.set(pref);

        return true;
    }



    @Override
    public void addPages() {
        addPage(preferencePage);
        addPage(configAbcdImport);
    }

    @Override
    public IWizardPage getNextPage(IWizardPage currentPage) {
       if (currentPage.equals(preferencePage)){
           return configAbcdImport;
       }
       return null;
    }


}
