/**
* Copyright (C) 2017 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.databaseAdmin.wizard;


import java.awt.Toolkit;
import java.util.ArrayList;

import javax.swing.event.DocumentEvent;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.List;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;


/**
 * @author k.luther
 * @date 20.04.2017
 *
 */
public class ListComponent
                      {
    private List list;

    private static final String addString = "Add";
    private static final String removeString = "Remove";
    private Button removeButton;
    private Text providerURI;

    public ListComponent(Composite parent, int style) {
        list = new List(parent, SWT.BORDER | SWT.MULTI | SWT.V_SCROLL);

        java.util.List<String> providerList = new ArrayList<String>();
        String allProviderString = PreferencesUtil.getPreferenceStore().getString(IPreferenceKeys.BIOCASE_PROVIDER_LIST);
        //the string is structured like this: http://ww3.bgbm.org/biocase/pywrapper.cgi?dsa=DNA_Bank;http:...;
        String[] providerArray = allProviderString.split(";");

        for (String providerString : providerArray){
            list.add(providerString);
        }

        list.setSelection(0);
        GridData dataList = new GridData();
        dataList.horizontalAlignment = GridData.FILL;
        dataList.horizontalSpan = 2;
        dataList.verticalSpan= 4;

        list.setLayoutData(dataList);


        providerURI = new Text(parent, SWT.BORDER | SWT.SINGLE | SWT.FULL_SELECTION);
        GridData dataProviderUri = new GridData();
        dataProviderUri.horizontalAlignment = GridData.FILL;
        dataProviderUri.horizontalSpan = 2;
        providerURI.setLayoutData(dataProviderUri);

        Button addButton = new Button(parent, SWT.NULL);
        AddListener addListener = new AddListener(addButton);
        addButton.setText(addString);
        addButton.addMouseListener(addListener);

        removeButton = new Button(parent, SWT.NULL);
        removeButton.setText(removeString);
        removeButton.addMouseListener(new RemoveListener());
    }

    class RemoveListener implements MouseListener {
        @Override
        public void mouseUp(MouseEvent e)  {
            //This method can be called only if
            //there's a valid selection
            //so go ahead and remove whatever's selected.
            int index = list.getSelectionIndex();
            list.remove(index);

            int size = list.getItemCount();

            if (size == 0) { //Nothing's left, disable removing.
                removeButton.setEnabled(false);

            } else { //Select an index.
                if (index == size) {
                    //removed item in last position
                    index--;
                }

                list.setSelection(index-1);


            }
        }
        /**
         * {@inheritDoc}
         */
        @Override
        public void mouseDoubleClick(MouseEvent e) {
            // TODO Auto-generated method stub

        }


        /**
         * {@inheritDoc}
         */
        @Override
        public void mouseDown(MouseEvent e) {
            // TODO Auto-generated method stub

        }
    }

    //This listener is shared by the text field and the add button.
    class AddListener implements MouseListener {
        private boolean alreadyEnabled = false;
        private Button button;

        public AddListener(Button button) {
            this.button = button;
        }


        protected boolean alreadyInList(String name) {
            return list.getData(name) != null;
        }


        private void enableButton() {
            if (!alreadyEnabled) {
                button.setEnabled(true);
            }
        }

        private boolean handleEmptyTextField(DocumentEvent e) {
            if (e.getDocument().getLength() <= 0) {
                button.setEnabled(false);
                alreadyEnabled = false;
                return true;
            }
            return false;
        }



        /**
         * {@inheritDoc}
         */
        @Override
        public void mouseDoubleClick(MouseEvent e) {
            // TODO Auto-generated method stub

        }

        /**
         * {@inheritDoc}
         */
        @Override
        public void mouseDown(MouseEvent e) {
            // TODO Auto-generated method stub

        }

        /**
         * {@inheritDoc}
         */
        @Override
        public void mouseUp(MouseEvent e) {
            String name = providerURI.getText();

            //User didn't type in a unique name...
            if (name.equals("") || alreadyInList(name)) {
                Toolkit.getDefaultToolkit().beep();
                providerURI.selectAll();
                return;
            }

            int index = list.getSelectionIndex(); //get selected index
            if (index == -1) { //no selection, so insert at beginning
                index = 0;
            } else {           //add after the selected item
                index++;
            }

            list.add(providerURI.getText(), index);

            //Select the new item
            list.setSelection(index);
            list.redraw();

        }
    }

    protected String createAllProviderString(){
        String allProviderString = null;
        boolean first = true;
        for (String item: list.getItems()){
            if (first || allProviderString == null || allProviderString == ""){
                allProviderString = item.trim();
                first = false;
            }else{
                allProviderString +=";"+ item.trim();
            }
        }

        return allProviderString;

    }



}

