/**
* Copyright (C) 2017 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.databaseAdmin.wizard;

import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.NameDetailsConfigurator;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;

/**
 * @author k.luther
 * @date 22.02.2017
 *
 */
public class NameDetailsViewComposite extends Composite {

    NameDetailsConfigurator config;
    boolean isSimpleDetailsViewActivated;
    boolean isShowTaxon;
    boolean isShowLSID;
    boolean isShowNomenclaturalCode;
    boolean isShowNameCache;
    boolean isShowAppendedPhrase;
    boolean isShowRank;
    boolean isShowEpithets;
    boolean isShowAuthorshipCache;
    boolean isShowAuthorship;
    boolean isShowNomenclaturalRef;
    boolean isShowNomenclaturalStatus;
    boolean isShowProtologue;
    boolean isShowTypeDesignation;
    boolean isShowNameRelationship;
    Composite child;

    public NameDetailsViewComposite(Composite parent, int style, NameDetailsConfigurator config){

        super(parent, style);
//        TabItem tbtmNameDetailsConfiguration = new TabItem(tabFolder, SWT.NONE);
//        Composite c2 = new Composite(tabFolder, SWT.BORDER);
//        c2.setLayout(new GridLayout(1, true));
//        tbtmNameDetailsConfiguration.setControl(c2);
       // composite.setLayout(new GridLayout(1, true));
       this.config = config;

      // Composite composite = new Composite(parent, SWT.NULL);
       this.setLayout(new GridLayout());

       isSimpleDetailsViewActivated= PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_SIMPLE_NAME_DETAILS_SECTION);
       final Button activateCheckButton = new Button(this, SWT.CHECK);
       activateCheckButton.setText("Show only a simple name details view");
       activateCheckButton.setSelection(isSimpleDetailsViewActivated);
       activateCheckButton.addSelectionListener(new SelectionAdapter(){
       @Override
       public void widgetSelected(SelectionEvent e) {
           isSimpleDetailsViewActivated = activateCheckButton.getSelection();
          //
           if(isSimpleDetailsViewActivated){
               child.setVisible(true);
               child.setEnabled(true);
           }else{
               child.setVisible(false);
               child.setEnabled(false);
           }
        }
        });

       child = new Composite(this, SWT.NULL);
       child.setLayout(new GridLayout());
       child.setVisible(isSimpleDetailsViewActivated);

       final Button showTaxon = new Button(child, SWT.CHECK);
       isShowTaxon = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_SIMPLE_NAME_DETAILS_TAXON);
       showTaxon.setText("Show taxon of the name");
       showTaxon.setSelection(isShowTaxon);
       showTaxon.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
               isShowTaxon = showTaxon.getSelection();

             }
        });

       final Button showLsid = new Button(child, SWT.CHECK);
       isShowLSID = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_LSID);
       showLsid.setText("Show Lsid of the name");
       showLsid.setSelection(isShowLSID);
       showLsid.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowLSID = showLsid.getSelection();

             }
        });

       final Button showNomenclaturalCode = new Button(child, SWT.CHECK);
       isShowNomenclaturalCode = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_CODE);
       showNomenclaturalCode.setText("Show the nomenclatural code");
       showNomenclaturalCode.setSelection(isShowNomenclaturalCode);
       showNomenclaturalCode.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowNomenclaturalCode = showNomenclaturalCode.getSelection();

             }
        });

       final Button showNameCache = new Button(child, SWT.CHECK);
       isShowNameCache= PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NAMECACHE);
       showNameCache.setText("Show nameCache of the name (only the scientific name without the author and year)");
       showNameCache.setSelection(isShowNomenclaturalCode);
       showNameCache.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowNameCache = showNameCache.getSelection();

             }
        });
       final Button showAppendedPhrase = new Button(child, SWT.CHECK);
       isShowAppendedPhrase= PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_APPENDED_PHRASE);
       showAppendedPhrase.setText("Show appended phrase");
       showAppendedPhrase.setSelection(isShowAppendedPhrase);
       showAppendedPhrase.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowAppendedPhrase = showAppendedPhrase.getSelection();

             }
        });

       final Button showRank = new Button(child, SWT.CHECK);
       isShowRank = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_RANK);
       showRank.setText("Show rank of the name");
       showRank.setSelection(isShowRank);
       showRank.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowRank = showRank.getSelection();

             }
        });
       final Button showEpithets = new Button(child, SWT.CHECK);
       isShowEpithets = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_ATOMISED_EPITHETS);
       showEpithets.setText("Show atomised epithets");
       showEpithets.setSelection(isShowEpithets);
       showEpithets.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowEpithets = showEpithets.getSelection();

             }
        });
       final Button showAuthorshipCache = new Button(child, SWT.CHECK);
       isShowAuthorshipCache= PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_AUTHORSHIP_CACHE);
       showAuthorshipCache.setText("Show authorship cache");
       showAuthorshipCache.setSelection(isShowAuthorshipCache);
       showAuthorshipCache.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowAuthorshipCache = showAuthorshipCache.getSelection();

             }
        });

       final Button showAuthorship = new Button(child, SWT.CHECK);
       isShowAuthorship = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_AUTHORSHIP);
       showAuthorship.setText("Show authorship section");
       showAuthorship.setSelection(isShowAuthorship);
       showAuthorship.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowAuthorship = showAuthorship.getSelection();

             }
        });

       final Button showNomenclaturalRef = new Button(child, SWT.CHECK);
       isShowNomenclaturalRef = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_REFERENCE);
       showNomenclaturalRef.setText("Show nomenclatural reference section");
       showNomenclaturalRef.setSelection(isShowNomenclaturalRef);
       showNomenclaturalRef.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowNomenclaturalRef = showNomenclaturalRef.getSelection();

             }
        });

       final Button showNomenclaturalStatus = new Button(child, SWT.CHECK);
       isShowNomenclaturalStatus = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_STATUS);
       showNomenclaturalStatus.setText("Show nomenclatural status section");
       showNomenclaturalStatus.setSelection(isShowNomenclaturalStatus);
       showNomenclaturalStatus.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowNomenclaturalStatus = showNomenclaturalStatus.getSelection();

             }
        });

       final Button showProtologue = new Button(child, SWT.CHECK);
       isShowProtologue  = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_PROTOLOGUE);
       showProtologue.setText("Show protologue section");
       showProtologue.setSelection(isShowProtologue);
       showProtologue.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowProtologue = showProtologue.getSelection();

             }
        });

       final Button showTypeDesignation = new Button(child, SWT.CHECK);
       isShowTypeDesignation = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_TYPE_DESIGNATION);
       showTypeDesignation.setText("Show name type designation section");
       showTypeDesignation.setSelection(isShowTypeDesignation);
       showTypeDesignation.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowTypeDesignation = showTypeDesignation.getSelection();

             }
        });


       final Button showNameRelationship = new Button(child, SWT.CHECK);
       isShowNameRelationship = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NAME_RELATIONSHIP);
       showNameRelationship.setText("Show name relationship section");
       showNameRelationship.setSelection(isShowNameRelationship);
       showNameRelationship.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isShowNameRelationship = showNameRelationship.getSelection();

             }
        });

       if(isSimpleDetailsViewActivated){
           child.setEnabled(true);
       }else{
           child.setEnabled(false);
       }

    }

    /**
    *
    */
   protected NameDetailsConfigurator createNameDetailsViewConfig() {
      saveConfigToPrefernceStore();

      config.setSimpleDetailsViewActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_SIMPLE_NAME_DETAILS_SECTION));
      config.setAppendedPhraseActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_APPENDED_PHRASE));
      config.setAtomisedEpithetsActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_ATOMISED_EPITHETS));
      config.setAuthorshipSectionActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_AUTHORSHIP));
      config.setLSIDActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_LSID));
      config.setNameCacheActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_CACHE));
      config.setNameRelationsSectionActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NAME_RELATIONSHIP));
      config.setNomenclaturalCodeActived(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_CODE));
      config.setNomenclaturalStatusSectionActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_STATUS));
      config.setNomenclaturalReferenceSectionActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_REFERENCE));
      config.setProtologueActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_PROTOLOGUE));
      config.setRankActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_RANK));
      config.setSimpleDetailsViewActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_SIMPLE_NAME_DETAILS_SECTION));
      config.setTaxonSectionActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_SIMPLE_NAME_DETAILS_TAXON));
      config.setTypeDesignationSectionActivated(doGetPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_TYPE_DESIGNATION));
      return config;
   }

    /**
     *
     */
    private void saveConfigToPrefernceStore() {
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_SIMPLE_NAME_DETAILS_SECTION,
                isSimpleDetailsViewActivated);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_SIMPLE_NAME_DETAILS_TAXON, isShowTaxon);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_LSID, isShowLSID);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_CODE,
                isShowNomenclaturalCode);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NAMECACHE,
                isShowNameCache);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_APPENDED_PHRASE,
                isShowAppendedPhrase);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_RANK, isShowRank);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_ATOMISED_EPITHETS,
                isShowEpithets);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_AUTHORSHIP_CACHE,
                isShowAuthorshipCache);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_AUTHORSHIP,
                isShowAuthorship);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_REFERENCE,
                isShowNomenclaturalRef);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NOMENCLATURAL_STATUS,
                isShowNomenclaturalStatus);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_PROTOLOGUE,
                isShowProtologue);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_TYPE_DESIGNATION,
                isShowTypeDesignation);
        PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_NAME_RELATIONSHIP,
                isShowNameRelationship);

    }

    protected IPreferenceStore doGetPreferenceStore() {
        return PreferencesUtil.getPreferenceStore();
    }

}
