/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.databaseAdmin.wizard;

import java.util.List;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.TabFolder;
import org.eclipse.swt.widgets.TabItem;

import eu.etaxonomy.cdm.io.common.CacheUpdaterConfigurator;
import eu.etaxonomy.cdm.io.common.SortIndexUpdaterConfigurator;
import eu.etaxonomy.cdm.model.common.IdentifiableEntity;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.l10n.Messages;

/**
 * @author k.luther
 * @date 14.12.2016
 *
 */
public class Test extends WizardPage {

    CacheUpdaterConfigurator config;
    SortIndexUpdaterConfigurator sortIndexConfig;
    public Test(String pageName, CacheUpdaterConfigurator configTitleCache, SortIndexUpdaterConfigurator sortIndexConfig) {
        super(pageName);
        config = configTitleCache;
        this.sortIndexConfig = sortIndexConfig;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void createControl(Composite parent) {


            Composite container = new Composite(parent, SWT.NULL);
            setControl(container);
            container.setLayout(new FillLayout(SWT.HORIZONTAL));

            TabFolder tabFolder = new TabFolder(container, SWT.NONE);

            TabItem tbtmSortIndex = new TabItem(tabFolder, SWT.NONE);
            tbtmSortIndex.setText("Sort Index");

            Composite composite = new Composite(tabFolder, SWT.NONE);
            tbtmSortIndex.setControl(composite);
            composite.setLayout(new GridLayout(1, true));

            Button checkBoxTaxonNode = new Button(composite, SWT.CHECK);
            checkBoxTaxonNode.setSelection(sortIndexConfig.isDoTaxonNode());
            checkBoxTaxonNode.setText(Messages.DatabaseRepairPage_updateTaxonNodes);
            checkBoxTaxonNode
                    .setToolTipText(Messages.DatabaseRepairPage_toolTip_taxonNode);
            checkBoxTaxonNode.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    sortIndexConfig.setDoTaxonNode(!sortIndexConfig.isDoTaxonNode());
                }
            });

            Button checkBoxPolytomousKeyNode = new Button(composite, SWT.CHECK);
            checkBoxPolytomousKeyNode.setSelection(sortIndexConfig.isDoPolytomousKeyNode());
            checkBoxPolytomousKeyNode.setText(Messages.DatabaseRepairPage_PolytomousKeyNode);
            checkBoxPolytomousKeyNode
            .setToolTipText(Messages.DatabaseRepairPage_toolTip_polytomousKeyNode);
            checkBoxPolytomousKeyNode.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    sortIndexConfig.setDoPolytomousKeyNode(!sortIndexConfig.isDoPolytomousKeyNode());
                }
            });

            Button checkBoxFeatureNode = new Button(composite, SWT.CHECK);
            checkBoxFeatureNode.setSelection(sortIndexConfig.isDoFeatureNode());
            checkBoxFeatureNode.setText(Messages.DatabaseRepairPage_featureNodes);
            checkBoxFeatureNode
            .setToolTipText(Messages.DatabaseRepairPage_toolTipFeatureNodes);
            checkBoxFeatureNode.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    sortIndexConfig.setDoFeatureNode(!sortIndexConfig.isDoFeatureNode());
                }
            });


            TabItem tbtmNewItem = new TabItem(tabFolder, SWT.NONE);
            tbtmNewItem.setText("Update Caches");

            Composite composite_1 = new Composite(tabFolder, SWT.NONE);
            tbtmNewItem.setControl(composite_1);
            composite_1.setLayout(new GridLayout(1, false));

            Button checkBoxTaxonName = new Button(composite_1, SWT.CHECK);
            checkBoxTaxonName.setSelection(config.getClassList().contains(TaxonNameBase.class));
            checkBoxTaxonName.setText(Messages.DatabaseRepairPage_updateTaxonName);
            checkBoxTaxonName
                    .setToolTipText(Messages.DatabaseRepairPage_toolTip_TaxonName);
            checkBoxTaxonName.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    List<Class<? extends IdentifiableEntity>> classList = config.getClassList();
                    classList.add(TaxonNameBase.class);
                }
            });

            Button checkBoxTaxonBase = new Button(composite_1, SWT.CHECK);
            checkBoxTaxonBase.setSelection(config.getClassList().contains(TaxonBase.class));
            checkBoxTaxonBase.setText(Messages.DatabaseRepairPage_TaxonBase);
            checkBoxTaxonBase
            .setToolTipText(Messages.DatabaseRepairPage_toolTip_taxonBase);
            checkBoxTaxonBase.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    List<Class<? extends IdentifiableEntity>> classList  = config.getClassList();
                    classList.add(TaxonBase.class);
                }
            });

            Button checkBoxReference = new Button(composite_1, SWT.CHECK);
            checkBoxReference.setSelection(config.getClassList().contains(Reference.class));
            checkBoxReference.setText(Messages.DatabaseRepairPage_Reference);
            checkBoxReference
            .setToolTipText(Messages.DatabaseRepairPage_toolTip_reference);
            checkBoxReference.addSelectionListener(new SelectionAdapter() {
                @Override
                public void widgetSelected(SelectionEvent e) {
                    List<Class<? extends IdentifiableEntity>> classList  = config.getClassList();
                    classList.add(Reference.class);
                }
            });


            tabFolder.pack();
    }
}
