/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.definedterm;

import org.eclipse.core.expressions.PropertyTester;
import org.eclipse.jface.viewers.IStructuredSelection;

import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.common.DefinedTermBase;
import eu.etaxonomy.cdm.model.common.Marker;
import eu.etaxonomy.cdm.model.common.MarkerType;
import eu.etaxonomy.cdm.model.common.TermBase;
import eu.etaxonomy.cdm.model.common.TermVocabulary;

/**
 * @author l.morris
 * @date 9 Jan 2012
 *
 */
public class TermBasePropertyTester extends PropertyTester {

	private static final String IS_MODIFIABLE = "isModifiable";
	

	/* (non-Javadoc)
	 * @see org.eclipse.core.expressions.IPropertyTester#test(java.lang.Object, java.lang.String, java.lang.Object[], java.lang.Object)
	 */
	@Override
	public boolean test(Object receiver, String property, Object[] args,
			Object expectedValue) {
		
		IStructuredSelection selection = (IStructuredSelection) receiver;
		Object selectedElement = selection.getFirstElement();
		if (selectedElement != null && HibernateProxyHelper.isInstanceOf(selectedElement, TermBase.class)){
			TermBase term = HibernateProxyHelper.deproxy(selectedElement, TermBase.class);

			if(IS_MODIFIABLE.equals(property)){
				return isModifiable(term);
			}
		}
		
		return false;
	}


	/**
	 * Checks whether there is a {@link Marker} with the type {@link MarkerType#MODIFIABLE()} and if there is then return its value.
	 * 
	 * @return The markers value if it exists 
	 */
	public static boolean isModifiable(TermBase termBase) {
		if (termBase == null){
			return true;
		}
		
		TermVocabulary vocabulary = null;
		
		if(termBase instanceof DefinedTermBase){
			vocabulary = ((DefinedTermBase) termBase).getVocabulary();
		}else if(termBase instanceof TermVocabulary){
			vocabulary = (TermVocabulary) termBase;
		}
		
		if(vocabulary == null){
			return true;
		}
		
		for(Marker vocabularyMarker : vocabulary.getMarkers()){
			if(vocabularyMarker.getMarkerType().equals(MarkerType.MODIFIABLE())){
				return vocabularyMarker.getValue();			
			}
		}
				
		return true;
	}

}
