/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.definedterm;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;
import java.util.SortedSet;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;

import eu.etaxonomy.cdm.model.common.DefinedTermBase;
import eu.etaxonomy.cdm.model.common.TermVocabulary;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author l.morris
 * @date 8 Dec 2011
 *
 */
public class TermContentProvider implements ITreeContentProvider {

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IContentProvider#dispose()
	 */
	@Override
	public void dispose() {
		// TODO Auto-generated method stub

	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IContentProvider#inputChanged(org.eclipse.jface.viewers.Viewer, java.lang.Object, java.lang.Object)
	 */
	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
		// TODO Auto-generated method stub

	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IStructuredContentProvider#getElements(java.lang.Object)
	 */
	@Override
	public Object[] getElements(Object inputElement) {
	
		Collection<TermVocabulary> inputElements = (Collection<TermVocabulary>) inputElement;
		return inputElements.toArray();

	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#getChildren(java.lang.Object)
	 */
	@Override
	public Object[] getChildren(Object parentElement) {
		
		if(parentElement instanceof TermVocabulary){			
			return getTopLevelElements((TermVocabulary)parentElement);
		} else if (parentElement instanceof DefinedTermBase) {
			return ((DefinedTermBase) parentElement).getIncludes().toArray();
		}
		return null;
	}
	
	/**
	 *  
	 * @param vocabulary
	 * @return An array of DefinedTermBase objects that do not have parents
	 * 
	 * TODO: Needs to be implemented in cdmlib
	 */
	private Object[] getTopLevelElements(TermVocabulary vocabulary) {
		
		SortedSet<DefinedTermBase> terms = vocabulary.getTermsOrderedByLabels(CdmStore.getDefaultLanguage());
		Set<DefinedTermBase> topLevelTerms = new HashSet<DefinedTermBase>(); 
	 
		for (DefinedTermBase term : terms){
			 if (term.getPartOf() == null){
				 topLevelTerms.add(term);
			 }				
		}	 
	 	return topLevelTerms.toArray();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#getParent(java.lang.Object)
	 */
	@Override
	public Object getParent(Object element) {

		if(element instanceof DefinedTermBase){
			DefinedTermBase definedTermBase = (DefinedTermBase)element;
			if (definedTermBase.getPartOf() == null) {
				return definedTermBase.getVocabulary();
			} else {
				return definedTermBase.getPartOf();
			}			
		}
		return null;

	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#hasChildren(java.lang.Object)
	 */
	@Override
	public boolean hasChildren(Object element) {		
		if (getChildren(element) != null){			
			return getChildren(element).length > 0;
		}
		return false;
	}

}
