/**
 * Copyright (C) 2009 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.editor.definedterm;

import java.util.ArrayList;

import org.eclipse.jface.viewers.StyledCellLabelProvider;
import org.eclipse.jface.viewers.StyledString;
import org.eclipse.jface.viewers.StyledString.Styler;
import org.eclipse.jface.viewers.ViewerCell;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyleRange;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.TextStyle;
import org.eclipse.swt.widgets.Display;

import eu.etaxonomy.cdm.common.CdmUtils;
import eu.etaxonomy.cdm.model.common.DefinedTermBase;
import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.common.Representation;
import eu.etaxonomy.cdm.model.common.TermBase;
import eu.etaxonomy.cdm.model.common.TermVocabulary;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;

/**
 * @author l.morris
 * @date 9 Dec 2011
 *
 */
public class TermLabelProvider extends StyledCellLabelProvider {

    private static Color vocColor = Display.getCurrent().getSystemColor(SWT.COLOR_BLUE);
    private Styler vocStyler;

    public TermLabelProvider() {
    }

    public TermLabelProvider(Styler vocStyler){
        this.vocStyler = vocStyler;
    }

    @Override
    public void update(ViewerCell cell) {
        Object element = cell.getElement();
        int columnIndex = cell.getColumnIndex();

        String text = getText(element);
        cell.setText(text);

        if (element instanceof TermVocabulary && text != null) {
            StyledString styledString = new StyledString(text, getVocabularyStyler());
            StyleRange[] styleRanges;
            styleRanges = styledString.getStyleRanges();
            cell.setStyleRanges(styleRanges);
        }
        super.update(cell);
    }

    public StyledString getStyledText(Object element) {

        if (element instanceof TermVocabulary) {
            new StyledString(getText(element), getVocabularyStyler());
        }
        return new StyledString(getText(element), StyledString.QUALIFIER_STYLER);
    }

    public String getText(Object element) {
    	if(element instanceof TermBase){
    		TermBase termBase = (TermBase)element;
    		Representation rep = termBase.getRepresentation(PreferencesUtil.getGlobalLanguage());
    		if (rep == null){
    			rep = termBase.getPreferredRepresentation(new ArrayList<Language>());
    		}
    		String label = rep != null? rep.getLabel() : termBase.getTitleCache();
    		if (element instanceof DefinedTermBase) {
    			DefinedTermBase<?> dtb = (DefinedTermBase<?>) element;
    			return CdmUtils.concat(" : ", dtb.getIdInVocabulary(), label);

    		} else {
    			return label;
    		}
    	}

        // FIXME : must throw an exception here
        return element.toString();
    }

    private Styler getVocabularyStyler() {
        if (vocStyler == null) {
            vocStyler = new Styler() {
                @Override
                public void applyStyles(TextStyle textStyle) {
                    textStyle.foreground = vocColor;
                }
            };
        }
        return vocStyler;
    }

}
