/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.definedterm.handler;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IHandler;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.taxeditor.editor.definedterm.DefinedTermEditor;
import eu.etaxonomy.taxeditor.editor.definedterm.operation.CreateTermVocabularyOperation;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.operation.AbstractPostOperation;
import eu.etaxonomy.taxeditor.operation.IPostOperationEnabled;
import eu.etaxonomy.taxeditor.store.StoreUtil;

/**
 * @author l.morris
 * @date 21 Dec 2011
 *
 */
public class CreateTermVocabularyHandler extends AbstractHandler implements
		IHandler {

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		IPostOperationEnabled editor = (IPostOperationEnabled) HandlerUtil
				.getActiveEditor(event);

		if (editor instanceof DefinedTermEditor){
			DefinedTermEditor dfe = (DefinedTermEditor) editor;

			try {
				String label = event.getCommand().getName();
				IUndoContext undoContext = StoreUtil.getUndoContext();

				AbstractPostOperation operation = 
						new CreateTermVocabularyOperation(label, 
								undoContext, 
								dfe.getDefinedTermEditorInput(), 
								(DefinedTermEditor) editor);
				StoreUtil.executeOperation(operation);

			} catch (NotDefinedException e) {
				MessagingUtils.error(getClass(), e);
			}			
		}
		return null;
	}
}
