/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.definedterm.handler;

import java.util.Iterator;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.common.TermBase;
import eu.etaxonomy.taxeditor.editor.definedterm.DefinedTermEditor;
import eu.etaxonomy.taxeditor.editor.definedterm.operation.DeleteTermBaseOperation;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.operation.AbstractPostOperation;
import eu.etaxonomy.taxeditor.store.StoreUtil;

/**
 * @author l.morris
 * @date 22 Dec 2011
 *
 */
public class DeleteTermBaseHandler extends AbstractHandler {

	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		IEditorPart editor = HandlerUtil
				.getActiveEditor(event);

		if (editor.isDirty()){
			boolean proceed = MessageDialog.openQuestion(null,
					"Save changes", "You have made changes that must be saved before this query can be executed. Would you like to proceed?");
			if (proceed) {
				editor.doSave(null);
			} else {
				return null;
			}
		}
		if (editor instanceof DefinedTermEditor){
		    DefinedTermEditor dfe = (DefinedTermEditor) editor;
		    try {
		        String label = event.getCommand().getName();
		        IUndoContext undoContext = StoreUtil.getUndoContext();

		        ISelection selection = dfe.getViewer().getSelection();
		        if(selection instanceof IStructuredSelection){

		            Iterator<TermBase> selectionIterator = ((IStructuredSelection) selection).iterator();

		            while (selectionIterator.hasNext()){

		                TermBase term = selectionIterator.next();


		                AbstractPostOperation operation =
		                        new DeleteTermBaseOperation(label,
		                                undoContext,
		                                term,
		                                dfe.getDefinedTermEditorInput(),
		                                dfe);
		                AbstractUtility.executeOperation(operation);
		            }
		        }
		    } catch (NotDefinedException e) {
		        MessagingUtils.error(getClass(), e);
		    }
		}
		return null;
	}

}
