/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.definedterm.operation;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.dialogs.MessageDialog;

import eu.etaxonomy.cdm.api.service.DeleteResult;
import eu.etaxonomy.cdm.api.service.ITermService;
import eu.etaxonomy.cdm.api.service.IVocabularyService;
import eu.etaxonomy.cdm.model.common.DefinedTermBase;
import eu.etaxonomy.cdm.model.common.TermBase;
import eu.etaxonomy.cdm.model.common.TermVocabulary;
import eu.etaxonomy.taxeditor.editor.definedterm.DefinedTermEditor;
import eu.etaxonomy.taxeditor.editor.definedterm.input.TermEditorInput;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.operation.AbstractPostTaxonOperation;
import eu.etaxonomy.taxeditor.operation.IPostOperationEnabled;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.StoreUtil;

/**
 * @author l.morris
 * @date 22 Dec 2011
 *
 */
public class DeleteTermBaseOperation extends AbstractPostTaxonOperation {

	private final TermEditorInput definedEditorInput;
	private final TermBase termBase;
	private DefinedTermEditor definedTermEditor;
	/**
	 * @param label
	 * @param undoContext
	 * @param postOperationEnabled
	 */
	public DeleteTermBaseOperation(String label,
			IUndoContext undoContext,
			TermBase termBase,
			TermEditorInput definedEditorInput,
			IPostOperationEnabled postOperationEnabled) {
		super(label, undoContext, postOperationEnabled);
		this.termBase = termBase;
		this.definedEditorInput = definedEditorInput;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {



		if (termBase instanceof TermVocabulary) {
			if (((TermVocabulary)termBase).getCreatedBy() == null) {
				IStatus status = new Status(IStatus.CANCEL, StoreUtil.getPluginId(), "This is a CDM system vocabulary");
				MessagingUtils.warningDialog("Cannot delete vocabulary", termBase, status);
				return status;
			}

			if (!((TermVocabulary)termBase).getTerms().isEmpty()) {
				IStatus status = new Status(IStatus.CANCEL, StoreUtil.getPluginId(), "Delete all terms from this vocaulary before deleting the vocabulary.");
				MessagingUtils.warningDialog("Vocabulary not empty", termBase, status);
				return status;
			}

			definedEditorInput.getVocabularies().remove(termBase);

			DeleteResult result =	CdmStore.getService(IVocabularyService.class).delete(termBase.getUuid());
			if (result.isError()){
				StringBuffer errorString = new StringBuffer();
				for (Exception e:result.getExceptions()){
					errorString.append(e.getMessage() + "\\n");
				}
				MessageDialog.openError(null, "Delete failed", errorString.toString());
			}

		} else if (termBase instanceof DefinedTermBase) {


			DefinedTermBase definedTermBase = (DefinedTermBase) termBase;

			if (((DefinedTermBase)termBase).getCreatedBy() == null) {
				IStatus status = new Status(IStatus.CANCEL, StoreUtil.getPluginId(), "This is a CDM system defined term");
				MessagingUtils.warningDialog("Cannot delete defined term", termBase, status);
				return status;
			}
			if(!definedTermBase.getIncludes().isEmpty()){
				IStatus status = new Status(IStatus.CANCEL, StoreUtil.getPluginId(), "This term includes other terms. Please delete the included terms before deleting this term.");
				MessagingUtils.warningDialog("Term has included terms", termBase, status);
				return status;
			}


			DefinedTermBase partOf = definedTermBase.getPartOf();
			if(partOf != null){
				partOf.removeIncludes(definedTermBase);
			}

			DefinedTermBase kindOf = definedTermBase.getKindOf();
			if(kindOf != null){
				definedTermBase.removeGeneralization(kindOf);
			}

			TermVocabulary vocabulary = definedTermBase.getVocabulary();
			if(vocabulary != null){
				vocabulary.removeTerm(definedTermBase);
			}

			DeleteResult result =	CdmStore.getService(ITermService.class).delete(termBase.getUuid());

			if (result.isError()){
				StringBuffer errorString = new StringBuffer();
				for (Exception e:result.getExceptions()){
					errorString.append(e.getMessage() + "\\n");
				}
				MessageDialog.openError(null, "Delete failed", errorString.toString());
			}
		}

		return postExecute(termBase);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		// TODO Auto-generated method stub
		return null;
	}

}
