/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.featuretree;

import java.util.Set;

import org.eclipse.jface.wizard.Wizard;

import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.cdm.model.description.FeatureTree;

/**
 * <p>AvailableFeaturesWizard class.</p>
 *
 * @author n.hoffmann
 * @created Aug 5, 2010
 * @version 1.0
 */
public class AvailableFeaturesWizard extends Wizard {
	
	private FeatureTree featureTree;

	private AvailableFeaturesWizardPage page;

	private Set<Feature> additionalFeatures;
	
	/**
	 * <p>Constructor for AvailableFeaturesWizard.</p>
	 *
	 * @param featureTree a {@link eu.etaxonomy.cdm.model.description.FeatureTree} object.
	 */
	public AvailableFeaturesWizard(FeatureTree featureTree){
		this.featureTree = featureTree;
	}
	
	/** {@inheritDoc} */
	@Override
	public void addPages() {
		page = new AvailableFeaturesWizardPage(featureTree);
		addPage(page);
	}
	
	/** {@inheritDoc} */
	@Override
	public boolean performFinish() {
		additionalFeatures = page.getSelectedFeatures();
		return additionalFeatures.size() > 0;
	}

	/**
	 * <p>Getter for the field <code>additionalFeatures</code>.</p>
	 *
	 * @return a {@link java.util.Set} object.
	 */
	public Set<Feature> getAdditionalFeatures() {
		return additionalFeatures;
	}
}
