/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.io;

import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.ui.progress.IProgressConstants;

import eu.etaxonomy.cdm.api.application.ICdmRepository;
import eu.etaxonomy.cdm.io.common.IIoConfigurator;

/**
 * <p>
 * Abstract AbstractIOHandler class.
 * </p>
 *
 * @author n.hoffmann
 * @created Sep 11, 2009
 * @version 1.0
 */
public abstract class AbstractIOManager<CONFIGURATOR extends IIoConfigurator> {

	protected ICdmRepository applicationConfiguration;

	public static enum TYPE {
		Jaxb, Tcs, Excel_Taxa, Endnote, Sdd, Abcd, SpecimenCdmExcel, Excel_Name, SpecimenSearch, Gbif
	}

	/**
	 * <p>
	 * Constructor for AbstractIOHandler.
	 * </p>
	 *
	 * @param applicationController
	 *            a
	 *            {@link eu.etaxonomy.cdm.api.application.CdmApplicationController}
	 *            object.
	 * @param <CONFIGURATOR>
	 *            a CONFIGURATOR object.
	 */
	protected AbstractIOManager(
			ICdmRepository applicationConfiguration) {
		this.applicationConfiguration = applicationConfiguration;
	}

	/**
	 * Starts the IO process
	 *
	 * @param configurator
	 *            a CONFIGURATOR object.
	 */
	public void run(final CONFIGURATOR configurator) {
	    // create job
	    Job job = createIOJob(configurator);
	    run(job);
	}

	public void run(Job job) {
	    // configure the job
	    job.setProperty(IProgressConstants.KEEP_PROPERTY, true);
	    job.setUser(true);
	    // schedule job
	    job.schedule();
	}

	/**
	 * <p>
	 * createIOJob
	 * </p>
	 *
	 * @param configurator
	 *            a CONFIGURATOR object.
	 * @return a {@link org.eclipse.core.runtime.jobs.Job} object.
	 */
	protected abstract Job createIOJob(CONFIGURATOR configurator);

}
