/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io.wizard;

import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportConfigurator;
import eu.etaxonomy.taxeditor.databaseAdmin.wizard.ListComponent;

/**
 *
 * @author pplitzner
 *
 */
public class AbcdImportConfiguratorWizardPage extends WizardPage {

	public static final String PAGE_NAME = "AbcdImportConfiguratorWizardPage";

	private Abcd206ImportConfigurator configurator;

	private List<URI> biocaseProvider = new ArrayList<>();

	private boolean isPreferencePage = false;

	protected AbcdImportConfiguratorWizardPage(String title, String description, Abcd206ImportConfigurator configurator) {
        super(PAGE_NAME);
        this.configurator = configurator;
        setTitle(title);
        setDescription(description);
    }

	protected AbcdImportConfiguratorWizardPage(String title, String description, Abcd206ImportConfigurator configurator, boolean isPreferencePage) {
		super(PAGE_NAME);
		this.configurator = configurator;
		setTitle(title);
		setDescription(description);
		this.isPreferencePage = isPreferencePage;
	}

	public static AbcdImportConfiguratorWizardPage createPage(Abcd206ImportConfigurator configurator){
		return new AbcdImportConfiguratorWizardPage("Configure import parameters",
				"Tooltips will explain parameters in more detail", configurator);
	}

	public static AbcdImportConfiguratorWizardPage createPreferencePage(Abcd206ImportConfigurator configurator){
        return new AbcdImportConfiguratorWizardPage("Configure import parameters",
                "Tooltips will explain parameters in more detail", configurator, true);
    }



	/** {@inheritDoc} */
	@Override
    public void createControl(Composite parent) {
		final Composite composite = new Composite(parent, SWT.NULL);

		GridLayout gridLayout = new GridLayout();
		composite.setLayout(gridLayout);
        if (isPreferencePage){
            ListComponent list = new ListComponent(composite, composite.getStyle());
        }

		Button checkBoxMediaSpecimen = new Button(composite, SWT.CHECK);
		checkBoxMediaSpecimen.setSelection(configurator.isAddMediaAsMediaSpecimen());
		checkBoxMediaSpecimen.setText("Import media as media specimen");
		checkBoxMediaSpecimen
				.setToolTipText("Any media attached to a ABCD unit will be imported as a sub derivative of the specimen created from this unit");
		checkBoxMediaSpecimen.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				configurator.setAddMediaAsMediaSpecimen(!configurator.isAddMediaAsMediaSpecimen());
			}
		});

		Button checkBoxIgnoreExisting = new Button(composite, SWT.CHECK);
		checkBoxIgnoreExisting.setSelection(configurator.isIgnoreImportOfExistingSpecimen());
		checkBoxIgnoreExisting.setText("Do not import existing specimens");
		checkBoxIgnoreExisting
		.setToolTipText("Specimens that have previously been imported will be ignored in this import");
		checkBoxIgnoreExisting.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				configurator.setIgnoreImportOfExistingSpecimen(!configurator.isIgnoreImportOfExistingSpecimen());
			}
		});

		Button checkBoxIgnoreAuthorship = new Button(composite, SWT.CHECK);
		checkBoxIgnoreAuthorship.setSelection(configurator.isIgnoreAuthorship());
		checkBoxIgnoreAuthorship.setText("Ignore Authorship for name matching");
		checkBoxIgnoreAuthorship
		.setToolTipText("Name matching with existing names will be done without "
				+ "the authorship part of the name");
		checkBoxIgnoreAuthorship.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				configurator.setIgnoreAuthorship(!configurator.isIgnoreAuthorship());
			}
		});

		Button checkBoxMapUnitIdToCatalogNumber = new Button(composite, SWT.CHECK);
		checkBoxMapUnitIdToCatalogNumber.setSelection(configurator.isMapUnitIdToCatalogNumber());
		checkBoxMapUnitIdToCatalogNumber.setText("Map UnitID to catalog number");
		checkBoxMapUnitIdToCatalogNumber
		.setToolTipText("The UnitID of every ABCD unit will be mapped the catalog number "
				+ "of the specimen");
		checkBoxMapUnitIdToCatalogNumber.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				configurator.setMapUnitIdToCatalogNumber(!configurator.isMapUnitIdToCatalogNumber());
			}
		});

		Button checkBoxMapUnitIdToAccessionNumber = new Button(composite, SWT.CHECK);
		checkBoxMapUnitIdToAccessionNumber.setSelection(configurator.isMapUnitIdToAccessionNumber());
		checkBoxMapUnitIdToAccessionNumber.setText("Map UnitID to accession number");
		checkBoxMapUnitIdToAccessionNumber
		.setToolTipText("The UnitID of every ABCD unit will be mapped the accession number "
				+ "of the specimen");
		checkBoxMapUnitIdToAccessionNumber.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				configurator.setMapUnitIdToAccessionNumber(!configurator.isMapUnitIdToAccessionNumber());
			}
		});

		Button checkBoxMapUnitIdToBarcode = new Button(composite, SWT.CHECK);
		checkBoxMapUnitIdToBarcode.setSelection(configurator.isMapUnitIdToBarcode());
		checkBoxMapUnitIdToBarcode.setText("Map UnitID to barcode");
		checkBoxMapUnitIdToBarcode
		.setToolTipText("The UnitID of every ABCD unit will be mapped the barcode "
				+ "of the specimen");
		checkBoxMapUnitIdToBarcode.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				configurator.setMapUnitIdToBarcode(!configurator.isMapUnitIdToBarcode());
			}
		});

		Button checkBoxRemoveCountry = new Button(composite, SWT.CHECK);
		checkBoxRemoveCountry.setSelection(configurator.isRemoveCountryFromLocalityText());
		checkBoxRemoveCountry.setText("Remove country from locality text");
		checkBoxRemoveCountry
		.setToolTipText("If the locality text contains information about the "
				+ "country which is additionally stored in other ABCD "
				+ "elements then it is removed from the locality text");
		checkBoxRemoveCountry.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				configurator.setRemoveCountryFromLocalityText(!configurator.isRemoveCountryFromLocalityText());
			}
		});

		Button checkBoxMoveToDefaultClassification = new Button(composite, SWT.CHECK);
		checkBoxMoveToDefaultClassification.setSelection(configurator.isMoveNewTaxaToDefaultClassification());
		checkBoxMoveToDefaultClassification.setText("Create new classification for new taxa");
		checkBoxMoveToDefaultClassification
		.setToolTipText("For taxa that do not exist in the data base "
				+ "a new classification will be created");
		checkBoxMoveToDefaultClassification.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				configurator.setRemoveCountryFromLocalityText(!configurator.isRemoveCountryFromLocalityText());
			}
		});

		setControl(composite);
	}

}
