/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io.wizard;

import java.io.File;
import java.net.URI;

import org.apache.log4j.Logger;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbench;

import eu.etaxonomy.cdm.database.DbSchemaValidation;
import eu.etaxonomy.cdm.io.common.IImportConfigurator.SOURCE_TYPE;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportConfigurator;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 *
 * @author n.hoffmann
 * @created Jun 16, 2010
 * @version 1.0
 */
public class AbcdImportWizard extends AbstractImportWizard<Abcd206ImportConfigurator> {

    private static final Logger logger = Logger.getLogger(AbcdImportWizard.class);

	private Abcd206ImportConfigurator configurator;
	private AbcdSourceSelectionPage dataSourcePage;
	private ClassificationChooserWizardPage classificationChooserWizardPage;

	/** {@inheritDoc} */
	@Override
	public Abcd206ImportConfigurator getConfigurator() {
		return configurator;
	}

	/** {@inheritDoc} */
	@Override
	public boolean performFinish() {
	    URI source = dataSourcePage.getUri();
	    configurator.setDbSchemaValidation(DbSchemaValidation.CREATE);

	    if(classificationChooserWizardPage.getClassification()!=null){
	        configurator.setClassificationUuid(classificationChooserWizardPage.getClassification().getUuid());
	    }

	    CdmStore.getImportManager().runMoniteredOperation(configurator, new File(source), SOURCE_TYPE.INPUTSTREAM);
	    
	    return true;

	}

	/** {@inheritDoc} */
	@Override
    public void init(IWorkbench workbench, IStructuredSelection selection) {
		super.init(workbench, selection);
		configurator =  CdmStore.getImportManager().AbcdConfigurator();
	}
	
	@Override
	protected void addConfiguratorPage() {
		AbcdImportConfiguratorWizardPage configuratorWizardPage = AbcdImportConfiguratorWizardPage.createPage(configurator);
		addPage(configuratorWizardPage);
	}

	/** {@inheritDoc} */
	@Override
	public void addPages() {
		super.addPages();

		classificationChooserWizardPage = ClassificationChooserWizardPage.createPage();

		dataSourcePage = ImportFromFileDataSourceWizardPage.XML();

		addPage(classificationChooserWizardPage);
		addPage(dataSourcePage);
	}
}
