/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io.wizard;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.IWizardContainer;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.swt.SWT;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IEditorReference;
import org.eclipse.ui.IImportWizard;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;

import eu.etaxonomy.cdm.io.common.IImportConfigurator;
import eu.etaxonomy.cdm.io.common.IIoConfigurator;

/**
 * @author n.hoffmann
 * @created 24.06.2009
 * @version 1.0
 */
public abstract class AbstractImportWizard<CONFIG extends IIoConfigurator> extends Wizard implements IImportWizard {

	protected final String CONFIGURATION_PAGE = "CONFIGURATION_PAGE";

	private GenericConfiguratorWizardPage pageConfiguration;
	private NomenclaturalCodeWizardPage pageNomenclaturalCode;

	private IWorkbench workbench;

	private IStructuredSelection selection;

	/** {@inheritDoc} */
	@Override
	public void addPages() {
		super.addPages();
		
		addConfiguratorPage();

		pageNomenclaturalCode = new NomenclaturalCodeWizardPage((IImportConfigurator)getConfigurator());
		this.addPage(pageNomenclaturalCode);
	}
	
	protected void addConfiguratorPage(){
		pageConfiguration = GenericConfiguratorWizardPage.Import(CONFIGURATION_PAGE, getConfigurator());
		this.addPage(pageConfiguration);
	}

	@Override
	public void setContainer(IWizardContainer wizardContainer) {
		if(existUnsavedEditors()){
		    MessageDialog.open(MessageDialog.WARNING, getShell(), "Unsaved editors", "Please save all open editors before executing " +
		            "an import operation. The import operation will be cancelled", SWT.NONE);
		}
		else{
		    super.setContainer(wizardContainer);
		}
	}

	@Override
	public void init(IWorkbench workbench, IStructuredSelection selection) {
		this.setWorkbench(workbench);
		this.setSelection(selection);
	}

	protected boolean existUnsavedEditors(){
		IWorkbenchPage activePage = getWorkbench().getActiveWorkbenchWindow().getActivePage();
		if(activePage != null){
			for (IEditorReference reference : activePage.getEditorReferences()) {
				IEditorPart editor = reference.getEditor(false);
				if(editor.isDirty()){
					return true;
				}
			}
		}
		return false;
	}

	@Override
	public boolean canFinish() {
	    return !existUnsavedEditors() && super.canFinish();
	}

	public abstract CONFIG getConfigurator();

	public void setSelection(IStructuredSelection selection) {
		this.selection = selection;
	}

	public IStructuredSelection getSelection() {
		return selection;
	}

	public void setWorkbench(IWorkbench workbench) {
		this.workbench = workbench;
	}

	public IWorkbench getWorkbench() {
		return workbench;
	}
}
