/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io.wizard;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.URI;

import org.apache.commons.io.IOUtils;
import org.apache.log4j.Logger;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.TreeSelection;
import org.eclipse.ui.IWorkbench;

import eu.etaxonomy.cdm.database.DbSchemaValidation;
import eu.etaxonomy.cdm.io.common.IImportConfigurator.SOURCE_TYPE;
import eu.etaxonomy.cdm.io.excel.taxa.NormalExplicitImportConfigurator;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.store.CdmStore;


/**
 * <p>ExcelNormalExplicitTaxaImportWizard class.</p>
 *
 * @author n.hoffmann
 * @created Sep 22, 2009
 * @version 1.0
 */
public class ExcelNormalExplicitTaxaImportWizard extends AbstractImportWizard<NormalExplicitImportConfigurator>{

	private NormalExplicitImportConfigurator configurator;

	private ImportFromFileDataSourceWizardPage dataSourcePage;
	private static final Logger logger = Logger.getLogger(ExcelNormalExplicitTaxaImportWizard.class);

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.io.wizard.AbstractImportWizard#getConfigurator()
	 */
	/** {@inheritDoc} */
	@Override
	public NormalExplicitImportConfigurator getConfigurator() {
		return configurator;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	/** {@inheritDoc} */
	@Override
	public boolean performFinish() {
		URI source = dataSourcePage.getUri();
		configurator.setSource(source);
		configurator.setDbSchemaValidation(DbSchemaValidation.CREATE);
		File file = new File(source);
		FileInputStream fis = null;

		try {
			fis = new FileInputStream(file);
		} catch (FileNotFoundException e) {
			logger.error("Error while reading file" + source.toString());
		}
		try {
            configurator.setStream(IOUtils.toByteArray(fis));
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
	    Job job = CdmStore.getImportManager().createIOServiceJob(configurator,file , SOURCE_TYPE.INPUTSTREAM);
	    CdmStore.getImportManager().run(job);

		return true;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
	 */
	/** {@inheritDoc} */
	@Override
    public void init(IWorkbench workbench, IStructuredSelection selection) {
		super.init(workbench, selection);
		configurator =  CdmStore.getImportManager().NormalExplicitConfigurator();
		if (selection instanceof TreeSelection && !selection.isEmpty()){
			TaxonNode node = (TaxonNode)selection.getFirstElement();
			configurator.setParentUUID(node.getTaxon().getUuid());
			configurator.setClassificationUuid(node.getClassification().getUuid());
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.io.wizard.AbstractImportWizard#addPages()
	 */
	/** {@inheritDoc} */
	@Override
	public void addPages() {
		super.addPages();

		dataSourcePage = new ImportFromFileDataSourceWizardPage("Choose NormalExplicit",
				"Please choose an xls file in the NormalExplicit format.", new String[]{"*.xlsx", "*.xls", "*.*"});
		addPage(dataSourcePage);
	}
}
