/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.io.wizard;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.UUID;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.service.IClassificationService;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.taxeditor.datasource.CdmDataSourceRepository;
import eu.etaxonomy.taxeditor.remoting.source.CdmRemoteSourceException;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>
 * ExportToFileDestinationWizardPage class.
 * </p>
 *
 * @author n.hoffmann
 * @created 15.06.2009
 * @version 1.0
 */
public class ExportToFileDestinationWizardPage extends WizardPage implements SelectionListener {

	/** Constant <code>DATE_FORMAT_NOW="yyyyMMddHHmm"</code> */
	public static final String DATE_FORMAT_NOW = "yyyyMMddHHmm";

	/** Constant <code>JAXB_EXPORT="JAXB_EXPORT"</code> */
	public static final String JAXB_EXPORT = "JAXB_EXPORT";

	/** Constant <code>TCS_EXPORT="TCS_EXPORT"</code> */
	public static final String TCS_EXPORT = "TCS_EXPORT";

	/** Constant <code>SDD_EXPORT="SDD_EXPORT"</code> */
	public static final String SDD_EXPORT = "SDD_EXPORT";

	public static final String DWCA_EXPORT = "DWCA_EXPORT";
	public static final String OUTPUT_MODEL_EXPORT = "OUTPUT_MODEL_EXPORT";
	public static final String CSV_EXPORT = "CSV_EXPORT";
	public static final String CSV_NAME_EXPORT = "CSV_NAME_EXPORT";

	public static final String XML = "xml";

	public static final String CSV = "csv";



	public static final String ZIP = "zip";

    private static boolean csvExport = false;

    private static boolean csvNameExport = false;

	private static String CSV_PRINT_EXPORT ="CSV_PRINT_EXPORT";

	private static boolean csvPrintExport = false;

	private static boolean outputModelExport = false;

	private DirectoryDialog folderDialog;
	private Text text_exportFileName;

	private Text text_folder;

	private final String type;

	private final String extension;

    private Combo classificationSelectionCombo;

    private List<Classification> classifications;

    private Classification selectedClassification;

	/**
	 * @param pageName
	 * @param selection
	 */
	protected ExportToFileDestinationWizardPage(String pageName, String type,
			String title, String description, String extension) {
		super(pageName);

		this.type = type;
		this.extension = extension;
		this.setTitle(title);
		this.setDescription(description);
	}

	/**
	 * <p>
	 * Jaxb
	 * </p>
	 *
	 * @return a
	 *         {@link eu.etaxonomy.taxeditor.io.wizard.ExportToFileDestinationWizardPage}
	 *         object.
	 */
	public static ExportToFileDestinationWizardPage Jaxb() {
		return new ExportToFileDestinationWizardPage(
				JAXB_EXPORT,
				"jaxb",
				"JAXB Export",
				"Exports the contents of the currently selected database into the cdm jaxb format.",
				XML);
	}

	/**
	 * <p>
	 * Tcs
	 * </p>
	 *
	 * @return a
	 *         {@link eu.etaxonomy.taxeditor.io.wizard.ExportToFileDestinationWizardPage}
	 *         object.
	 */
	public static ExportToFileDestinationWizardPage Tcs() {
		return new ExportToFileDestinationWizardPage(
				TCS_EXPORT,
				"tcs",
				"Tcs Export",
				"Export the contents of the currently selected database into TCS format.",
				XML);
	}

	/**
	 * <p>
	 * Sdd
	 * </p>
	 *
	 * @return a
	 *         {@link eu.etaxonomy.taxeditor.io.wizard.ExportToFileDestinationWizardPage}
	 *         object.
	 */
	public static ExportToFileDestinationWizardPage Sdd() {
		return new ExportToFileDestinationWizardPage(
				SDD_EXPORT,
				"sdd",
				"Sdd Export",
				"Export the contents of the currently selected database into SDD format.",
				XML);
	}

	/**
	 * @return
	 */
	public static ExportToFileDestinationWizardPage Dwca() {
		return new ExportToFileDestinationWizardPage(
				DWCA_EXPORT,
				"dwca",
				"DwC-Archive Export",
				"Export the contents of the currently selected database into Darwin Core Archive format.",
				ZIP);
	}

	/**
     * @return
     */
    public static ExportToFileDestinationWizardPage OutputModel() {
        outputModelExport = true;
        return new ExportToFileDestinationWizardPage(
                OUTPUT_MODEL_EXPORT,
                "output model",
                "Output Model Export",
                "Export the contents of the currently selected database into the output model format.",
                CSV);
    }


    /**
     * @return
     */
    public static ExportToFileDestinationWizardPage Csv() {
        csvExport = true;
        return new ExportToFileDestinationWizardPage(
                CSV_EXPORT,
                "csv",
                "CSV Export",
                "Export the contents of the currently selected database into Comma Separated Value format.",
                CSV);
    }

    /**
     * @return
     */
    public static ExportToFileDestinationWizardPage CsvNames() {
    	csvNameExport = true;
        return new ExportToFileDestinationWizardPage(
                CSV_NAME_EXPORT,
                "csvNames",
                "CSV Name Export",
                "Export the names of the currently selected database into Semicolon Separated Value format.",
                CSV);
    }

    /**
     * @return
     */
    public static ExportToFileDestinationWizardPage CsvPrint() {
    	csvPrintExport  = true;
        return new ExportToFileDestinationWizardPage(
                CSV_PRINT_EXPORT,
                "csvPrint",
                "CSV Print Export",
                "Export the content of the currently selected database into Semicolon Separated Value format.",
                CSV);
    }

	/*
	 * (non-Javadoc)
	 *
	 * @see
	 * org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets
	 * .Composite)
	 */
	/** {@inheritDoc} */
	@Override
    public void createControl(Composite parent) {

		setPageComplete(false);

		Composite composite = new Composite(parent, SWT.NONE);
		GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 3;
		composite.setLayout(gridLayout);
		if(classifications == null){
			classifications = CdmStore.getService(IClassificationService.class).list(null, null, null, null, null);
			Collections.sort(classifications, new Comparator<Classification>() {

                @Override
                public int compare(Classification o1, Classification o2) {
                    if (o1.equals(o2)){
                        return 0;
                    }
                    int result = o1.getTitleCache().compareTo(o2.getTitleCache());
                    if (result == 0){
                        return o1.getUuid().compareTo(o2.getUuid());
                    }
                    return result;
                }
            });

			selectedClassification = classifications.iterator().next();
		}


		if(csvExport || csvPrintExport || outputModelExport){
		    Label comboBoxLabel = new Label(composite, SWT.NONE);
		    comboBoxLabel.setText("Classification");

		    createClassificationSelectionCombo(composite);
		    classificationSelectionCombo.setLayoutData(new GridData(SWT.FILL, SWT.FILL,
		                true, false, 2, 1));
		}
		if (!outputModelExport){
		    Label fileLabel = new Label(composite, SWT.NONE);
	        fileLabel.setText("File");
    		text_exportFileName = new Text(composite, SWT.BORDER);
    		text_exportFileName.setText(generateFilename());
    		text_exportFileName.setLayoutData(new GridData(SWT.FILL, SWT.FILL,
    				true, false, 2, 1));
		}

		Label folderLabel = new Label(composite, SWT.NONE);
		folderLabel.setText("Folder");

		folderDialog = new DirectoryDialog(parent.getShell());

		text_folder = new Text(composite, SWT.BORDER);
		text_folder.setEditable(false);
		text_folder.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true,
				false));

		Button button = new Button(composite, SWT.PUSH);
		button.setText("Browse...");

		button.addSelectionListener(new SelectionAdapter() {
			/*
			 * (non-Javadoc)
			 *
			 * @see
			 * org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse
			 * .swt.events.SelectionEvent)
			 */
			@Override
			public void widgetSelected(SelectionEvent e) {
				super.widgetSelected(e);
				String path = folderDialog.open();
				if (path != null) { // a folder was selected
					text_folder.setText(path);
					setPageComplete(true);
				}
			}
		});

		// make the composite the wizard pages control
		setControl(composite);
	}

	protected String generateFilename() {
		StringBuffer buffer = new StringBuffer();

		Calendar cal = Calendar.getInstance();
		SimpleDateFormat sdf = new SimpleDateFormat(DATE_FORMAT_NOW);
		buffer.append(sdf.format(cal.getTime()));

		buffer.append("-");

		buffer.append(type + "_export-");
		try {
			buffer.append(CdmDataSourceRepository.getCurrentCdmSource());
		} catch (CdmRemoteSourceException e) {
			buffer.append("Unknown");
		}

		buffer.append(".");
		buffer.append(extension);

		return buffer.toString();
	}

	/**
	 * <p>
	 * getExportFileName
	 * </p>
	 *
	 * @return the exportFileName
	 */
	public String getExportFileName() {
		return text_exportFileName.getText();
	}

	/**
	 * <p>
	 * getFolderText
	 * </p>
	 *
	 * @return the folderText
	 */
	public String getFolderText() {
		return text_folder.getText();
	}

	private Control createClassificationSelectionCombo(Composite parent){
//		classifications = CdmStore.getTaxonTreeService().list(null, null, null, null, null);

		Composite classificationSelection = new Composite(parent, SWT.NULL);
		classificationSelection.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));

		GridLayout layout = new GridLayout();
		classificationSelection.setLayout(layout);

		Label label = new Label(classificationSelection, SWT.NULL);
		// TODO not working is not really true but leave it here to remind everyone that this is under construction
		label.setText("Select Classification");
		classificationSelectionCombo = new Combo(classificationSelection, SWT.BORDER | SWT.READ_ONLY);
		classificationSelectionCombo.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, true));

		for(Classification tree : classifications){
			classificationSelectionCombo.add(tree.getName().getText(), classifications.indexOf(tree));

		}

		classificationSelectionCombo.select(classifications.indexOf(selectedClassification));

		// TODO remember last selection
		classificationSelectionCombo.addSelectionListener(this);



		return classificationSelection;
	}

	public Combo getCombo(){
	    return classificationSelectionCombo;
	}

	@Override
	public void widgetSelected(SelectionEvent e) {
		selectedClassification = classifications.get(classificationSelectionCombo.getSelectionIndex());

	}

	@Override
	public void widgetDefaultSelected(SelectionEvent e) {
		//not needed here

	}

	public UUID getSelectedClassificationUUID() {

		return selectedClassification.getUuid();
	}

}
