/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io.wizard;

import java.io.File;
import java.net.URI;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.common.CdmUtils;

/**
 *
 * @author n.hoffmann
 * @created 04.08.2009
 * @version 1.0
 */
public class ImportFromFileDataSourceWizardPage extends AbcdSourceSelectionPage {

	/** Constant <code>PAGE_NAME="CdmXmlDataSourceWizardPage"</code> */
	public static final String PAGE_NAME = "CdmXmlDataSourceWizardPage";

	private String[] extensions = {"*.xml"};

	private FileDialog fileDialog;



	protected ImportFromFileDataSourceWizardPage(String title, String description, String[] extensions) {
		super(PAGE_NAME);

		setTitle(title);

		setDescription(description);

		this.extensions = extensions;
	}

	protected static ImportFromFileDataSourceWizardPage XML(){
		return new ImportFromFileDataSourceWizardPage("Xml File", "Select XML file.", new String[]{"*.xml","*.*"});
	}

	/** {@inheritDoc} */
	@Override
    public void createControl(Composite parent) {
		final Composite composite = new Composite(parent, SWT.NULL);

		setPageComplete(false);

		GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 3;
		composite.setLayout(gridLayout);

		Label folderLabel = new Label(composite, SWT.NONE);
		folderLabel.setText("File");

		fileDialog = new FileDialog(parent.getShell());

		fileDialog.setFilterExtensions(extensions);

		text_source = new Text(composite, SWT.BORDER);
		text_source.setEditable(false);
		text_source.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));


		Button button = new Button(composite, SWT.PUSH);
		button.setText("Browse...");

		button.addSelectionListener(new SelectionAdapter(){

			@Override
			public void widgetSelected(SelectionEvent e) {
				String path = fileDialog.open();
				if(path!=null){
				    text_source.setText(path);
				    setPageComplete(true);
				}
			}

		});


		setControl(composite);
	}

	public File getFile() {
		return new File(text_source.getText());
	}

	@Override
    public URI getUri() {
		return getFile().toURI();
	}

	@Override
	public boolean isPageComplete() {
		return CdmUtils.isNotBlank(text_source.getText());
	}

}
