/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io.wizard;

import java.net.URI;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbench;

import eu.etaxonomy.cdm.database.DbSchemaValidation;
import eu.etaxonomy.cdm.io.jaxb.JaxbImportConfigurator;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>JaxbImportWizard class.</p>
 *
 * @author n.hoffmann
 * @created 15.06.2009
 * @version 1.0
 */
public class JaxbImportWizard extends AbstractImportWizard<JaxbImportConfigurator> {

	private JaxbImportConfigurator configurator;
	
	private ImportFromFileDataSourceWizardPage dataSourcePage;
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.io.wizard.AbstractImportWizard#getConfigurator()
	 */
	/** {@inheritDoc} */
	@Override
	public JaxbImportConfigurator getConfigurator() {
		return configurator;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	/** {@inheritDoc} */
	@Override
	public boolean performFinish() {
		URI source = dataSourcePage.getUri();
		configurator.setSource(source);
		configurator.setDbSchemaValidation(DbSchemaValidation.CREATE);
		
		CdmStore.getImportManager().run(configurator);
		
		return true;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
	 */
	/** {@inheritDoc} */
	public void init(IWorkbench workbench, IStructuredSelection selection) {
		super.init(workbench, selection);
		configurator =  CdmStore.getImportManager().JaxbConfigurator();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.io.wizard.AbstractImportWizard#addPages()
	 */
	/** {@inheritDoc} */
	@Override
	public void addPages() {
		super.addPages();
		
		dataSourcePage = new ImportFromFileDataSourceWizardPage("Choose File", 
				"Please choose an XML file in the cdm JAXB format.", new String[]{"*.xml"});
		addPage(dataSourcePage);
	}
}
