/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io.wizard;

import java.io.File;

import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.progress.IProgressConstants;

import eu.etaxonomy.cdm.io.sdd.out.SDDExportConfigurator;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>SddExportWizard class.</p>
 *
 * @author n.hoffmann
 * @created Jun 16, 2010
 * @version 1.0
 */
public class SddExportWizard extends AbstractExportWizard<SDDExportConfigurator> {

	private ExportToFileDestinationWizardPage page;

	private SDDExportConfigurator configurator;

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.io.wizard.AbstractExportWizard#getConfigurator()
	 */
	/** {@inheritDoc} */
	@Override
	public SDDExportConfigurator getConfigurator() {
		return configurator;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	/** {@inheritDoc} */
	@Override
	public boolean performFinish() {
	    File file = new File(page.getFolderText() + File.separator + page.getExportFileName());
        // create job
        Job job = CdmStore.getExportManager().createIOServiceJob(configurator, file);
        // configure the job
        job.setProperty(IProgressConstants.KEEP_PROPERTY, true);
        job.setUser(true);
        // schedule job
        job.schedule();
	    
	    return true;
	}

	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.io.wizard.AbstractExportWizard#addPages()
	 */
	/** {@inheritDoc} */
	@Override
	public void addPages() {
		super.addPages();

		page = ExportToFileDestinationWizardPage.Sdd();
		addPage(page);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
	 */
	/** {@inheritDoc} */
	@Override
    public void init(IWorkbench workbench, IStructuredSelection selection) {
		this.setWindowTitle("SDD Export");
		this.configurator = CdmStore.getExportManager().SddConfigurator();
	}
}
