/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io.wizard;

import java.io.File;
import java.net.URI;

import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbench;

import eu.etaxonomy.cdm.database.DbSchemaValidation;
import eu.etaxonomy.cdm.io.common.IImportConfigurator.SOURCE_TYPE;
import eu.etaxonomy.cdm.io.sdd.in.SDDImportConfigurator;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>SddImportWizard class.</p>
 *
 * @author n.hoffmann
 * @created Jun 16, 2010
 * @version 1.0
 */
public class SddImportWizard extends AbstractImportWizard<SDDImportConfigurator> {

	private SDDImportConfigurator configurator;

	private ImportFromFileDataSourceWizardPage dataSourcePage;

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.io.wizard.AbstractImportWizard#getConfigurator()
	 */
	/** {@inheritDoc} */
	@Override
	public SDDImportConfigurator getConfigurator() {
		return configurator;
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#addPage(org.eclipse.jface.wizard.IWizardPage)
	 */
	/** {@inheritDoc} */
	@Override
	public void addPages() {
		super.addPages();

		dataSourcePage = new ImportFromFileDataSourceWizardPage("Choose File",
				"Please choose an XML file in the SDD format.", new String[]{"*.xml", "*.sdd"});
		addPage(dataSourcePage);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	/** {@inheritDoc} */
	@Override
	public boolean performFinish() {
		URI source = dataSourcePage.getUri();
		configurator.setSource(source);
		configurator.setDbSchemaValidation(DbSchemaValidation.CREATE);
		Job job = CdmStore.getImportManager().createIOServiceJob(configurator, new File(source), SOURCE_TYPE.URI);
		CdmStore.getImportManager().run(job);
		
		return true;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
	 */
	/** {@inheritDoc} */
	@Override
    public void init(IWorkbench workbench, IStructuredSelection selection) {
		super.init(workbench, selection);
		configurator =  CdmStore.getImportManager().SddConfigurator();
	}
}
