/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.io.wizard;

import java.io.File;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbench;

import eu.etaxonomy.cdm.io.tcsxml.out.TcsXmlExportConfigurator;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>
 * TcsExportWizard class.
 * </p>
 * 
 * @author n.hoffmann
 * @created 15.06.2009
 * @version 1.0
 */
public class TcsExportWizard extends
		AbstractExportWizard<TcsXmlExportConfigurator> {
	private TcsXmlExportConfigurator configurator;
	private ExportToFileDestinationWizardPage page;

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	/** {@inheritDoc} */
	@Override
	public boolean performFinish() {
		String urlString = page.getFolderText() + File.separator
				+ page.getExportFileName();

		configurator.setDestination(new File(urlString));

		CdmStore.getExportManager().run(configurator);

		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IWorkbenchWizard#init(org.eclipse.ui.IWorkbench,
	 * org.eclipse.jface.viewers.IStructuredSelection)
	 */
	/** {@inheritDoc} */
	public void init(IWorkbench workbench, IStructuredSelection selection) {
		configurator = TcsXmlExportConfigurator.NewInstance(null, null);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see eu.etaxonomy.taxeditor.io.AbstractExportWizard#getConfigurator()
	 */
	/** {@inheritDoc} */
	@Override
	public TcsXmlExportConfigurator getConfigurator() {
		return configurator;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see eu.etaxonomy.taxeditor.io.AbstractExportWizard#addPages()
	 */
	/** {@inheritDoc} */
	@Override
	public void addPages() {
		super.addPages();

		page = ExportToFileDestinationWizardPage.Tcs();
		addPage(page);
	}

}
