/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.newWizard;

import java.util.List;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.ListViewer;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.application.ICdmRepository;
import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.ext.ipni.IIpniService;
import eu.etaxonomy.cdm.ext.ipni.IpniService;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.LayoutConstants;

/**
 * <p>ExternalReferenceServiceWizardPage class.</p>
 *
 * @author n.hoffmann
 * @created Sep 16, 2010
 * @version 1.0
 */
public class ExternalReferenceServiceWizardPage extends WizardPage implements SelectionListener, ISelectionChangedListener {

	private ConversationHolder conversation;
	private CdmFormFactory formFactory;
	private Reference entity;
	private Composite control;
	private ListViewer viewer;
	
	private IIpniService ipniService;
	private Text text_query;
	private Button button_search;

	/**
	 * <p>Constructor for ExternalReferenceServiceWizardPage.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param entity a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
	 */
	protected ExternalReferenceServiceWizardPage(CdmFormFactory formFactory, ConversationHolder conversation, Reference entity) {
		super("ExternalReferenceServiceWizardPage");
		this.formFactory = formFactory;
		this.entity = entity;
		this.conversation = conversation;
		ipniService = new IpniService();
		
		setDescription("Query IPNI service for references");
	}
	
	/** {@inheritDoc} */
	@Override
	public void createControl(Composite parent) {
		control = formFactory.createComposite(parent);
		
		control.setLayout(LayoutConstants.LAYOUT(2, false));
		
		text_query = new Text(control, SWT.SINGLE | SWT.BORDER);
		text_query.setLayoutData(LayoutConstants.FILL_HORIZONTALLY());
		
		button_search = new Button(control, SWT.PUSH);
		button_search.setLayoutData(LayoutConstants.RIGHT());
		button_search.setText("Search");
		
		button_search.addSelectionListener(this);
		
		viewer = new ListViewer(control);
		viewer.getControl().setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2,1));
		
		viewer.setContentProvider(new IStructuredContentProvider(){

			@Override
			public Object[] getElements(Object inputElement) {
				if(inputElement instanceof List){
					return ((List) inputElement).toArray();
				}
				return null;
			}
			
			@Override
			public void inputChanged(Viewer viewer, Object oldInput,
					Object newInput) {}
			
			@Override
			public void dispose() {}
			
		});
		viewer.setLabelProvider(new LabelProvider(){
			@Override
			public String getText(Object element) {
				if(element instanceof Reference){
					return ((Reference) element).getTitleCache();
				}
				return "Element is not a reference";
			}
		});
		
		viewer.addSelectionChangedListener(this);
		
		setControl(control);
	}

	/** {@inheritDoc} */
	@Override
	public void widgetSelected(SelectionEvent e) {
		String query = text_query.getText();
		List<Reference> publications = ipniService.getPublications(query, null, (ICdmRepository) CdmStore.getCurrentApplicationConfiguration(), null);
		viewer.setInput(publications);
	}

	/** {@inheritDoc} */
	@Override
	public void widgetDefaultSelected(SelectionEvent e) {}

	/** {@inheritDoc} */
	@Override
	public void selectionChanged(SelectionChangedEvent event) {
		IStructuredSelection selection = (IStructuredSelection) viewer.getSelection();
		
		Reference selectedReference = (Reference) selection.getFirstElement();
		if(selectedReference != null){
			((AbstractNewEntityWizard) getWizard()).setEntity(selectedReference);
		}
	}
	
	
}
