/**
 *
 */
package eu.etaxonomy.taxeditor.newWizard;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.UUID;

import org.apache.commons.lang.StringUtils;

import eu.etaxonomy.cdm.api.application.CdmApplicationState;
import eu.etaxonomy.cdm.api.application.CdmChangeEvent;
import eu.etaxonomy.cdm.api.application.CdmChangeEvent.Action;
import eu.etaxonomy.cdm.api.service.IClassificationService;
import eu.etaxonomy.cdm.api.service.ITaxonNodeService;
import eu.etaxonomy.cdm.api.service.ITaxonService;
import eu.etaxonomy.cdm.api.service.UpdateResult;
import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.ITaxonTreeNode;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.cdm.persistence.dto.MergeResult;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.section.classification.TaxonNodeDetailElement;
import eu.etaxonomy.taxeditor.ui.section.classification.TaxonNodeWizardPage;

/**
 * <p>NewTaxonNodeWizard class.</p>
 *
 * @author n.hoffmann
 * @created Sep 15, 2009
 * @version 1.0
 */
public class NewTaxonNodeWizard extends AbstractNewEntityWizard<ITaxonTreeNode>{

    private TaxonNodeWizardPage taxonNodePage;
    private boolean openEmptyEditor;
    private UUID generatedTaxonNodeUuid;
    private IWizardPageListener wizardPageListener;

    @Override
    public void addPages() {
        taxonNodePage = new TaxonNodeWizardPage(formFactory, getConversationHolder(), getEntity(), wizardPageListener, true);

        addPage(taxonNodePage);
    }

    @Override
    protected void saveEntity() {
        Taxon taxon = taxonNodePage.createTaxon();
        if(taxon == null || StringUtils.isEmpty(taxon.getName().getFullTitleCache())){
            openEmptyEditor = true;
        }else{
            getConversationHolder().bind();
            ITaxonTreeNode parent = getParentTreeNode();
            Reference sec = taxon.getSec();
            taxon.setSec(null);
            try{
            	UUID parentNodeUuid;
            	if(parent instanceof Classification){
            	    parentNodeUuid = ((Classification) parent).getRootNode().getUuid();
            	}
            	else{
            	    parentNodeUuid = parent.getUuid();
            	}
            	UpdateResult result;
            	
            	if (taxon.getId() == 0){
            		result = CdmStore.getService(ITaxonNodeService.class).createNewTaxonNode(parentNodeUuid, taxon, parent.getReference(), parent.getMicroReference());
            	}else{
            		result = CdmStore.getService(ITaxonNodeService.class).createNewTaxonNode(parentNodeUuid, taxon.getUuid(), parent.getReference(), parent.getMicroReference());
            	}
            	if (result.isOk()){
	             	generatedTaxonNodeUuid = result.getCdmEntity().getUuid();
	             	TaxonNode taxonNode = CdmStore.getService(ITaxonNodeService.class).load(generatedTaxonNodeUuid);
	             	taxonNode.getTaxon().setSec(sec);
	             	CdmStore.getService(ITaxonNodeService.class).merge(taxonNode, true);
	                 Set<CdmBase> affectedObjects = new HashSet<CdmBase>();
	                 if (result.getUpdatedObjects().iterator().hasNext()){
	                 	TaxonNode parentNode = (TaxonNode)result.getUpdatedObjects().iterator().next();
	                 	if(parentNode.getParent() == null) {
	                         affectedObjects.add(taxonNode.getClassification());
	                     }
	                 	affectedObjects.add(parentNode);
	                 }
	                 CdmApplicationState.getCurrentDataChangeService()
	                         .fireChangeEvent(new CdmChangeEvent(Action.Create, affectedObjects, NewTaxonNodeWizard.class), true);
	                 
	             }else{
	                 if (!result.isOk()){
	                     if (!result.getExceptions().isEmpty()){
	                         MessagingUtils.error(getClass(), "Taxon could not be created", result.getExceptions().iterator().next());
	                     }else{
	                         MessagingUtils.warn(getClass(), "Taxon could not be created");
	                     }
	                 }
	             }
          }catch(IllegalArgumentException e){
                MessagingUtils.warningDialog("Taxon already exists in classfication", getClass(), e.getMessage());
            }
        }
    }

    @Override
    protected ITaxonTreeNode createNewEntity() {
        if(getSelection() != null){
            Object selectedObject = getSelection().getFirstElement();
            if(selectedObject instanceof ITaxonTreeNode){
                ITaxonTreeNode treeNode = (ITaxonTreeNode) selectedObject;

                if(treeNode instanceof Classification){
                    return CdmStore.getService(IClassificationService.class).load(treeNode.getUuid());
                }
                else if(treeNode instanceof TaxonNode){
                	
                	TaxonNode node =  CdmStore.getService(ITaxonNodeService.class).load(treeNode.getUuid());
                	Taxon taxon = (Taxon) CdmStore.getService(ITaxonService.class).load(node.getTaxon().getUuid());
                    return node;
                }
            }
        }

        return null;
    }

    /**
     * <p>openInEditor</p>
     *
     * @return a boolean.
     */
    public boolean openInEditor(){
        return taxonNodePage.openInEditor();
    }

    /**
     * <p>openEmpty</p>
     *
     * @return a boolean.
     */
    public boolean openEmpty(){
        return openInEditor() && openEmptyEditor;
    }

    /**
     * <p>getTaxonNode</p>
     *
     * @return a {@link eu.etaxonomy.cdm.model.taxon.TaxonNode} object.
     */
    public TaxonNode getTaxonNode(){
        if(generatedTaxonNodeUuid != null){
            return CdmStore.getService(ITaxonNodeService.class).load(generatedTaxonNodeUuid);
        }
        return null;
    }

    public ITaxonTreeNode getParentTreeNode(){
        return taxonNodePage.getParentTreeNode();
    }

    @Override
    protected String getEntityName() {
        return "Taxon";
    }

    public void addWizardPageListener(IWizardPageListener wizardPageListener){
        this.wizardPageListener = wizardPageListener;
    }

}
