/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.operation;

import java.util.Set;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.AbstractOperation;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.api.application.CdmApplicationState;
import eu.etaxonomy.cdm.api.application.CdmChangeEvent;
import eu.etaxonomy.cdm.api.application.CdmChangeEvent.Action;
import eu.etaxonomy.cdm.api.service.UpdateResult;
import eu.etaxonomy.cdm.model.common.CdmBase;

/**
 * @author cmathew
 * @date 16 Jun 2015
 *
 */
public abstract class RemotingCdmOperation extends AbstractOperation {

    private final Object source;
    private final Action action;
    private final boolean async;
    protected Class entityType;

    public RemotingCdmOperation(String label, Action action, Object source, boolean async) {
        super(label);
        this.source = source;
        this.action = action;
        this.async = async;
    }

    /* (non-Javadoc)
     * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
     */
    @Override
    public IStatus execute(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {

       boolean success = doExecute(monitor, info);
       postExecute(success);
       return onComplete(success);
    }

    protected abstract boolean doExecute(IProgressMonitor monitor, IAdaptable info);

    protected void postExecute(boolean success) {}

    protected abstract IStatus onComplete(boolean success);

    protected void fireDataChangeEvent(Set<CdmBase> changedObjects) {
        if(changedObjects != null && !changedObjects.isEmpty()) {
            CdmApplicationState.getCurrentDataChangeService().fireChangeEvent(new CdmChangeEvent(action, changedObjects, source.getClass()), async);
        }
    }

    protected void fireDataChangeEvent(UpdateResult updateResult) {
        Set<CdmBase> updatedObjects = updateResult.getUpdatedObjects();
        CdmApplicationState.getCurrentDataChangeService()
            .fireChangeEvent(new CdmChangeEvent(action, updatedObjects, source.getClass(), entityType), async);
    }

    protected void fireDataChangeEvent(CdmBase cdmBase) {
        if(cdmBase != null) {
            CdmApplicationState.getCurrentDataChangeService().fireChangeEvent(new CdmChangeEvent(action, cdmBase, source.getClass()), async);
        }
    }

    /* (non-Javadoc)
     * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
     */
    @Override
    public IStatus redo(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
        // TODO Auto-generated method stub
        return null;
    }

    /* (non-Javadoc)
     * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
     */
    @Override
    public IStatus undo(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
        // TODO Auto-generated method stub
        return null;
    }

}
