/**
 * Copyright (C) 2014 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.preference;

import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.element.CommandHandlerButton;

/**
 * @author a.oppermann
 * @date 21.07.2014
 *
 */
public class ChecklistEditorGeneralPreference extends PreferencePage implements IWorkbenchPreferencePage {

    boolean isEditorActivated;
    Composite child ;
    /*
     * (non-Javadoc)
     *
     * @see
     * org.eclipse.jface.preference.FieldEditorPreferencePage#createFieldEditors
     * ()
     */
    @Override
    protected Control createContents(Composite parent) {

        Composite composite = new Composite(parent, SWT.NULL);
        composite.setLayout(new GridLayout());
        isEditorActivated = PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.DISTRIBUTION_AREA_PREFRENCES_ACTIVE);
        final Button activateCheckButton = new Button(composite, SWT.CHECK);
        activateCheckButton.setText("Enable Distribution Editor");
        activateCheckButton.setSelection(isEditorActivated);
        activateCheckButton.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                isEditorActivated = activateCheckButton.getSelection();
                PreferencesUtil.getPreferenceStore().setValue(IPreferenceKeys.DISTRIBUTION_AREA_PREFRENCES_ACTIVE, isEditorActivated);
                if(isEditorActivated){
                    child.setVisible(true);
                    child.setEnabled(true);
                }else{
                    child.setVisible(false);
                    child.setEnabled(false);
                }

            }
        });

        child  = new Composite(composite, SWT.NULL);
        child.setLayout(new GridLayout());
        child.setVisible(isEditorActivated);
        final CLabel label = new CLabel(child, SWT.NULL);
        label.setText("Please open the wizard below, in order to \n" + "choose the areas for the Distribution Editor");
        final CommandHandlerButton button_openFeatureTree = new CommandHandlerButton(child, SWT.PUSH,
                "eu.etaxonomy.taxeditor.store.open.OpenDistributionEditorWizardHandler");

        button_openFeatureTree.setText("Open Distribution Selection Wizard");
        final Button showIdInVocabulary = new Button(child, SWT.CHECK);
        boolean isShowIdInVocabulary = PreferencesUtil.isShowIdInVocabularyInChecklistEditor();
        showIdInVocabulary.setText("Show Id in Vocabulary instead of full title of the areas");
        showIdInVocabulary.setSelection(isShowIdInVocabulary);
        showIdInVocabulary.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                boolean isShowIdInVocabulary = showIdInVocabulary.getSelection();
                PreferencesUtil.setShowIdInVocabularyInChecklistEditor(isShowIdInVocabulary);
             }
        });
        PreferencesUtil.recursiveSetEnabled(button_openFeatureTree, CdmStore.isActive());
        boolean isShowRank = PreferencesUtil.isShowRankInChecklistEditor();
        final Button activateRankButton = new Button(child, SWT.CHECK);
        activateRankButton.setText("Show Rank in Distribution Editor");
        activateRankButton.setSelection(isShowRank);
        activateRankButton.addSelectionListener(new SelectionAdapter(){
            @Override
            public void widgetSelected(SelectionEvent e) {
                boolean isShowRank = activateRankButton.getSelection();
                PreferencesUtil.setShowRankInChecklistEditor(isShowRank);
            }
        });


        if(isEditorActivated){
            child.setEnabled(true);
        }else{
            child.setEnabled(false);
        }

        return composite;
    }

    /*
     * (non-Javadoc)
     *
     * @see
     * org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
     */
    @Override
    public void init(IWorkbench workbench) {
    }

}
