/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.preference;

import java.util.List;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.ListViewer;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import eu.etaxonomy.cdm.api.service.IFeatureTreeService;
import eu.etaxonomy.cdm.model.description.FeatureTree;
import eu.etaxonomy.taxeditor.featuretree.FeatureTreeContentProvider;
import eu.etaxonomy.taxeditor.featuretree.FeatureTreeLabelProvider;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.preference.menu.CdmPreferencePage;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>DefaultFeatureTreePreferenecs class.</p>
 *
 * @author n.hoffmann
 * @created Sep 16, 2010
 * @version 1.0
 */
public class DefaultFeatureTreePreferenecs extends CdmPreferencePage implements IWorkbenchPreferencePage {

	private FeatureTree defaultFeatureTreeForTextualDescription;
	private FeatureTree defaultFeatureTreeForStructuredDescription;

	/* (non-Javadoc)
	 * @see org.eclipse.jface.preference.PreferencePage#createContents(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	protected Control createContents(Composite parent) {
		defaultFeatureTreeForTextualDescription = PreferencesUtil.getDefaultFeatureTreeForTextualDescription();
		defaultFeatureTreeForStructuredDescription = PreferencesUtil.getDefaultFeatureTreeForStructuredDescription();

		Composite composite = new Composite(parent, SWT.NULL);
		composite.setLayout(new GridLayout());
		if(!CdmStore.isActive()) {
            MessagingUtils.noDataSourceWarningDialog(null);
		}else{
		    createTextTreeSelection(composite);
		    createStructureTreeSelection(composite);
		}

		return composite;
	}

	private void createTextTreeSelection(Composite parent){
		final CLabel label = new CLabel(parent, SWT.NONE);
		label.setText("Deafult Feature Tree to be used for textual descriptions");

		final ListViewer viewer = new ListViewer(parent);
		viewer.getControl().setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));

		viewer.setContentProvider(new FeatureTreeContentProvider());
		viewer.setLabelProvider(new FeatureTreeLabelProvider());

		viewer.addSelectionChangedListener(new ISelectionChangedListener() {

			@Override
			public void selectionChanged(SelectionChangedEvent arg0) {
				IStructuredSelection selection = (IStructuredSelection) viewer.getSelection();

				defaultFeatureTreeForTextualDescription = (FeatureTree) selection.getFirstElement();
			}
		});

		List<FeatureTree> input = CdmStore.getService(IFeatureTreeService.class).list(FeatureTree.class, null, null, null, null);

		viewer.setInput(input);

		if(defaultFeatureTreeForTextualDescription != null){
			IStructuredSelection selection = new StructuredSelection(defaultFeatureTreeForTextualDescription);
			viewer.setSelection(selection, true);
		}
	}

	private void createStructureTreeSelection(Composite parent){
		final CLabel label = new CLabel(parent, SWT.NONE);
		label.setText("Deafult Feature Tree to be used for structured descriptions");

		final ListViewer viewer = new ListViewer(parent);
		viewer.getControl().setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));

		viewer.setContentProvider(new FeatureTreeContentProvider());
		viewer.setLabelProvider(new FeatureTreeLabelProvider());

		viewer.addSelectionChangedListener(new ISelectionChangedListener() {

			@Override
			public void selectionChanged(SelectionChangedEvent arg0) {
				IStructuredSelection selection = (IStructuredSelection) viewer.getSelection();

				defaultFeatureTreeForStructuredDescription = (FeatureTree) selection.getFirstElement();
			}
		});

		List<FeatureTree> input = CdmStore.getService(IFeatureTreeService.class).list(FeatureTree.class, null, null, null, null);

		viewer.setInput(input);

		if(defaultFeatureTreeForStructuredDescription != null){
			IStructuredSelection selection = new StructuredSelection(defaultFeatureTreeForStructuredDescription);
			viewer.setSelection(selection, true);
		}
	}

	/** {@inheritDoc} */
	@Override
	public void init(IWorkbench workbench) {
		setPreferenceStore(PreferencesUtil.getPreferenceStore());
	}

	/** {@inheritDoc} */
	@Override
	public boolean performOk() {
		String defaultFeatureTreeForTextualDescriptionUuid = "";
		String defaultFeatureTreeForStructuredDescriptionUuid = "";

		if(defaultFeatureTreeForTextualDescription != null){
			defaultFeatureTreeForTextualDescriptionUuid = defaultFeatureTreeForTextualDescription.getUuid().toString();
		}
		if(defaultFeatureTreeForStructuredDescription != null){
			defaultFeatureTreeForStructuredDescriptionUuid = defaultFeatureTreeForStructuredDescription.getUuid().toString();
		}

		getPreferenceStore().setValue(IPreferenceKeys.FEATURE_TREE_DEFAULT_TEXT, defaultFeatureTreeForTextualDescriptionUuid);
		getPreferenceStore().setValue(IPreferenceKeys.FEATURE_TREE_DEFAULT_STRUCTURE, defaultFeatureTreeForStructuredDescriptionUuid);

		return super.performOk();
	}
}
