package eu.etaxonomy.taxeditor.preference;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import eu.etaxonomy.taxeditor.l10n.Messages;

public class OrderPreferences extends PreferencePage implements IWorkbenchPreferencePage {


	    boolean isNaturalOrderActivated;
	    boolean isAlphabeticalOrderActivated;
	    boolean isRankAndNameOrderActivated;
	    boolean isRestoreTaxonNavigator;
	    boolean isSelectionChanged = false;
	    boolean isStrictlyAlphabeticallyOrdered;
	    /*
	     * (non-Javadoc)
	     *
	     * @see
	     * org.eclipse.jface.preference.FieldEditorPreferencePage#createFieldEditors
	     * ()
	     */
	    @Override
	    protected Control createContents(Composite parent) {

	        isRestoreTaxonNavigator = PreferencesUtil.isStoreNavigatorState();

            Composite secondComposite = new Composite(parent, SWT.NULL);
            secondComposite.setLayout(new GridLayout());

            final Button activateRestoreNavigatorButton = new Button(secondComposite, SWT.CHECK | SWT.LEFT);
            activateRestoreNavigatorButton.setText("Restore the last Taxon Navigator state.");
            activateRestoreNavigatorButton.setSelection(isRestoreTaxonNavigator);
            activateRestoreNavigatorButton.addSelectionListener(new SelectionAdapter(){
                @Override
                public void widgetSelected(SelectionEvent e) {
                    if(isRestoreTaxonNavigator != activateRestoreNavigatorButton.getSelection()) {
                        isRestoreTaxonNavigator = activateRestoreNavigatorButton.getSelection();
                        PreferencesUtil.setStoreNavigatorState(isRestoreTaxonNavigator);
                    }
                }

            });


            Composite composite = new Composite(parent, SWT.NULL);
	        composite.setLayout(new GridLayout());

	        Label label = new Label(composite, SWT.NONE);
	        label.setText("Sorting");


	        isNaturalOrderActivated = PreferencesUtil.getSortNodesNaturally();
	        final Button activateNaturalOrderCheckButton = new Button(composite, SWT.RADIO);
	        activateNaturalOrderCheckButton.setText("Enable Natural Order");
	        activateNaturalOrderCheckButton.setSelection(isNaturalOrderActivated);

	        isRankAndNameOrderActivated = !PreferencesUtil.getSortNodesStrictlyAlphabetically() && !PreferencesUtil.getSortNodesNaturally();
	        final Button activateRankAndNameOrderActivatedCheckButton = new Button(composite, SWT.RADIO);
	        activateRankAndNameOrderActivatedCheckButton.setText("Enable Rank and Alphabetical Order");
	        activateRankAndNameOrderActivatedCheckButton.setSelection(isRankAndNameOrderActivated);

	        isAlphabeticalOrderActivated = PreferencesUtil.getSortNodesStrictlyAlphabetically();
	        final Button activateAlphabeticallyOrderedCheckButton = new Button(composite, SWT.RADIO);
	        activateAlphabeticallyOrderedCheckButton.setText("Enable Alphabetical Order");
	        activateAlphabeticallyOrderedCheckButton.setSelection(isAlphabeticalOrderActivated);

	        activateNaturalOrderCheckButton.addSelectionListener(new SelectionAdapter(){
	            @Override
	            public void widgetSelected(SelectionEvent e) {
	            	if(isNaturalOrderActivated != activateNaturalOrderCheckButton.getSelection()) {
	                	isNaturalOrderActivated = activateNaturalOrderCheckButton.getSelection();
	                	if (isAlphabeticalOrderActivated && isNaturalOrderActivated){
	                		isAlphabeticalOrderActivated = false;
	                		PreferencesUtil.setSortNodesStrictlyAlphabetically(isAlphabeticalOrderActivated);
	            		}
	            		if (isRankAndNameOrderActivated && isNaturalOrderActivated){
	            			isRankAndNameOrderActivated = false;
	            		}
	                	PreferencesUtil.setSortNodesNaturally(isNaturalOrderActivated);
                        isSelectionChanged = true;
                    }else{
                        isSelectionChanged = false;
                    }

	            }
	        });
	        activateAlphabeticallyOrderedCheckButton.addSelectionListener(new SelectionAdapter(){
	            @Override
	            public void widgetSelected(SelectionEvent e) {
	            	if(isAlphabeticalOrderActivated != activateAlphabeticallyOrderedCheckButton.getSelection()) {
	            		isAlphabeticalOrderActivated = activateAlphabeticallyOrderedCheckButton.getSelection();
	            		if (isNaturalOrderActivated && isAlphabeticalOrderActivated){
	            			isNaturalOrderActivated = false;
	            			PreferencesUtil.setSortNodesNaturally(isNaturalOrderActivated);
	            		}
	            		if (isRankAndNameOrderActivated && isAlphabeticalOrderActivated){
	            			isRankAndNameOrderActivated = false;
	            		}
	                	PreferencesUtil.setSortNodesStrictlyAlphabetically(isAlphabeticalOrderActivated);
                        isSelectionChanged = true;
                    }else{
                        isSelectionChanged = false;
                    }

	            }
	        });

	        activateRankAndNameOrderActivatedCheckButton.addSelectionListener(new SelectionAdapter(){
	            @Override
	            public void widgetSelected(SelectionEvent e) {
	            	if(isRankAndNameOrderActivated != activateRankAndNameOrderActivatedCheckButton.getSelection()) {
	            		isRankAndNameOrderActivated = activateRankAndNameOrderActivatedCheckButton.getSelection();
	            		if (isAlphabeticalOrderActivated && isRankAndNameOrderActivated){
	            			 isAlphabeticalOrderActivated = false;
	            		}
	            		if (isNaturalOrderActivated && isRankAndNameOrderActivated){
	            			isNaturalOrderActivated = false;
	            		}

	            		if (isRankAndNameOrderActivated ||(!isNaturalOrderActivated && !isAlphabeticalOrderActivated)){
	            			PreferencesUtil.setSortNodesStrictlyAlphabetically(false);
	            			PreferencesUtil.setSortNodesNaturally(false);
	            		}
                        isSelectionChanged = true;
                    }else{
                        isSelectionChanged = false;
                    }

	            }
	        });





            final Label description = new Label(parent, SWT.NONE);
            description.setText(Messages.OrderPreferencePage_NewNavigatorWindowRequired);

	        return composite;
	    }


		@Override
		public void init(IWorkbench workbench) {
			// TODO Auto-generated method stub

		}

		/* (non-Javadoc)
		 * @see org.eclipse.jface.preference.PreferencePage#performOk()
		 */
		@Override
		public boolean performOk() {
	       if(isSelectionChanged){
	    	  MessageDialog.openInformation(getShell(), null, Messages.OrderPreferencePage_PleaseReopenNavigator);
	    	  isSelectionChanged = false;
			return super.performOk();
	       }
	       return true;
		}


}
