/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.preference.menu;

import java.util.List;

import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.ComboFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import eu.etaxonomy.cdm.api.application.ICdmRepository;
import eu.etaxonomy.cdm.api.service.IPreferenceService;
import eu.etaxonomy.cdm.model.metadata.CdmPreference;
import eu.etaxonomy.cdm.model.metadata.CdmPreference.PrefKey;
import eu.etaxonomy.cdm.model.metadata.PreferencePredicate;
import eu.etaxonomy.cdm.model.metadata.PreferenceSubject;
import eu.etaxonomy.cdm.model.name.NomenclaturalCode;
import eu.etaxonomy.taxeditor.model.NomenclaturalCodeHelper;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.internal.TaxeditorStorePlugin;

/**
 * <p>
 * NomenclaturalCodePreferences class.
 * </p>
 *
 * @author p.ciardelli
 * @created 16.09.2008
 */
public class NomenclaturalCodePreferences extends FieldEditorPreferencePage
		implements IWorkbenchPreferencePage {

	@Override
	protected void createFieldEditors() {
	    PreferencesUtil.setPreferredNomenclaturalCode(null, false);
	    if (getPreferenceStore().getBoolean(IPreferenceKeys.ALLOW_OVERRIDE_NOMENCLATURAL_CODE_KEY)) {
	        addField(new ComboFieldEditor(
				IPreferenceKeys.PREFERRED_NOMENCLATURAL_CODE_KEY,
				"Available Codes", getLabelAndValues(),
				getFieldEditorParent()));

            addField(new BooleanFieldEditor(
                    IPreferenceKeys.OVERRIDE_NOMENCLATURAL_CODE_KEY,
                    "Use local nomenclatural code",
                    getFieldEditorParent()));
        } else {
            setDescription("The CDM settings don't allow to set the nomenclatural code locally. If you need to make local settings, please ask an administrator.");
        }

	}

	/**
	 * @return
	 */
	private String[][] getLabelAndValues() {
		List<NomenclaturalCode> supportedCodes = NomenclaturalCodeHelper
				.getSupportedCodes();
		String[][] labelAndValues = new String[supportedCodes.size()][2];
		for (int i = 0; i < supportedCodes.size(); i++) {
			labelAndValues[i][0] = NomenclaturalCodeHelper
					.getDescription(supportedCodes.get(i));
			labelAndValues[i][1] = PreferencesUtil
					.getPreferenceKey(supportedCodes.get(i));
		}
		return labelAndValues;
	}

	/**
	 * {@inheritDoc}
	 *
	 * Initialize the preference page
	 */
	@Override
    public void init(IWorkbench workbench) {

	        setPreferenceStore(TaxeditorStorePlugin.getDefault()
				.getPreferenceStore());

	      ICdmRepository controller = CdmStore.getCurrentApplicationConfiguration();
          if (controller != null){
              IPreferenceService service = controller.getPreferenceService();
              PrefKey key = CdmPreference.NewKey(PreferenceSubject.NewDatabaseInstance(), PreferencePredicate.NomenclaturalCode);
              CdmPreference pref = service.find(key);
              getPreferenceStore().setValue(IPreferenceKeys.ALLOW_OVERRIDE_NOMENCLATURAL_CODE_KEY, pref == null? true : pref.isAllowOverride());
          }

	    if (getPreferenceStore().getBoolean(IPreferenceKeys.ALLOW_OVERRIDE_NOMENCLATURAL_CODE_KEY)) {
	        setDescription("Choose which nomenclatural code you would like to use in your local application for scientific names unless otherwise specified.");
	    }else{
	        setDescription("The CDM settings don't allow to set the nomenclatural code locally. If you need to make local settings, please ask an administrator.");

	    }
	}

	@Override
	 public boolean performOk() {

		boolean result = super.performOk();
//		if (result){
//			String value = getPreferenceStore().getString(IPreferenceKeys.PREFERRED_NOMENCLATURAL_CODE_KEY);
//			CdmPreference pref = CdmPreference.NewDatabaseInstance( PreferencePredicate.NomenclaturalCode, value);
//			ICdmRepository controller = CdmStore.getCurrentApplicationConfiguration();
//			if (controller == null){
//				return false;
//			}
//			IPreferenceService service = controller.getPreferenceService();
//			service.set(pref);
//		}
        return result;
    }

}
