/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store;

import java.util.UUID;

import org.eclipse.core.commands.operations.IOperationHistory;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.jface.action.IStatusLineManager;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.FeatureNodeContainer;
import eu.etaxonomy.taxeditor.store.internal.TaxeditorStorePlugin;

/**
 * <p>StoreUtil class.</p>
 *
 * @author n.hoffmann
 * @created 11.05.2009
 * @version 1.0
 */
public class StoreUtil extends AbstractUtility {

	/**
	 * <p>checktaxonExists</p>
	 *
	 * @param fromString a {@link java.util.UUID} object.
	 */
	public static void checktaxonExists(UUID fromString) {
//        if (CdmStore.getTaxonService().getTaxonByUuid(UUID.fromString(uuid)) == null) {
//        	logger.warn("Couldn't find taxon with UUID " + uuid);
//        	return null;
//        }
	}

	/**
	 * If the object given is already a {@link CdmBase} then it is returned.<br>
	 * If it is a kind of "container" for CDM objects then it is asked for its "responsible" CdmBase entity.<br>
	 * Otherwise an exception is thrown.
	 * @param object the object to test for CdmBase
	 * @return a CdmBase object
	 * @throws IllegalArgumentException if the tested object is neither a CdmBase nor a CDM "container"
	 */
	public static CdmBase getCdmEntity(Object object){
        // TODO temporary solution for ticket #4091????
        if (object == null){
        	return null;   //not sure if an object should ever be null at this point, but this needs to be handled in calling methods
        }else if(object instanceof DerivedUnitFacade){
            return ((DerivedUnitFacade)object).baseUnit();
        }
        else if(object instanceof FeatureNodeContainer){
            return ((FeatureNodeContainer) object).getFeatureNode();
        }
        else if(object instanceof CdmBase){
            return (CdmBase) object;
        }
        throw new IllegalArgumentException("Object " + object.toString() + " is neither a CdmBase nor a CDM \"container\"");
	}

	/**
	 * <p>getOperationHistory</p>
	 *
	 * @return a {@link org.eclipse.core.commands.operations.IOperationHistory} object.
	 */
	public static IOperationHistory getOperationHistory() {
		return TaxeditorStorePlugin.getDefault().getWorkbench().
					getOperationSupport().getOperationHistory();
	}

	/**
	 * <p>setStatusLineManager</p>
	 *
	 * @param manager a {@link org.eclipse.jface.action.IStatusLineManager} object.
	 */
	public static void setStatusLineManager(IStatusLineManager manager) {
		statusLineManager = manager;
	}


	/**
	 * <p>getUndoContext</p>
	 *
	 * @return a {@link org.eclipse.core.commands.operations.IUndoContext} object.
	 */
	public static IUndoContext getUndoContext(){
		return IOperationHistory.GLOBAL_UNDO_CONTEXT;
	}

	/**
	 * <p>getPluginId</p>
	 *
	 * @return a {@link java.lang.String} object.
	 */
	public static String getPluginId(){
		return TaxeditorStorePlugin.PLUGIN_ID;
	}

	/**
	 *
	 * @return
	 */
	public static IEditorInput getActiveEditorInput() {
		IEditorPart activeEditor = getActiveEditor();
		if (activeEditor != null){
			return activeEditor.getEditorInput();
		}
		return null;
	}
}
