/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.bar;

import java.util.Observable;
import java.util.Observer;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.menus.WorkbenchWindowControlContribution;

import eu.etaxonomy.cdm.model.common.User;
import eu.etaxonomy.taxeditor.l10n.Messages;
import eu.etaxonomy.taxeditor.remoting.source.CdmRemoteSource;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.util.ApplicationUtil;

/**
 * Shows the currently logged in user in status bar
 *
 * @author n.hoffmann
 * @created 01.07.2009
 * @version 1.0
 */
public class AuthenticatedUserBar extends WorkbenchWindowControlContribution implements Observer{

    private Label label_authenticatedUser;

    public AuthenticatedUserBar(){
        CdmStore.getLoginManager().addObserver(this);
    }

    /** {@inheritDoc} */
    @Override
    protected Control createControl(Composite parent) {

        label_authenticatedUser = new Label(parent,  SWT.NULL);

        update(null, null);

        return label_authenticatedUser;
    }

    /** {@inheritDoc} */
    @Override
    public void update(Observable o, Object arg) {
        User authenticatedUser = CdmStore.getLoginManager().getAuthenticatedUser();
        // TODO find a method to recompute width for parental toolbar item
        String text = ""; //$NON-NLS-1$
        if(authenticatedUser == null) {
            text = Messages.AuthenticatedUserBar_NOT_LOGGED_IN ;
        } else {
            CdmRemoteSource source = (CdmRemoteSource) CdmStore.getActiveCdmSource();
            String loginInfo = String.format("%s@%s:%s",authenticatedUser.getUsername(), source.getName(), source.getContextPath()); //$NON-NLS-1$
            PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell().setText(ApplicationUtil.getTitle() + " " + loginInfo); //$NON-NLS-1$

            text = String.format(Messages.AuthenticatedUserBar_LOGGED_IN_AS, authenticatedUser.getUsername());
        }

        label_authenticatedUser.setText(text);
    }

    /** {@inheritDoc} */
    @Override
    public void dispose() {
        super.dispose();
        CdmStore.getLoginManager().deleteObserver(this);
    }

}
