/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.combo;

import org.eclipse.jface.viewers.ComboViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.forms.widgets.TableWrapData;

import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.preference.Resources;
import eu.etaxonomy.taxeditor.ui.element.AbstractCdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.IEnableableFormElement;
import eu.etaxonomy.taxeditor.ui.element.ISelectable;
import eu.etaxonomy.taxeditor.ui.element.LayoutConstants;

/**
 * @author pplitzner
 * @date Aug 11, 2016
 *
 */
public abstract class AbstractComboElement<T> extends
AbstractCdmFormElement implements SelectionListener,
IEnableableFormElement, ISelectable,
DisposeListener {

    protected static final int DEFAULT_VISIBLE_ITEMS = 10;

    protected T selection;

    protected Label label;

    protected final Combo combo;


    public AbstractComboElement(CdmFormFactory formFactory, ICdmFormElement formElement) {
        super(formFactory, formElement);

        label = formFactory.createLabel(getLayoutComposite(), "");
        addControl(label);

        // create combo
        ComboViewer viewer = new ComboViewer(getLayoutComposite(), SWT.BORDER | SWT.READ_ONLY );
        combo = viewer.getCombo();
        addControl(combo);
        TableWrapData fill_HORIZONTALLY = LayoutConstants.FILL_HORIZONTALLY();
        combo.setLayoutData(fill_HORIZONTALLY);
        fill_HORIZONTALLY.maxWidth = 50;
        combo.setVisibleItemCount(DEFAULT_VISIBLE_ITEMS);
    }

    /** {@inheritDoc} */
    @Override
    public void setBackground(Color color) {
        if (label != null) {
            label.setBackground(color);
        }
    }

    /** {@inheritDoc} */
    @Override
    public void setIrrelevant(boolean irrelevant) {
        String colorId = irrelevant ? Resources.COLOR_COMPOSITE_IRRELEVANT
                : Resources.COLOR_COMPOSITE_BACKGROUND;

        Color color = AbstractUtility.getColor(colorId);
        combo.setBackground(color);
        if (label != null) {
            label.setBackground(color);
        }
        colorId = !irrelevant ? Resources.COLOR_COMPOSITE_IRRELEVANT
                : Resources.COLOR_COMPOSITE_BACKGROUND;
        color = AbstractUtility.getColor(colorId);
        combo.setForeground(color);

    }

    public void setVisibleItemCount(int count){
        combo.setVisibleItemCount(count);
    }

    /** {@inheritDoc} */
    @Override
    public void setSelected(boolean selected) {
        setBackground(selected ? SELECTED : getPersistentBackground());
    }

    public T getSelection() {
        return selection;
    }

    public void addSelectionListener(SelectionListener listener) {
        combo.addSelectionListener(listener);
    }

    public void removeSelectionListener(SelectionListener listener) {
        combo.removeSelectionListener(listener);
    }

    /** {@inheritDoc} */
    @Override
    public void widgetDisposed(DisposeEvent e) {
        PreferencesUtil.getPreferenceStore().removePropertyChangeListener(this);
    }

    @Override
    public void widgetDefaultSelected(SelectionEvent e) {
    }

    @Override
    public boolean isEnabled() {
        return combo.isEnabled();
    }

    /** {@inheritDoc} */
    @Override
    public void setEnabled(boolean enabled) {
        combo.setEnabled(enabled);
    }

    public abstract void setSelection(T selection);
}
