/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.dialog;

import java.io.IOException;

import org.eclipse.jface.dialogs.IMessageProvider;
import org.eclipse.jface.dialogs.TitleAreaDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CCombo;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;

import eu.etaxonomy.taxeditor.preference.PreferencesUtil;


/**
 * @author alex
 * @date 19.08.2014
 *
 */
public class DefaultLanguageDialog extends TitleAreaDialog{


    private CCombo combo;
    final PreferencesUtil preferencesUtil = new PreferencesUtil();

    /**
     * @param parentShell
     */
    public DefaultLanguageDialog(Shell parentShell) {
        super(parentShell);
    }

    @Override
    protected void configureShell(Shell shell) {
        super.configureShell(shell);
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(org.eclipse.swt.widgets.Composite)
     */
    @Override
    protected Control createDialogArea(Composite parent) {
        // TODO Auto-generated method stub
        setTitle("Select your default Language");
        setMessage("This is will set your default langauge once.\n You will be able to change this in the prefrence menue at any time.", IMessageProvider.INFORMATION);
        Composite composite = (Composite)super.createDialogArea(parent);
        Composite container = new Composite(parent, SWT.NONE);
        container.setLayoutData(new GridData(SWT.TOP));

        GridLayout layout = new GridLayout(1, false);
        container.setLayoutData(new GridData(SWT.CENTER, SWT.TOP, true, true));
        container.setLayout(layout);

        final CLabel titleLabel = new CLabel(container, SWT.NONE);
        titleLabel.setText("After this the editor will restart, " +
        		            "with your selection loaded. ");


        createComboElement(container);

        return composite;
    }

    /**
     *
     * @param parent
     */
    private void createComboElement(Composite parent) {
        Composite container1 = new Composite(parent, SWT.NONE);
        container1.setLayoutData(new GridData(GridData.FILL_BOTH));

        GridLayout layout1 = new GridLayout(2, false);
        container1.setLayoutData(new GridData(SWT.RIGHT, SWT.RIGHT, true, true));
        container1.setLayout(layout1);


        final CLabel comboLabel = new CLabel(container1, SWT.NONE);
        comboLabel.setText("Please choose your default language: ");

        GridData oneLine = new GridData();
        oneLine.grabExcessHorizontalSpace = true;
        oneLine.horizontalAlignment = GridData.FILL;

        combo = new CCombo(container1, SWT.NONE);
        combo.setLayoutData(oneLine);

        combo.add(Language.GERMAN.getLabel(), 0);
        combo.add(Language.ENGLISH.getLabel(), 1);
        combo.select(1);
        combo.addSelectionListener(new SelectionListener() {

            @Override
            public void widgetSelected(SelectionEvent e) {
                try {
                    preferencesUtil.writePropertyToConfigFile(combo.getSelectionIndex());
                } catch (IOException e1) {
                    e1.printStackTrace();
                }
            }

            @Override
            public void widgetDefaultSelected(SelectionEvent e) {
            }
        });
    }

    @Override
    protected void okPressed() {
        try {
            preferencesUtil.writePropertyToConfigFile(combo.getSelectionIndex());
        } catch (IOException e) {
            e.printStackTrace();
        }
        super.okPressed();
    }

    private enum Language{

        GERMAN("Deutsch"), ENGLISH("English");
        private String label;
        private Language(String label){
            this.label = label;
        }

        /**
         * @return the label
         */
        public String getLabel() {
            return label;
        }
    }
}
