/**
* Copyright (C) 2017 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.dialog.configurator;

import org.eclipse.core.databinding.DataBindingContext;
import org.eclipse.core.databinding.beans.PojoProperties;
import org.eclipse.core.databinding.observable.value.IObservableValue;
import org.eclipse.jface.databinding.swt.WidgetProperties;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Text;
import org.eclipse.wb.swt.ResourceManager;

import eu.etaxonomy.cdm.io.common.SetSecundumForSubtreeConfigurator;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.taxeditor.l10n.Messages;
import eu.etaxonomy.taxeditor.ui.dialog.selection.SelectionDialogFactory;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * @author k.luther
 * @date 10.02.2017
 *
 */
public class SetSecundumConfiguratorWizardPage extends WizardPage implements Listener {
    private DataBindingContext m_bindingContext;

    private final static CdmFormFactory toolkit = new CdmFormFactory(Display.getCurrent());
    private final SetSecundumForSubtreeConfigurator configurator;

    private  Button btnBrowseReference = null;
    private  Text textReference = null;
    private  Button btnClear = null;
    private EntitySelectionElement<Reference> selectReference;
    private  Button btnIncludeAcceptedTaxa;
    private Button btnIncludeSynonyms;
    private Button btnOverwriteExistingAccepted;
    private Button btnOverwriteExistingSynonyms;
    private Button btnEmptySecundumDetail;
    private Button btnIncludeSharedTaxa;


    /**
     * Create the composite.
     * @param parent
     * @param style
     */
    public SetSecundumConfiguratorWizardPage(SetSecundumForSubtreeConfigurator configurator, Wizard parent, int style ) {
        super("Set Secundum Reference Configuration");
        this.configurator = configurator;
        this.setDescription(Messages.SetSecundumConfiguration_Description);

//        addDisposeListener(new DisposeListener() {
//            @Override
//            public void widgetDisposed(DisposeEvent e) {
//                toolkit.dispose();
//            }
//        });
      //  toolkit.paintBordersFor(this);
//        setLayout(new GridLayout());
//        setBackground(getBackground());




    }

    /**
     * @return
     */
    private DataBindingContext initDataBindings() {
        DataBindingContext bindingContext = new DataBindingContext();

        IObservableValue observeSelectionBtnIncludeAcceptedTaxa = WidgetProperties.selection().observe(btnIncludeAcceptedTaxa);
        IObservableValue includeAcceptedTaxaConfiguratorObserveValue = PojoProperties.value("includeAcceptedTaxa").observe(configurator);
        bindingContext.bindValue(observeSelectionBtnIncludeAcceptedTaxa, includeAcceptedTaxaConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionBtnIncludeSynonyms = WidgetProperties.selection().observe(btnIncludeSynonyms);
        IObservableValue includeSynonymsConfiguratorObserveValue = PojoProperties.value("includeSynonyms").observe(configurator);
        bindingContext.bindValue(observeSelectionBtnIncludeSynonyms, includeSynonymsConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionBtnOverwriteExistingAccepted = WidgetProperties.selection().observe(btnOverwriteExistingAccepted);
        IObservableValue overwriteExistingAcceptedConfiguratorObserveValue = PojoProperties.value("overwriteExistingAccepted").observe(configurator);
        bindingContext.bindValue(observeSelectionBtnOverwriteExistingAccepted, overwriteExistingAcceptedConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionBtnOverwriteExistingSynonyms = WidgetProperties.selection().observe(btnOverwriteExistingSynonyms);
        IObservableValue overwriteExistingSynonymsConfiguratorObserveValue = PojoProperties.value("overwriteExistingSynonyms").observe(configurator);
        bindingContext.bindValue(observeSelectionBtnOverwriteExistingSynonyms, overwriteExistingSynonymsConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionBtnEmptySecundumDetail = WidgetProperties.selection().observe(btnEmptySecundumDetail);
        IObservableValue emptySecundumDetailConfiguratorObserveValue = PojoProperties.value("emptySecundumDetail").observe(configurator);
        bindingContext.bindValue(observeSelectionBtnEmptySecundumDetail, emptySecundumDetailConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionBtnIncludeSharedTaxal = WidgetProperties.selection().observe(btnIncludeSharedTaxa);
        IObservableValue includeSharedTaxaConfiguratorObserveValue = PojoProperties.value("includeSharedTaxa").observe(configurator);
        bindingContext.bindValue(observeSelectionBtnIncludeSharedTaxal, includeSharedTaxaConfiguratorObserveValue, null, null);
        return bindingContext;
    }

    @Override
    public void createControl(Composite parent) {

        final Composite composite = new Composite(parent, SWT.NULL);

        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        composite.setLayout(gridLayout);
        final Composite compositeRef = new Composite(composite, SWT.NULL);

        GridLayout gridLayoutRef = new GridLayout();
        gridLayoutRef.numColumns = 4;

        compositeRef.setLayout(gridLayoutRef);
        compositeRef.setLayoutData(new GridData(SWT.FILL, SWT.LEFT, true, true));
        Label label = new Label(compositeRef, SWT.NONE);
        label.setText(Messages.SetSecundumConfiguration_NewSecundum_Label);
       label.setLayoutData(new GridData(SWT.FILL, SWT.LEFT, true, false));

        textReference = new Text(compositeRef, SWT.BORDER);
        textReference.setEditable(false);
        textReference.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
        textReference.setTextLimit(Text.LIMIT);

        btnBrowseReference = new Button(compositeRef, SWT.NONE);
        btnBrowseReference.setImage(ResourceManager.getPluginImage("eu.etaxonomy.taxeditor.store", "icons/open.gif"));
        btnBrowseReference.addListener(SWT.Selection, this);
        btnClear = new Button(compositeRef, SWT.NONE);
        btnClear.setImage(ResourceManager.getPluginImage("eu.etaxonomy.taxeditor.store", "icons/trash.gif"));
        btnClear.addListener(SWT.Selection, this);

       // selectReference = toolkit.createSelectionElement(Rights.class, getConversationHolder(), composite, "Rights", null, EntitySelectionElement.SELECTABLE);
        final Composite control = new Composite(composite, SWT.NULL);
        GridLayout gridLayoutControl = new GridLayout();
        gridLayoutControl.numColumns = 1;

        control.setLayout(gridLayoutControl);
        control.setLayoutData(new GridData(SWT.FILL, SWT.LEFT, true, true));
      //  Composite control = toolkit.createComposite(composite);
        btnIncludeAcceptedTaxa = new Button(control, SWT.CHECK);
        btnIncludeAcceptedTaxa.setText(Messages.SetSecundumConfiguration_IncludeAcceptedTaxa);
        btnIncludeAcceptedTaxa.setSelection(configurator.isIncludeAcceptedTaxa());
        btnIncludeAcceptedTaxa.addListener(SWT.Selection, new Listener() {
            @Override
         public void handleEvent(Event e) {
                Button b = (Button) e.widget;
                GridData data = (GridData)  btnIncludeAcceptedTaxa.getLayoutData();
                data.exclude = b.getSelection();
                btnOverwriteExistingAccepted.setVisible(data.exclude);
                btnIncludeSharedTaxa.setVisible(data.exclude);
                if (!btnIncludeSynonyms.getSelection() && !data.exclude){
                    btnEmptySecundumDetail.setVisible(false);
                    setPageComplete(false);
                }else{
                    btnEmptySecundumDetail.setVisible(true);
                    setPageComplete(true);
                }
            }
        });

        btnOverwriteExistingAccepted = new Button(control, SWT.CHECK);
        btnOverwriteExistingAccepted.setText(Messages.SetSecundumConfiguration_OverwriteExistingAccepted);

        btnIncludeSynonyms = new Button(control, SWT.CHECK);
        btnIncludeSynonyms.setText(Messages.SetSecundumConfiguration_IncludeSynonyms);
        btnIncludeSynonyms.setSelection(configurator.isIncludeSynonyms());
        btnIncludeSynonyms.addListener(SWT.Selection, new Listener() {
            @Override
         public void handleEvent(Event e) {
                Button b = (Button) e.widget;
                GridData data = (GridData)  btnIncludeSynonyms.getLayoutData();
                data.exclude = b.getSelection();
                btnOverwriteExistingSynonyms.setVisible(data.exclude);
                if (!btnIncludeAcceptedTaxa.getSelection() && !data.exclude){
                    btnEmptySecundumDetail.setVisible(false);
                    setPageComplete(false);
                }else{
                    btnEmptySecundumDetail.setVisible(true);
                    setPageComplete(true);
                }

            }
        });

        btnOverwriteExistingAccepted.setSelection(configurator.isOverwriteExistingAccepted());
        btnOverwriteExistingSynonyms = new Button(control, SWT.CHECK);
        btnOverwriteExistingSynonyms.setText(Messages.SetSecundumConfiguration_OverwriteExistingSynonyms);
        btnOverwriteExistingSynonyms.setSelection(configurator.isOverwriteExistingSynonyms());
        btnEmptySecundumDetail = new Button(control, SWT.CHECK);
        btnEmptySecundumDetail.setText(Messages.SetSecundumConfiguration_EmptySecundumDetail);
        btnEmptySecundumDetail.setSelection(configurator.isEmptySecundumDetail());

        btnIncludeSharedTaxa = new Button(control, SWT.CHECK);
        btnIncludeSharedTaxa.setText(Messages.SetSecundumConfiguration_IncludeSharedtaxa);
        btnIncludeSharedTaxa.setSelection(configurator.isIncludeSharedTaxa());

        m_bindingContext = initDataBindings();
        setControl(composite);
    }



    @Override
    public void handleEvent(Event event) {
        Reference reference;
        if(event.widget==btnBrowseReference){
            reference = SelectionDialogFactory.getSelectionFromDialog(Reference.class, this.getShell(), null, null);
            if(reference!=null){
                this.configurator.setNewSecundum(reference);
                textReference.setText(reference.getTitleCache());

            }

        } else if(event.widget==btnClear){
            reference = null;
            textReference.setText("");
            this.configurator.setNewSecundum(null);
        } else{
            reference = null;
            textReference.setText("");
            this.configurator.setNewSecundum(null);
        }

    }

//    /**
//     * {@inheritDoc}
//     */
//    @Override
//    public AbstractCdmDetailElement createElement(ICdmFormElement rootElement) {
//        // TODO Auto-generated method stub
//        return null;
//    }




}
