/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.dialog.configurator.deleteConfigurator;

import org.eclipse.core.databinding.DataBindingContext;
import org.eclipse.core.databinding.beans.PojoProperties;
import org.eclipse.core.databinding.observable.value.IObservableValue;
import org.eclipse.jface.databinding.swt.WidgetProperties;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.ui.forms.widgets.FormToolkit;

import eu.etaxonomy.cdm.api.service.config.MediaDeletionConfigurator;
import eu.etaxonomy.taxeditor.l10n.Messages;

/**
 * @author k.luther
 * @date 02.11.2016
 *
 */
public class DeleteMediaConfiguratorComposite extends Composite {
    private final DataBindingContext m_bindingContext;

    private final FormToolkit toolkit = new FormToolkit(Display.getCurrent());
    private final MediaDeletionConfigurator configurator;
    private final Button btnDeleteIfUsedInTaxonDescription;
    private final Button btnDeleteIfUsedInSpecimenDescription;
    private Button btnRemoveFromImageGallery;


    public DeleteMediaConfiguratorComposite(MediaDeletionConfigurator configurator, Composite parent, int style, boolean inBulkEditor) {
        super(parent, style);
        this.configurator = configurator;
        addDisposeListener(new DisposeListener() {
            @Override
            public void widgetDisposed(DisposeEvent e) {
                toolkit.dispose();
            }
        });
        toolkit.paintBordersFor(this);
        setLayout(new RowLayout(SWT.VERTICAL));
        setBackground(getBackground());

        if (inBulkEditor){
            btnDeleteIfUsedInTaxonDescription = new Button(this, SWT.CHECK);
            btnDeleteIfUsedInTaxonDescription.setText(Messages.DeleteConfiguration_media_deleteIfUsedInTaxonDescription);
        }
        else {
            btnDeleteIfUsedInTaxonDescription = new Button(this, SWT.RADIO);
            btnDeleteIfUsedInTaxonDescription.setText(Messages.DeleteConfiguration_media_delete);

            btnRemoveFromImageGallery = new Button(this, SWT.RADIO);
            btnRemoveFromImageGallery.setText(Messages.DeleteConfiguration_media_removeFromGallery);
        }

        btnDeleteIfUsedInSpecimenDescription = new Button(this, SWT.CHECK);
        btnDeleteIfUsedInSpecimenDescription.setText(Messages.DeleteConfiguration_media_deleteIfUsedInSpecimenDescription);

        if(inBulkEditor){
            btnDeleteIfUsedInSpecimenDescription.setEnabled(true);
        }
        else{
            btnDeleteIfUsedInSpecimenDescription.setEnabled(false);

            btnDeleteIfUsedInTaxonDescription.addListener(SWT.Selection, (Event e) -> {
                Button b = (Button) e.widget;
                btnDeleteIfUsedInSpecimenDescription.setEnabled(b.getSelection());

            });
        }
        btnDeleteIfUsedInTaxonDescription.setSelection(true);

        m_bindingContext = initDataBindings();

    }

    protected DataBindingContext initDataBindings() {
        DataBindingContext bindingContext = new DataBindingContext();
        //
        IObservableValue observeSelectionBtnDeleteIfUsedInTaxonDescription = WidgetProperties.selection().observe(btnDeleteIfUsedInTaxonDescription);
        IObservableValue deleteIfUsedInTaxonDescriptionConfiguratorObserveValue = PojoProperties.value("deleteIfUsedInTaxonDescription").observe(configurator);
        bindingContext.bindValue(observeSelectionBtnDeleteIfUsedInTaxonDescription, deleteIfUsedInTaxonDescriptionConfiguratorObserveValue, null, null);

        if(btnRemoveFromImageGallery!=null){
            IObservableValue observeSelectionBtnRemoveFromImageGallery = WidgetProperties.selection().observe(btnRemoveFromImageGallery);
            IObservableValue removeFromImageGalleryConfiguratorObserveValue = PojoProperties.value("onlyRemoveFromGallery").observe(configurator);
            bindingContext.bindValue(observeSelectionBtnRemoveFromImageGallery, removeFromImageGalleryConfiguratorObserveValue, null, null);
        }

        IObservableValue observeSelectionBtnDeleteIfUsedInSpecimenDescription = WidgetProperties.selection().observe(btnDeleteIfUsedInSpecimenDescription);
        IObservableValue deleteIfUsedInSpecimenDescriptionConfiguratorObserveValue = PojoProperties.value("deleteIfUsedInSpecimenDescription").observe(configurator);
        bindingContext.bindValue(observeSelectionBtnDeleteIfUsedInSpecimenDescription, deleteIfUsedInSpecimenDescriptionConfiguratorObserveValue, null, null);

        return bindingContext;
    }


}
