/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.dialog.configurator.deleteConfigurator;

import java.util.List;

import org.eclipse.core.databinding.DataBindingContext;
import org.eclipse.core.databinding.beans.PojoProperties;
import org.eclipse.core.databinding.observable.value.IObservableValue;
import org.eclipse.jface.databinding.swt.WidgetProperties;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.ui.forms.widgets.FormToolkit;

import eu.etaxonomy.cdm.api.service.config.NameDeletionConfigurator;
import eu.etaxonomy.cdm.api.service.config.TaxonBaseDeletionConfigurator;
import eu.etaxonomy.cdm.model.taxon.Classification;


/**
 * @author pplitzner
 * @date Feb 18, 2015
 *
 */
public class DeleteTaxonBaseConfiguratorComposite extends Composite implements SelectionListener{

    protected  DataBindingContext m_bindingContext;

    private final FormToolkit toolkit = new FormToolkit(Display.getCurrent());
    protected final TaxonBaseDeletionConfigurator configurator;
    private final Button btnDeleteTaxonName;


    //name related
    private final Button btnRemoveAllNameRelationships;
    private final Button btnIgnoreIsBasionym;
    private final Button btnIgnoreIsReplacedSynonymFor;
    private final Button btnIgnoreHasBasionym;
    private final Button btnIgnoreHasReplacedSynonym;
    private final Button btnRemoveAllTypeDesignations;

    private Combo classificationSelectionCombo;


    Classification selectedClassification;
    private List<Classification> classifications;


    /**
     * Create the composite.
     * @param parent
     * @param style
     */
    public DeleteTaxonBaseConfiguratorComposite(TaxonBaseDeletionConfigurator configurator, Composite parent, int style) {
        super(parent, style);
        this.configurator = configurator;
        addDisposeListener(new DisposeListener() {
            @Override
            public void widgetDisposed(DisposeEvent e) {
                toolkit.dispose();
            }
        });
        toolkit.paintBordersFor(this);
        setLayout(new GridLayout());
        setBackground(getBackground());

        btnDeleteTaxonName = new Button(this, SWT.CHECK);
        btnDeleteTaxonName.setText("Delete name if possible");
        btnDeleteTaxonName.setSelection(true);
        btnDeleteTaxonName.addListener(SWT.Selection, new Listener() {
               @Override
            public void handleEvent(Event e) {
                   Button b = (Button) e.widget;
                   GridData data = (GridData)  btnRemoveAllNameRelationships.getLayoutData();
                   data.exclude = b.getSelection();
                   btnRemoveAllNameRelationships.setVisible(data.exclude);
                   btnIgnoreIsBasionym.setVisible(data.exclude);
                   btnIgnoreIsReplacedSynonymFor.setVisible(data.exclude);
                   btnIgnoreHasBasionym.setVisible(data.exclude);
                   btnIgnoreHasReplacedSynonym.setVisible(data.exclude);
                   btnRemoveAllTypeDesignations.setVisible(data.exclude);
               }
        });


        //DeleteConfigurator for the name


        btnRemoveAllNameRelationships = new Button(this, SWT.CHECK);
        btnRemoveAllNameRelationships.setText("Remove all name relations");
        btnRemoveAllNameRelationships.setSelection(true);

        btnIgnoreIsBasionym = new Button(this, SWT.CHECK);
        btnIgnoreIsBasionym.setText("Ignore if it is basionym");
        btnIgnoreIsBasionym.setSelection(true);

        btnIgnoreIsReplacedSynonymFor = new Button(this, SWT.CHECK);
        btnIgnoreIsReplacedSynonymFor.setText("Ignore if it is replaced synonym");
        btnIgnoreIsReplacedSynonymFor.setSelection(true);

        btnIgnoreHasBasionym = new Button(this, SWT.CHECK);
        btnIgnoreHasBasionym.setText("Ignore if it has basionym");
        btnIgnoreHasBasionym.setSelection(true);

        btnIgnoreHasReplacedSynonym = new Button(this, SWT.CHECK);
        btnIgnoreHasReplacedSynonym.setText("Ignore if it has replaced synonym");
        btnIgnoreHasReplacedSynonym.setSelection(true);

        btnRemoveAllTypeDesignations = new Button(this, SWT.CHECK);
        btnRemoveAllTypeDesignations.setText("Remove all type designations");
        btnRemoveAllTypeDesignations.setSelection(true);



       // createClassificationSelectionCombo(this);
        initDataBindings();


    }

    protected void initDataBindings() {
        m_bindingContext = new DataBindingContext();
        //
        IObservableValue observeSelectionBtnDeleteTaxonNameObserveWidget = WidgetProperties.selection().observe(btnDeleteTaxonName);
        IObservableValue deleteNameIfPossibleConfiguratorObserveValue = PojoProperties.value("deleteNameIfPossible").observe(configurator);
        m_bindingContext.bindValue(observeSelectionBtnDeleteTaxonNameObserveWidget, deleteNameIfPossibleConfiguratorObserveValue, null, null);

        NameDeletionConfigurator nameConfig = configurator.getNameDeletionConfig();
        IObservableValue observeSelectionbtnRemoveAllNameRelationshipsObserveWidget = WidgetProperties.selection().observe(btnRemoveAllNameRelationships);
        IObservableValue deleteRemoveAllNameRelationshipsConfiguratorObserveValue = PojoProperties.value("removeAllNameRelationships").observe(nameConfig);
        m_bindingContext.bindValue(observeSelectionbtnRemoveAllNameRelationshipsObserveWidget, deleteRemoveAllNameRelationshipsConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionbtnIgnoreIsBasionymObserveWidget = WidgetProperties.selection().observe(btnIgnoreIsBasionym);
        IObservableValue deleteIgnoreIsBasionymConfiguratorObserveValue = PojoProperties.value("ignoreIsBasionymFor").observe(nameConfig);
        m_bindingContext.bindValue(observeSelectionbtnIgnoreIsBasionymObserveWidget, deleteIgnoreIsBasionymConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionbtnIgnoreIsReplacedSynonymForObserveWidget = WidgetProperties.selection().observe(btnIgnoreIsReplacedSynonymFor);
        IObservableValue deleteIgnoreIsReplacedSynonymForConfiguratorObserveValue = PojoProperties.value("ignoreIsReplacedSynonymFor").observe(nameConfig);
        m_bindingContext.bindValue(observeSelectionbtnIgnoreIsReplacedSynonymForObserveWidget, deleteIgnoreIsReplacedSynonymForConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionbtnIgnoreHasBasionymObserveWidget = WidgetProperties.selection().observe(btnIgnoreHasBasionym);
        IObservableValue deleteIgnoreHasBasionymConfiguratorObserveValue = PojoProperties.value("ignoreHasBasionym").observe(nameConfig);
        m_bindingContext.bindValue(observeSelectionbtnIgnoreHasBasionymObserveWidget, deleteIgnoreHasBasionymConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionbtnIgnoreHasReplacedSynonymObserveWidget = WidgetProperties.selection().observe(btnIgnoreHasReplacedSynonym);
        IObservableValue deleteIgnoreHasReplacedSynonymConfiguratorObserveValue = PojoProperties.value("ignoreHasReplacedSynonym").observe(nameConfig);
        m_bindingContext.bindValue(observeSelectionbtnIgnoreHasReplacedSynonymObserveWidget, deleteIgnoreHasReplacedSynonymConfiguratorObserveValue, null, null);

        IObservableValue observeSelectionbtnRemoveAllTypeDesignationsObserveWidget = WidgetProperties.selection().observe(btnRemoveAllTypeDesignations);
        IObservableValue deleteRemoveAllTypeDesignationsConfiguratorObserveValue = PojoProperties.value("removeAllTypeDesignations").observe(nameConfig);
        m_bindingContext.bindValue(observeSelectionbtnRemoveAllTypeDesignationsObserveWidget, deleteRemoveAllTypeDesignationsConfiguratorObserveValue, null, null);


    }

  /* private Control createClassificationSelectionCombo(Composite parent){
//		classifications = CdmStore.getTaxonTreeService().list(null, null, null, null, null);

		Composite classificationSelection = new Composite(parent, SWT.NULL);
		classificationSelection.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, true));

		GridLayout layout = new GridLayout();
		classificationSelection.setLayout(layout);

		Label label = new Label(classificationSelection, SWT.NULL);
		// TODO not working is not really true but leave it here to remind everyone that this is under construction
		label.setText("Select Classification");
		classificationSelectionCombo = new Combo(classificationSelection, SWT.BORDER | SWT.READ_ONLY);
		classificationSelectionCombo.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, true));
		classifications = CdmStore.getService(IClassificationService.class).list(null, null, null, null, null);

		for(Classification tree : classifications){
			classificationSelectionCombo.add(tree.getName().getText(), classifications.indexOf(tree));

		}

		classificationSelectionCombo.select(0);
		classificationSelectionCombo.addSelectionListener(this);

		return classificationSelection;
	}*/

@Override
public void widgetSelected(SelectionEvent e) {
	selectedClassification = classifications.get(classificationSelectionCombo.getSelectionIndex());
}

@Override
public void widgetDefaultSelected(SelectionEvent e) {
	// TODO Auto-generated method stub

}
}
