/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.UUID;

import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IAgentService;
import eu.etaxonomy.cdm.model.agent.AgentBase;
import eu.etaxonomy.cdm.model.agent.INomenclaturalAuthor;
import eu.etaxonomy.cdm.persistence.dto.UuidAndTitleCache;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewPersonWizard;
import eu.etaxonomy.taxeditor.newWizard.NewTeamWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>FilteredAgentSelectionDialog class.</p>
 *
 * @author n.hoffmann
 * @created Sep 10, 2009
 * @version 1.0
 */
public class AgentSelectionDialog extends
		AbstractFilteredCdmResourceSelectionDialog<AgentBase> {

	/**
	 *
	 */
	protected static final String PERSON = "Person";
	/**
	 *
	 */
	protected static final String TEAM = "Team";

	protected static boolean selectTeamMember;

	/**
	 * <p>select</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param entity a {@link eu.etaxonomy.cdm.model.agent.AgentBase} object.
	 * @return a {@link eu.etaxonomy.cdm.model.agent.AgentBase} object.
	 */
	public static AgentBase select(Shell shell, ConversationHolder conversation, AgentBase entity, boolean selectTeamMember) {
		AgentSelectionDialog dialog = new AgentSelectionDialog(shell, conversation,
				"Choose Agent", false, AgentSelectionDialog.class.getCanonicalName(), entity, selectTeamMember);
		return getSelectionFromDialog(dialog);
	}

	/**
	 * <p>Constructor for FilteredAgentSelectionDialog.</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param title a {@link java.lang.String} object.
	 * @param agent a {@link eu.etaxonomy.cdm.model.agent.AgentBase} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param multi a boolean.
	 * @param settings a {@link java.lang.String} object.
	 */
	protected AgentSelectionDialog(Shell shell, ConversationHolder conversation, String title, boolean multi, String settings, AgentBase agent, boolean selectTeamMember) {
		super(shell, conversation, title, multi, settings, agent);
		this.selectTeamMember = selectTeamMember;
	}


	/**
	 * @author p.ciardelli
	 * @created 18.09.2009
	 * @version 1.0
	 */
	public class DetailsLabelProvider extends LabelProvider {
		/* (non-Javadoc)
		 * @see org.eclipse.jface.viewers.ILabelProvider#getText(java.lang.Object)
		 */
		@Override
        public String getText(Object element) {
			AgentBase agent = getCdmObjectByUuid(((UuidAndTitleCache<AgentBase>) element).getUuid());
			if (agent instanceof INomenclaturalAuthor) {
				return "Nomenclatural title: '" + ((INomenclaturalAuthor) agent).getNomenclaturalTitle() + "'";
			} else {
				return "'" + agent.getTitleCache() + "' is not a nomenclatural author.";
			}
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.AbstractFilteredCdmResourceSelectionDialog#getPersistentObect(java.util.UUID)
	 */
	/** {@inheritDoc} */
	@Override
	protected AgentBase getPersistentObject(UUID cdmUuid) {
		return CdmStore.getService(IAgentService.class).load(cdmUuid);
	}

	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		if(TEAM.equals(parameter)){
			return new NewTeamWizard();
		}
		else if(PERSON.equals(parameter)){
			return new NewPersonWizard();
		}
		else{
			throw new IllegalArgumentException("Could not determine the desired wizard.");
		}
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
		if (this.selectTeamMember){
			return String.format("Create a new <a>%1s</a>", PERSON);
		}
		return String.format("Create a new <a>%1s</a> or <a>%2s</a>", TEAM, PERSON);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.filteredSelection.AbstractFilteredCdmResourceSelectionDialog#getNewWizardLinkSelectionListener()
	 */
	@Override
	protected SelectionListener getNewWizardLinkSelectionListener() {
		return super.getNewWizardLinkSelectionListener();
	}

	/** {@inheritDoc} */
	@Override
	protected void initModel() {
	    Control control = getPatternControl();
        String pattern = null;
        if (control != null){
            pattern = ((Text)control).getText();
        }
        if (pattern == null || pattern.equals("?")){
            model = CdmStore.getService(IAgentService.class).getUuidAndTitleCache(null, null);
        }else{
            model = CdmStore.getService(IAgentService.class).getUuidAndTitleCache(limitOfInitialElements, pattern);
        }
	}


}
