/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.UUID;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IClassificationService;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>
 * FilteredClassificationSelectionDialog class.
 * </p>
 *
 * @author n.hoffmann
 * @created Sep 21, 2009
 * @version 1.0
 */
public class ClassificationSelectionDialog extends
		AbstractFilteredCdmResourceSelectionDialog<Classification> {

	/**
	 * <p>
	 * select
	 * </p>
	 *
	 * @param shell
	 *            a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation
	 *            a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder}
	 *            object.
	 * @param curentSelection
	 * @return a {@link eu.etaxonomy.cdm.model.taxon.TaxonomicTree} object.
	 */
	public static Classification select(Shell shell,
			ConversationHolder conversation, Classification curentSelection) {
		ClassificationSelectionDialog dialog = new ClassificationSelectionDialog(
				shell, conversation, "Choose a Classification", false, "", null);
		return getSelectionFromDialog(dialog);
	}

	/**
	 * <p>
	 * Constructor for FilteredClassificationSelectionDialog.
	 * </p>
	 *
	 * @param shell
	 *            a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param title
	 *            a {@link java.lang.String} object.
	 * @param multi
	 *            a boolean.
	 * @param settings
	 *            a {@link java.lang.String} object.
	 * @param conversation
	 *            a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder}
	 *            object.
	 * @param classification
	 *            a {@link eu.etaxonomy.cdm.model.taxon.TaxonomicTree} object.
	 */
	protected ClassificationSelectionDialog(Shell shell,
			ConversationHolder conversation, String title, boolean multi,
			String settings, Classification classification) {
		super(shell, conversation, title, multi, settings, classification);
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see
	 * org.eclipse.ui.dialogs.FilteredItemsSelectionDialog#createExtendedContentArea
	 * (org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	protected Control createExtendedContentArea(Composite parent) {
		return null;
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see
	 * eu.etaxonomy.taxeditor.dialogs.AbstractFilteredCdmResourceSelectionDialog
	 * #getPersistentObject(java.util.UUID)
	 */
	/** {@inheritDoc} */
	@Override
	protected Classification getPersistentObject(UUID cdmUuid) {
		return CdmStore.getService(IClassificationService.class).load(cdmUuid);
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see
	 * eu.etaxonomy.taxeditor.dialogs.AbstractFilteredCdmResourceSelectionDialog
	 * #initModel()
	 */
	/** {@inheritDoc} */
	@Override
	protected void initModel() {
	    Control control = getPatternControl();
        String pattern = null;
        if (control != null){
            pattern = ((Text)control).getText();
        }

        if (pattern == null || pattern.equals("?")){
            model = CdmStore.getService(IClassificationService.class).getUuidAndTitleCache(null, null);
        }else{
            model = CdmStore.getService(IClassificationService.class).getUuidAndTitleCache(limitOfInitialElements, pattern);
        }

	}

	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
		return null;
	}
}
