/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.UUID;

import org.eclipse.swt.widgets.Shell;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.ICollectionService;
import eu.etaxonomy.cdm.model.occurrence.Collection;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewCollectionWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>FilteredCollectionSelectionDialog class.</p>
 *
 * @author n.hoffmann
 * @created Oct 13, 2010
 * @version 1.0
 */
public class CollectionSelectionDialog extends
		AbstractFilteredCdmResourceSelectionDialog<Collection> {

	/**
	 * <p>select</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param collection a {@link eu.etaxonomy.cdm.model.occurrence.Collection} object.
	 * @return a {@link eu.etaxonomy.cdm.model.occurrence.Collection} object.
	 */
	public static Collection select(Shell shell, ConversationHolder conversation, Collection collection){
		CollectionSelectionDialog dialog = new CollectionSelectionDialog(shell, conversation,
				"Choose Collection", false, CollectionSelectionDialog.class.getCanonicalName(), collection);
		return getSelectionFromDialog(dialog);
	}

	/**
	 * <p>Constructor for FilteredCollectionSelectionDialog.</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param title a {@link java.lang.String} object.
	 * @param multi a boolean.
	 * @param settings a {@link java.lang.String} object.
	 * @param cdmObject a {@link eu.etaxonomy.cdm.model.occurrence.Collection} object.
	 */
	protected CollectionSelectionDialog(Shell shell,
			ConversationHolder conversation, String title, boolean multi,
			String settings, Collection cdmObject) {
		super(shell, conversation, title, multi, settings, cdmObject);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.filteredSelection.AbstractFilteredCdmResourceSelectionDialog#getPersistentObject(java.util.UUID)
	 */
	/** {@inheritDoc} */
	@Override
	protected Collection getPersistentObject(UUID uuid) {
		return CdmStore.getService(ICollectionService.class).load(uuid);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.filteredSelection.AbstractFilteredCdmResourceSelectionDialog#initModel()
	 */
	/** {@inheritDoc} */
	@Override
	protected void initModel() {
		model = CdmStore.getService(ICollectionService.class).getUuidAndTitleCache(null, null);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.filteredSelection.AbstractFilteredCdmResourceSelectionDialog#getNewWizardLinkText()
	 */
	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
        return String.format("Create a new <a>%1s</a>", "Collection ");
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.filteredSelection.AbstractFilteredCdmResourceSelectionDialog#getNewEntityWizard()
	 */
	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		return new NewCollectionWizard();
	}


}
