/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.UUID;

import org.eclipse.swt.widgets.Shell;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IOccurrenceService;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.occurrence.FieldUnit;
import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationBase;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewFieldUnitWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>FilteredFieldUnitSelectionDialog class.</p>
 *
 * @author n.hoffmann
 * @created Jun 17, 2010
 * @version 1.0
 */
public class FieldUnitSelectionDialog extends
		AbstractFilteredCdmResourceSelectionDialog<FieldUnit> {

	/**
	 * <p>select</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param observation a {@link eu.etaxonomy.cdm.model.occurrence.FieldUnit} object.
	 * @return a {@link eu.etaxonomy.cdm.model.occurrence.FieldUnit} object.
	 */
	public static FieldUnit select(Shell shell, ConversationHolder conversation, FieldUnit observation){
		FieldUnitSelectionDialog dialog = new FieldUnitSelectionDialog(shell, conversation,
				"Choose Derived Unit", false, FieldUnitSelectionDialog.class.getCanonicalName(), observation);
		return getSelectionFromDialog(dialog);
	}

	/**
	 * <p>Constructor for FilteredFieldUnitSelectionDialog.</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param title a {@link java.lang.String} object.
	 * @param multi a boolean.
	 * @param settings a {@link java.lang.String} object.
	 * @param cdmObject a {@link eu.etaxonomy.cdm.model.occurrence.FieldUnit} object.
	 */
	protected FieldUnitSelectionDialog(Shell shell, ConversationHolder conversation,
			String title, boolean multi, String settings,
			FieldUnit cdmObject) {
		super(shell, conversation, title, multi, settings, cdmObject);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.filteredSelection.AbstractFilteredCdmResourceSelectionDialog#getPersistentObject(java.util.UUID)
	 */
	/** {@inheritDoc} */
	@Override
	protected FieldUnit getPersistentObject(UUID uuid) {
		Object object = CdmStore.getService(IOccurrenceService.class).load(uuid);

		SpecimenOrObservationBase specimenObservationBase = (SpecimenOrObservationBase) HibernateProxyHelper.deproxy(object);

		if(specimenObservationBase instanceof FieldUnit){
			return (FieldUnit) specimenObservationBase;
		}
		MessagingUtils.error(this.getClass(), "Selected object is not a field unit", null);
		return null;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.filteredSelection.AbstractFilteredCdmResourceSelectionDialog#initModel()
	 */
	/** {@inheritDoc} */
	@Override
	protected void initModel() {
		model = CdmStore.getService(IOccurrenceService.class).getFieldUnitUuidAndTitleCache();
	}

	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		return new NewFieldUnitWizard();
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
		return String.format("Create a new <a>%1s</a>", "Field Unit ");
	}
}
