/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.UUID;

import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.INameService;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewNonViralNameWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author n.hoffmann
 * @created 04.06.2009
 * @version 1.0
 */
public class NameSelectionDialog extends AbstractFilteredCdmResourceSelectionDialog<TaxonNameBase> {

	public static TaxonNameBase select(Shell shell, ConversationHolder conversation, TaxonNameBase name) {
		NameSelectionDialog dialog = new NameSelectionDialog(shell, conversation,
				"Choose a name", false, name);
		return getSelectionFromDialog(dialog);
	}

	protected NameSelectionDialog(Shell shell, ConversationHolder conversation, String title, boolean multi, TaxonNameBase name) {
		super(shell, conversation, title, multi, NameSelectionDialog.class.getCanonicalName(), name);
	}

	/** {@inheritDoc} */
	@Override
	protected TaxonNameBase getPersistentObject(UUID cdmUuid) {
		return CdmStore.getService(INameService.class).load(cdmUuid);
	}

	/** {@inheritDoc} */
	@Override
	protected void initModel() {
	    Control control = getPatternControl();
        String pattern = null;
        if (control != null){
            pattern = ((Text)control).getText();
        }

        if (pattern == null || pattern.equals("?")){
            model = CdmStore.getService(INameService.class).getUuidAndTitleCache(null, null);
        }else{
            model = CdmStore.getService(INameService.class).getUuidAndTitleCache(limitOfInitialElements, pattern);
        }
	}

	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		return new NewNonViralNameWizard();
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
		return String.format("Create a new <a>%1s</a>", "Name ");
	}
}
