/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.dialog.selection;



import java.text.Collator;
import java.util.Comparator;

import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IAgentService;
import eu.etaxonomy.cdm.model.agent.AgentBase;
import eu.etaxonomy.cdm.model.agent.TeamOrPersonBase;
import eu.etaxonomy.cdm.persistence.dto.UuidAndTitleCache;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewPersonWizard;
import eu.etaxonomy.taxeditor.newWizard.NewTeamWizard;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author k.luther
 * @date 25.05.2016
 *
 */
public class NomenclaturalAuthorSelectionDialog extends AgentSelectionDialog {


    /**
     * @param shell
     * @param conversation
     * @param title
     * @param multi
     * @param settings
     * @param agent
     */
    protected NomenclaturalAuthorSelectionDialog(Shell shell, ConversationHolder conversation, String title,
            boolean multi, String settings, AgentBase agent, boolean teamMemberSelection) {
        super(shell, conversation, title, multi, settings, agent, teamMemberSelection);
        // TODO Auto-generated constructor stub
    }

    @Override
    protected void initModel() {
        Control control = getPatternControl();
        String pattern = null;
        if (control != null){
            pattern = ((Text)control).getText();
        }
        if (pattern == null || pattern.equals("?")){
            model = CdmStore.getService(IAgentService.class).getUuidAndAbbrevTitleCache(null, null, null);
        }else{
            model = CdmStore.getService(IAgentService.class).getUuidAndAbbrevTitleCache(limitOfInitialElements, pattern, null);
        }
    }

    /** {@inheritDoc} */
    @Override
    protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
        if(TEAM.equals(parameter)){
            return new NewTeamWizard(true);
        }
        else if(PERSON.equals(parameter)){
            return new NewPersonWizard();
        }
        else{
            throw new IllegalArgumentException("Could not determine the desired wizard.");
        }
    }
    /**
	 *
	 * @return
	 */
    @Override
	protected ILabelProvider createListLabelProvider() {
		return new FilteredCdmResourceAbbrevLabelProvider();
	}

    /**
     * <p>select</p>
     *
     * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
     * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
     * @param entity a {@link eu.etaxonomy.cdm.model.agent.AgentBase} object.
     * @return a {@link eu.etaxonomy.cdm.model.agent.AgentBase} object.
     */
    public static AgentBase select(Shell shell, ConversationHolder conversation, AgentBase entity, boolean teamMemberSelection) {
        NomenclaturalAuthorSelectionDialog dialog = new NomenclaturalAuthorSelectionDialog(shell, conversation,
                "Choose Agent", false, NomenclaturalAuthorSelectionDialog.class.getCanonicalName(), entity, teamMemberSelection);
        return getSelectionFromDialog(dialog);
    }

    /**
     * <p>getTitle</p>
     *
     * @param cdmObject a T object.
     * @return a {@link java.lang.String} object.
     */
    @Override
    protected String getTitle(AgentBase cdmObject) {
        if(cdmObject == null){
            return "";
        }

        if (cdmObject instanceof TeamOrPersonBase) {
            return ((TeamOrPersonBase) cdmObject).getNomenclaturalTitle();
        } else if (cdmObject instanceof AgentBase){
            return ((TeamOrPersonBase) cdmObject).getTitleCache();
        }

        throw new IllegalArgumentException("Generic method only" +
                " supports cdmObject of type IIdentifiableEntity." +
                " Please implement specific method in subclass.");
    }



    public class FilteredCdmResourceAbbrevLabelProvider extends LabelProvider {
		@Override
		public String getText(Object element) {
			if (element == null) {
				return null;
			}
			UuidAndTitleCache uuidAndTitleCache = (UuidAndTitleCache) element;
			String titleCache = uuidAndTitleCache.getTitleCache();
			String abbrevTitleCache = uuidAndTitleCache.getAbbrevTitleCache();
			if (!titleCache.equals(abbrevTitleCache)){
				abbrevTitleCache += " - " + titleCache;
			}
			if(PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_ID_IN_ENTITY_SELECTION_DIAOLOG)){
				abbrevTitleCache += " ["+uuidAndTitleCache.getId()+"]";
			}
            return abbrevTitleCache;
		}
	};

	/** {@inheritDoc} */
	@Override
	protected ItemsFilter createFilter() {
		return new ItemsFilter() {

			/**
			 * Always returns false to enforce refiltering even if the pattern is equal
			 */
			@Override
			public boolean equalsFilter(ItemsFilter filter) {
				return false;
			}

			@Override
			public boolean isConsistentItem(Object item) {
				return false;
			}

			@Override
			public boolean matchItem(Object item) {
				String textTitleCache = null;
				String abbrevTitleCache = null;
				if(item instanceof UuidAndTitleCache){
					if (((UuidAndTitleCache) item).getAbbrevTitleCache() != null){
						abbrevTitleCache = ((UuidAndTitleCache) item).getAbbrevTitleCache();
					}
					if (((UuidAndTitleCache) item).getTitleCache() != null ){
						textTitleCache = ((UuidAndTitleCache) item).getTitleCache();
					}
				}else if(item instanceof String){
					textTitleCache = (String) item;
				}

				return  (matches(textTitleCache) || matches(abbrevTitleCache)) ;

			}

		};
	}

	@Override
	protected Comparator getItemsComparator() {
		return new Comparator<UuidAndTitleCache>() {
			@Override
			public int compare(UuidAndTitleCache entity1,
					UuidAndTitleCache entity2) {

			    if (entity1.getUuid().equals(entity2.getUuid())){
			        return 0;
			    }
				Collator collator = Collator.getInstance();
				String compareString1 = "";
				if (entity1.getAbbrevTitleCache() != null){
					compareString1 = entity1.getAbbrevTitleCache();
				}
				if (entity1.getTitleCache() != null){
					compareString1 += entity1.getTitleCache();
				}


				String compareString2 = "";
				if (entity2.getAbbrevTitleCache() != null){
					compareString2 = entity2.getAbbrevTitleCache();
				}
				if (entity2.getTitleCache() != null){
					compareString2 += entity2.getTitleCache();
				}


				int result =collator.compare(compareString1, compareString2);
				if (result == 0){
				    result = entity1.getUuid().compareTo(entity2.getUuid());
				}
				return result;
			}
		};
	}


}
