/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.UUID;

import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IAgentService;
import eu.etaxonomy.cdm.model.agent.AgentBase;
import eu.etaxonomy.cdm.model.agent.Team;
import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewTeamWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>FilteredNomenclaturalAuthorTeamSelectionDialog class.</p>
 *
 * @author n.hoffmann
 * @created Jun 22, 2010
 * @version 1.0
 */
public class NomenclaturalAuthorTeamSelectionDialog extends
	AbstractFilteredCdmResourceSelectionDialog<AgentBase> {

	/**
	 * <p>select</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param team a {@link eu.etaxonomy.cdm.model.agent.Team} object.
	 * @return a {@link eu.etaxonomy.cdm.model.agent.Team} object.
	 */
	public static Team select(Shell shell, ConversationHolder conversation, Team team){
		NomenclaturalAuthorTeamSelectionDialog dialog = new NomenclaturalAuthorTeamSelectionDialog(shell, conversation,
				"Choose Author Team", false, NomenclaturalAuthorTeamSelectionDialog.class.getCanonicalName(), team);
		return (Team)getSelectionFromDialog(dialog);
	}

	/**
	 * <p>Constructor for FilteredNomenclaturalAuthorTeamSelectionDialog.</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param title a {@link java.lang.String} object.
	 * @param multi a boolean.
	 * @param settings a {@link java.lang.String} object.
	 * @param agent a {@link eu.etaxonomy.cdm.model.agent.Team} object.
	 */
	protected NomenclaturalAuthorTeamSelectionDialog(Shell shell, ConversationHolder conversation, String title,
			boolean multi, String settings, Team agent) {
		super(shell, conversation, title, multi, settings, agent);
	}

	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		return new NewTeamWizard(true);
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
		return String.format("Create a new <a>%1s</a>", "Team ");
	}

	/** {@inheritDoc} */
	@Override
	protected void initModel() {
	    Control control = getPatternControl();
        String pattern = null;
        if (control != null){
            pattern = ((Text)control).getText();
        }

		model = CdmStore.getService(IAgentService.class).getUuidAndAbbrevTitleCache(limitOfInitialElements, pattern, Team.class);
	}

	/** {@inheritDoc} */
	@Override
	protected Team getPersistentObject(UUID uuid) {
		return CdmBase.deproxy(CdmStore.getService(IAgentService.class).load(uuid), Team.class) ;
	}
}
