package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.text.Collator;
import java.util.Comparator;

import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IReferenceService;
import eu.etaxonomy.cdm.model.agent.TeamOrPersonBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.persistence.dto.UuidAndTitleCache;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;

public class NomenclaturalReferenceSelectionDialog extends
		ReferenceSelectionDialog {

    private TeamOrPersonBase author;
    private boolean firstCall = true;

	protected NomenclaturalReferenceSelectionDialog(Shell shell,
			ConversationHolder conversation, String title, boolean multi,
			Reference reference, boolean inReference, TeamOrPersonBase author) {
		super(shell, conversation, title, multi, reference);
		this.author = author;
		firstCall = true;

	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.AbstractFilteredCdmResourceSelectionDialog#initModel()
	 */
	/** {@inheritDoc} */
	@Override
	protected void initModel() {
	    Control control = getPatternControl();
        String pattern = null;
        if (control != null){
            pattern = ((Text)control).getText();

        }
        if (firstCall && author != null){
            pattern = author.getNomenclaturalTitle();
            if (control!= null){
                firstCall = false;
                ((Text)control).setText(pattern);
            }

        }

        if (pattern == null || pattern.equals("?")){
            model = CdmStore.getService(IReferenceService.class).getUuidAndAbbrevTitleCache(null, null);
        }else{
            model = CdmStore.getService(IReferenceService.class).getUuidAndAbbrevTitleCache(limitOfInitialElements, pattern);
        }
        System.out.println("2");
	}

	/**
	 *
	 * @return
	 */
   @Override
	protected ILabelProvider createListLabelProvider() {
		return new FilteredCdmResourceAbbrevLabelProvider();
	}

	/**
	 * <p>select</p>
	 *
	 * @param reference a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @return a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
	 */

	public static Reference select(Shell shell, ConversationHolder conversation, Reference reference, TeamOrPersonBase author) {
		NomenclaturalReferenceSelectionDialog dialog = new NomenclaturalReferenceSelectionDialog(shell, conversation,
				"Choose a reference", isInReference, reference, false, author);
		return getSelectionFromDialog(dialog);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.dialogs.FilteredItemsSelectionDialog#createFilter()
	 */
	/** {@inheritDoc} */
	@Override
	protected ItemsFilter createFilter() {
		return new ItemsFilter() {

			/**
			 * Always returns false to enforce refiltering even if the pattern is equal
			 */
			@Override
			public boolean equalsFilter(ItemsFilter filter) {
				return false;
			}

			@Override
			public boolean isConsistentItem(Object item) {
				return false;
			}

			@Override
			public boolean matchItem(Object item) {
				return true;
//				String text = null;
//				if(item instanceof UuidAndTitleCache){
//					if (((UuidAndTitleCache) item).getAbbrevTitleCache() != null){
//						text = ((UuidAndTitleCache) item).getAbbrevTitleCache();
//					} else{
//						text = ((UuidAndTitleCache) item).getTitleCache();
//					}
//				}else if(item instanceof String){
//					text = (String) item;
//				}
//				return text != null ? matches(text) : false;
			}

		};
	}



	public class FilteredCdmResourceAbbrevLabelProvider extends LabelProvider {
		@Override
		public String getText(Object element) {
			if (element == null) {
				return null;
			}
			UuidAndTitleCache uuidAndTitleCache = (UuidAndTitleCache) element;
			String titleCache = uuidAndTitleCache.getTitleCache();
			String abbrevTitleCache = uuidAndTitleCache.getAbbrevTitleCache();
			if (!abbrevTitleCache.equals(titleCache)){
				abbrevTitleCache += " - " + titleCache;
			}
			if(PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_ID_IN_ENTITY_SELECTION_DIAOLOG)){
				abbrevTitleCache += " ["+uuidAndTitleCache.getId()+"]";
			}
            return abbrevTitleCache;
		}
	};

	@Override
    protected Comparator getItemsComparator() {
        return new Comparator<UuidAndTitleCache>() {
            @Override
            public int compare(UuidAndTitleCache entity1,
                    UuidAndTitleCache entity2) {

                if (entity1.getUuid().equals(entity2.getUuid())){
                    return 0;
                }
                Collator collator = Collator.getInstance();
                String compareString1 = "";
                if (entity1.getAbbrevTitleCache() != null){
                    compareString1 = entity1.getAbbrevTitleCache();
                }
                if (entity1.getTitleCache() != null){
                    compareString1 += entity1.getTitleCache();
                }


                String compareString2 = "";
                if (entity2.getAbbrevTitleCache() != null){
                    compareString2 = entity2.getAbbrevTitleCache();
                }
                if (entity2.getTitleCache() != null){
                    compareString2 += entity2.getTitleCache();
                }


                int result =collator.compare(compareString1, compareString2);
                if (result == 0){
                    result = entity1.getUuid().compareTo(entity2.getUuid());
                }
                return result;
            }
        };
    }
	@Override
	protected String getTitle(Reference cdmObject) {
        if(cdmObject == null){
            return "";
        }
        if (cdmObject.getAbbrevTitle() != null){
            return cdmObject.getAbbrevTitleCache();
        }else{
            return cdmObject.getTitleCache();
        }



    }




}
