/**
 * Copyright (C) 2014 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.UUID;

import org.eclipse.swt.widgets.Shell;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.molecular.IPrimerService;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.molecular.Primer;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewPrimerWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author pplitzner
 * @date 11.03.2014
 *
 */
public class PrimerSelectionDialog extends
AbstractFilteredCdmResourceSelectionDialog<Primer> {

    public static Primer select(Shell shell, ConversationHolder conversation, Primer primer){
        PrimerSelectionDialog dialog = new PrimerSelectionDialog(shell, conversation,
                "Choose Primer", false, PrimerSelectionDialog.class.getCanonicalName(), primer);
        return getSelectionFromDialog(dialog);
    }

    /**
     * <p>Constructor for FilteredDerivedUnitSelectionDialog.</p>
     */
    protected PrimerSelectionDialog(Shell shell, ConversationHolder conversation, String title,
            boolean multi, String settings, Primer cdmObject) {
        super(shell, conversation, title, multi, settings, cdmObject);
    }

    /** {@inheritDoc} */
    @Override
    protected Primer getPersistentObject(UUID uuid) {
        Object object = CdmStore.getService(IPrimerService.class).load(uuid);

        Primer primer = (Primer) HibernateProxyHelper.deproxy(object);

        if(primer != null){
            return primer;
        }
        MessagingUtils.error(this.getClass(), "Selected element is not a primer", null);
        return null;
    }

    /** {@inheritDoc} */
    @Override
    protected void initModel() {
        model = CdmStore.getService(IPrimerService.class).getPrimerUuidAndTitleCache();
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.ui.dialog.selection.AbstractFilteredCdmResourceSelectionDialog#getTitle(eu.etaxonomy.cdm.model.common.ICdmBase)
     */
    @Override
    protected String getTitle(Primer cdmObject) {
        if(cdmObject!=null){
            return cdmObject.getLabel();
        }
        return super.getTitle(cdmObject);
    }

    /** {@inheritDoc} */
    @Override
    protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
        return new NewPrimerWizard();
    }

    /** {@inheritDoc} */
    @Override
    protected String getNewWizardLinkText() {
        return String.format("Create a new <a>%1s</a>", "Primer ");
    }
}
