/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.UUID;

import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IReferenceService;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewReferenceWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>FilteredReferenceSelectionDialog class.</p>
 *
 * @author n.hoffmann
 * @created 04.06.2009
 * @version 1.0
 */
public class ReferenceSelectionDialog extends AbstractFilteredCdmResourceSelectionDialog<Reference> {

    protected static boolean isInReference = false;
    private Reference currentReference;

	/**
	 * <p>select</p>
	 *
	 * @param reference a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @return a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
	 */
	public static Reference select(Shell shell, ConversationHolder conversation, Reference reference, boolean isInReference) {
		ReferenceSelectionDialog dialog = new ReferenceSelectionDialog(shell, conversation,
				"Choose a reference", false, reference, isInReference);
		return getSelectionFromDialog(dialog);
	}

	/**
     * <p>select</p>
     *
     * @param reference a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
     * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
     * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
     * @return a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
     */
    public static Reference select(Shell shell, ConversationHolder conversation, Reference reference) {
        ReferenceSelectionDialog dialog = new ReferenceSelectionDialog(shell, conversation,
                "Choose a reference", false, reference);
        return getSelectionFromDialog(dialog);
    }



	/**
	 * <p>Constructor for FilteredReferenceSelectionDialog.</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param title a {@link java.lang.String} object.
	 * @param reference a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param multi a boolean.
	 */
	protected ReferenceSelectionDialog(Shell shell, ConversationHolder conversation, String title, boolean multi, Reference reference) {
		super(shell, conversation, title, multi, ReferenceSelectionDialog.class.getCanonicalName(), null);
		this.currentReference = reference;


	}




	/**
     * <p>Constructor for FilteredReferenceSelectionDialog.</p>
     *
     * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
     * @param title a {@link java.lang.String} object.
     * @param reference a {@link eu.etaxonomy.cdm.model.reference.ReferenceBase} object.
     * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
     * @param multi a boolean.
     */
    protected ReferenceSelectionDialog(Shell shell, ConversationHolder conversation, String title, boolean multi, Reference reference, boolean isInReference) {
        super(shell, conversation, title, multi, ReferenceSelectionDialog.class.getCanonicalName(), null);
        this.isInReference = isInReference;
        this.currentReference = reference;

    }


	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.AbstractFilteredCdmResourceSelectionDialog#getPersistentObject(java.util.UUID)
	 */
	/** {@inheritDoc} */
	@Override
	protected Reference getPersistentObject(UUID cdmUuid) {
		return CdmStore.getService(IReferenceService.class).load(cdmUuid);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.AbstractFilteredCdmResourceSelectionDialog#initModel()
	 */
	/** {@inheritDoc} */
	@Override
	protected void initModel() {
	    Control control = getPatternControl();
        String pattern = null;
        if (control != null){
            pattern = ((Text)control).getText();
        }

        if (pattern == null || pattern.equals("?")){
            if (isInReference && currentReference != null){
                model = CdmStore.getService(IReferenceService.class).getUuidAndTitleCache(null,null,currentReference.getType());
            }else{
                model = CdmStore.getService(IReferenceService.class).getUuidAndTitleCache(null,null);
            }
        }else{
            if (isInReference && currentReference != null){
                model = CdmStore.getService(IReferenceService.class).getUuidAndTitleCache(limitOfInitialElements,pattern, currentReference.getType());
            }else{
                model = CdmStore.getService(IReferenceService.class).getUuidAndTitleCache(limitOfInitialElements,pattern);
            }
        }
	}


	/** {@inheritDoc} */
	@Override
	protected String getTitle(Reference cdmObject) {
		if(cdmObject == null){
			return "";
		}else{
			return super.getTitle(cdmObject);
		}
//		}else{
//			return DefaultReferenceCacheStrategy.putAuthorToEndOfString(cdmObject.getTitleCache(), cdmObject.getAuthorship().getTitleCache());
//		}
	}

	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		return new NewReferenceWizard();
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
		return String.format("Create a new <a>%1s</a>", "Reference ");
	}

}
