/**
 *
 */
package eu.etaxonomy.taxeditor.ui.dialog.selection;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.UUID;

import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IClassificationService;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author p.ciardelli
 * @version $Id: $
 */
public class TaxonNodeSelectionDialog extends AbstractFilteredCdmResourceSelectionDialog<TaxonNode> implements SelectionListener{

	public static TaxonNode select(Shell shell, ConversationHolder conversation, String title, List<UUID> excludeTaxa, TaxonNode node, Classification classification) {
		TaxonNodeSelectionDialog dialog = new TaxonNodeSelectionDialog(shell,
				conversation,
				title,
				excludeTaxa,
				false,
				node,
				classification);
		return getSelectionFromDialog(dialog);
	}

	private Combo classificationSelectionCombo;

	private List<Classification> classifications;

	private Classification selectedClassification;
	private final List<UUID> excludeTaxa;

	protected TaxonNodeSelectionDialog(Shell shell, ConversationHolder conversation, String title, List<UUID> excludeTaxa, boolean multi, TaxonNode node, Classification classification) {
		super(shell, conversation, title, multi, TaxonNodeSelectionDialog.class.getCanonicalName(), node);

		ILabelProvider labelProvider = new FilteredCdmResourceLabelProvider();

		setListLabelProvider(labelProvider);
		setDetailsLabelProvider(labelProvider);
		this.excludeTaxa = excludeTaxa;
		if(classification != null){
			selectedClassification = classification;
		}
		initModel();
	}

	/** {@inheritDoc} */
	@Override
	protected Control createExtendedContentArea(Composite parent) {
		return createClassificationSelectionCombo(parent);
	}

	/*
	 * currently disabled tree selection composite
	 */
	private Control createClassificationSelectionCombo(Composite parent){
//		classifications = CdmStore.getTaxonTreeService().list(null, null, null, null, null);

		Composite classificationSelection = new Composite(parent, SWT.NULL);
		classificationSelection.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));

		GridLayout layout = new GridLayout();
		classificationSelection.setLayout(layout);

		Label label = new Label(classificationSelection, SWT.NULL);
		// TODO not working is not really true but leave it here to remind everyone that this is under construction
		label.setText("Select Classification");
		classificationSelectionCombo = new Combo(classificationSelection, SWT.BORDER | SWT.READ_ONLY);
		classificationSelectionCombo.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, true));

		for(Classification tree : classifications){
			classificationSelectionCombo.add(tree.getName().getText(), classifications.indexOf(tree));

		}

		classificationSelectionCombo.select(classifications.indexOf(selectedClassification));

		// TODO remember last selection
		classificationSelectionCombo.addSelectionListener(this);



		return classificationSelection;
	}

	/** {@inheritDoc} */
	@Override
	protected String getTitle(TaxonNode taxonNode) {
		if(taxonNode != null && taxonNode.getTaxon() != null){
			return taxonNode.getTaxon().getTitleCache();
		}

		return "";
	}

	/** {@inheritDoc} */
	@Override
	protected TaxonNode getPersistentObject(UUID uuid) {
		return CdmStore.getService(IClassificationService.class).getTaxonNodeByUuid(uuid);
	}

	/** {@inheritDoc} */
	@Override
	protected void initModel() {
		// default to first tree
		// TODO this will be problematic and can only be seen as workaround

	    Control control = getPatternControl();
        String pattern = null;
        if (control != null){
            pattern = ((Text)control).getText();
        }


		if(classifications == null){
			classifications = CdmStore.getService(IClassificationService.class).list(null, null, null, null, null);
			Collections.sort(classifications, new Comparator<Classification>() {

                @Override
                public int compare(Classification o1, Classification o2) {
                    if (o1.equals(o2)){
                        return 0;
                    }
                    int result = o1.getTitleCache().compareTo(o2.getTitleCache());
                    if (result == 0){
                        return o1.getUuid().compareTo(o2.getUuid());
                    }
                    return result;
                }
            });
			if (this.cdmBaseToBeFiltered == null){
			    selectedClassification = classifications.iterator().next();
			} else {
			    selectedClassification = this.cdmBaseToBeFiltered.getClassification();
			}
		}
		if (pattern == null || pattern.equals("?")){
		    model = CdmStore.getService(IClassificationService.class).getTaxonNodeUuidAndTitleCacheOfAcceptedTaxaByClassification(selectedClassification.getUuid(),  limitOfInitialElements, pattern);
		}else{
		    model = CdmStore.getService(IClassificationService.class).getTaxonNodeUuidAndTitleCacheOfAcceptedTaxaByClassification(selectedClassification.getUuid(),  null, null);
		}
	}

	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
		return null;
	}

	/** {@inheritDoc} */
	@Override
    public void widgetSelected(SelectionEvent e) {
		selectedClassification = classifications.get(classificationSelectionCombo.getSelectionIndex());

//		refresh();
		setPattern(null);
	}

	/** {@inheritDoc} */
	@Override
    public void widgetDefaultSelected(SelectionEvent e) {}


}
