/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.element;



/**
 * Implementors of this interface provide a {@link SelectionArbitrator}.<br>
 * The arbitrator allows the element to be selected to show e.g.
 * supplemental data.<br>
 * An arbitrator can be added like in the following code example:
 * <br>
 * <br>
 * <pre>
 * //make element selectable
 *  if(cdmFormFactory.getSelectionProvider() != null){
 *     selectionArbitrator = cdmFormFactory.createSelectionArbitrator(this);
 *  }
 *  </pre>
 *
 * @author n.hoffmann
 * @created Mar 5, 2010
 * @version 1.0
 */
public interface ISelectableElement {

	/**
	 * Returns this elements selection arbitrator
	 *
	 * @return a {@link eu.etaxonomy.taxeditor.ui.element.SelectionArbitrator} object.
	 */
	public SelectionArbitrator getSelectionArbitrator();
}
