/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.element;

import org.eclipse.ui.forms.widgets.TableWrapData;
import org.eclipse.ui.forms.widgets.TableWrapLayout;

/**
 * @author n.hoffmann
 * @date Jan 25, 2012
 *
 */
public class LayoutConstants {

	/**
	 * <p>
	 * LAYOUT
	 * </p>
	 * 
	 * @return a {@link org.eclipse.ui.forms.widgets.TableWrapLayout} object.
	 */
	public static final TableWrapLayout LAYOUT() {
		return LayoutConstants.LAYOUT(1, false);
	}

	/**
	 * <p>
	 * LAYOUT
	 * </p>
	 * 
	 * @param columns
	 *            a int.
	 * @param equalWidth
	 *            a boolean.
	 * @return a {@link org.eclipse.ui.forms.widgets.TableWrapLayout} object.
	 */
	public static final TableWrapLayout LAYOUT(int columns, boolean equalWidth) {
		TableWrapLayout layout = new TableWrapLayout();
		layout.topMargin = 0;
		layout.rightMargin = 0;
		layout.bottomMargin = 0;
		layout.leftMargin = 0;
		layout.numColumns = columns;
		layout.makeColumnsEqualWidth = equalWidth;
		layout.verticalSpacing = 0;
		layout.horizontalSpacing = 0;
		return layout;
	}

	/**
	 * <p>
	 * FILL
	 * </p>
	 * 
	 * @return a {@link org.eclipse.ui.forms.widgets.TableWrapData} object.
	 */
	public static final TableWrapData FILL() {
		return LayoutConstants.FILL(1, 1);
	}

	/**
	 * <p>
	 * FILL
	 * </p>
	 * 
	 * @param horizontalSpan
	 *            a int.
	 * @param verticalSpan
	 *            a int.
	 * @return a {@link org.eclipse.ui.forms.widgets.TableWrapData} object.
	 */
	public static final TableWrapData FILL(int horizontalSpan, int verticalSpan) {
		TableWrapData layoutData = new TableWrapData(TableWrapData.FILL_GRAB,
				TableWrapData.FILL_GRAB);
		layoutData.colspan = horizontalSpan;
		layoutData.rowspan = verticalSpan;
		return layoutData;
	}

	/**
	 * <p>
	 * LEFT
	 * </p>
	 * 
	 * @return a {@link org.eclipse.ui.forms.widgets.TableWrapData} object.
	 */
	public static final TableWrapData LEFT() {
		return new TableWrapData(TableWrapData.LEFT, TableWrapData.TOP);
	}

	/**
	 * <p>
	 * RIGHT
	 * </p>
	 * 
	 * @return a {@link org.eclipse.ui.forms.widgets.TableWrapData} object.
	 */
	public static final TableWrapData RIGHT() {
		return new TableWrapData(TableWrapData.RIGHT, TableWrapData.TOP);
	}

	/**
	 * <p>
	 * FILL_HORIZONTALLY
	 * </p>
	 * 
	 * @return a {@link org.eclipse.ui.forms.widgets.TableWrapData} object.
	 */
	public static final TableWrapData FILL_HORIZONTALLY() {
		return LayoutConstants.FILL_HORIZONTALLY(1, 1);
	}

	/**
	 * <p>
	 * FILL_HORIZONTALLY
	 * </p>
	 * 
	 * @param horizontalSpan
	 *            a int.
	 * @param verticalSpan
	 *            a int.
	 * @return a {@link org.eclipse.ui.forms.widgets.TableWrapData} object.
	 */
	public static final TableWrapData FILL_HORIZONTALLY(int horizontalSpan,
			int verticalSpan) {
		TableWrapData layoutData = new TableWrapData(TableWrapData.FILL_GRAB,
				TableWrapData.TOP);
		layoutData.colspan = horizontalSpan;
		layoutData.rowspan = verticalSpan;
		return layoutData;
	}

}
