/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.element;

/**
 * @author k.luther
 * @date 22.06.2016
 *
 */

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Button;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.common.Representation;
import eu.etaxonomy.cdm.model.common.TermBase;
import eu.etaxonomy.cdm.model.common.TermType;
import eu.etaxonomy.taxeditor.model.DefaultTermComparator;
import eu.etaxonomy.taxeditor.model.ImageResources;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.combo.TermComboElement;


public class RepresentationElement  extends AbstractCdmFormElement implements
SelectionListener{

        protected TermComboElement<Language> combo_language;

        protected TextWithLabelElement element_Label;
        protected TextWithLabelElement element_abbrevLabel;
        protected TextWithLabelElement element_text;

        protected Button button;
       
        protected Representation selectedRepresentation;
        protected TermBase term;

		private Button removeRepresentation;

       // protected final boolean isTranslationWizard;


        /**
         * <p>
         * Constructor for MultilanguageTextElement.
         * </p>
         *
         * @param formFactory
         *            a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory}
         *            object.
         * @param formElement
         *            a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement}
         *            object.
         *
         * @param term
         *            a {@link eu.etaxonomy.cdm.model.common.TermBase} object.
         * @param textHeight
         *            a {@link java.lang.Integer} object.
         * @param style
         *            a int.
         */
        public RepresentationElement(CdmFormFactory formFactory,
                ICdmFormElement formElement, TermBase term,
                Integer textHeight, int style, boolean fill) {
            super(formFactory, formElement);

            formFactory.addPropertyChangeListener(this);

            element_Label = this.formFactory.createTextWithLabelElement(formElement, "Label", null, style);
            element_abbrevLabel = this.formFactory
                    .createTextWithLabelElement(formElement, "abbrev. Label",
                            null, style);
            element_text = this.formFactory.createMultiLineTextWithLabel(formElement, "Description", textHeight, style);
            if (PreferencesUtil.isMultilanguageTextEditingCapability()) {
                createRepresentationEditingElements(formElement, style);
            }
            setTerm(term, fill);

        }

        /**
         * <p>
         * Constructor for MultilanguageTextElement.
         * </p>
         *
         * @param formFactory
         *            a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory}
         *            object.
         * @param formElement
         *            a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement}
         *            object.
         * @param representation
         *            a {@link eu.etaxonomy.cdm.model.common.Representation} object.
         * @param term
         *            a {@link eu.etaxonomy.cdm.model.common.TermBase} object.
         * @param textHeight
         *            a {@link java.lang.Integer} object.
         * @param style
         *            a int.
         */
        public RepresentationElement(CdmFormFactory formFactory,
                ICdmFormElement formElement, Representation representation, TermBase term,
                Integer textHeight, int style, boolean fill) {
            super(formFactory, formElement);

            formFactory.addPropertyChangeListener(this);

            element_Label = this.formFactory.createTextWithLabelElement(formElement, "Label", null, style);
            element_abbrevLabel = this.formFactory
                    .createTextWithLabelElement(formElement, "abbrev. Label",
                            null, style);
            element_text = this.formFactory.createMultiLineTextWithLabel(formElement, "Description", textHeight, style);
            if (PreferencesUtil.isMultilanguageTextEditingCapability()) {
                createRepresentationEditingElements(formElement, style);
            }
            setTerm(term, fill);
            setSelectedRepresentation(representation);


        }

        protected void createRepresentationEditingElements(
                ICdmFormElement formElement, int style) {
        	removeRepresentation = formFactory.createButton(getLayoutComposite(), null,
    				SWT.PUSH);
    		removeRepresentation.setImage(ImageResources
    				.getImage(ImageResources.TRASH_ICON));
    		removeRepresentation.setToolTipText("Remove representation");
    		removeRepresentation.addSelectionListener(new DeleteListener(this));
    		addControl(removeRepresentation);
    		
            combo_language = formFactory.createDefinedTermComboElement(TermType.Language, formElement,
                            "", null, false, style);

            combo_language.addSelectionListener(this);
            
            //addControl(formFactory.createLabel(getLayoutComposite(), ""));
       }

        public List<Language> getLanguages() {

            ArrayList<Language> languageList = new ArrayList<Language>();
            for (Representation rep: term.getRepresentations()){
                languageList.add(rep.getLanguage());
            }

            Collections.sort(languageList, new DefaultTermComparator<Language>());

            return languageList;
        }

        /*
         * (non-Javadoc)
         *
         * @see
         * org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt
         * .events.SelectionEvent)
         */
        /** {@inheritDoc} */
        @Override
        public void widgetSelected(SelectionEvent e) {
            Language selectedLanguage = combo_language.getSelection();
            if (selectedLanguage != null) {
                selectedRepresentation = getTerm().getRepresentation(
                        selectedLanguage);
                if (selectedRepresentation == null){
                    selectedRepresentation = Representation.NewInstance("", "", "", selectedLanguage);
                }
                element_Label.setText(selectedRepresentation.getLabel());
                element_abbrevLabel.setText(selectedRepresentation.getAbbreviatedLabel());
                element_text.setText(selectedRepresentation.getDescription());
                
            }else {
            	 
            	 element_Label.setEnabled(false);
                 element_abbrevLabel.setEnabled(false);
                 element_text.setEnabled(false);
            }

        }

        /*
         * (non-Javadoc)
         *
         * @see
         * org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse
         * .swt.events.SelectionEvent)
         */
        /** {@inheritDoc} */
        @Override
        public void widgetDefaultSelected(SelectionEvent e) {
        }

        /**
         * <p>
         * Setter for the field <code>multilanguageText</code>.
         * </p>
         *
         * @param multilanguageText
         *            the multilanguageText to set
         */
        public void setTerm(
                TermBase term, boolean update) {
            this.term = term;
            if (term.getRepresentations().isEmpty()){
            	//if the term has no representation at all, create a default one.
            	Representation rep = Representation.NewInstance("", "empty representation", "", PreferencesUtil.getGlobalLanguage());
            	term.addRepresentation(rep);
            }

            if (selectedRepresentation != null) {
               combo_language.setTerms(getLanguages());
               
            } else{
            	 element_Label.setEnabled(false);
                 element_abbrevLabel.setEnabled(false);
                 element_text.setEnabled(false);
                 if (PreferencesUtil.isMultilanguageTextEditingCapability()) {
                	 removeRepresentation.setEnabled(false);
                 }
            }
            if (update){
            	updateControls();
            }
        }

        /**
         *
         */
        protected void updateControls() {
            Representation preferredRepresentation = term
                    .getPreferredRepresentation(PreferencesUtil.getGlobalLanguage() );

            element_Label.setText(preferredRepresentation.getLabel());
            element_abbrevLabel.setText(preferredRepresentation.getAbbreviatedLabel());
            element_text.setText(preferredRepresentation.getDescription());
            selectedRepresentation = preferredRepresentation;
            if (PreferencesUtil.isMultilanguageTextEditingCapability()) {
                combo_language.setSelection(preferredRepresentation == null?CdmStore.getDefaultLanguage():preferredRepresentation.getLanguage());
                boolean removePossible = term.getRepresentations().size() > 1 ;
                removeRepresentation.setEnabled(removePossible);
                
            }
        }

        /**
         * <p>
         * Getter for the field <code>multilanguageText</code>.
         * </p>
         *
         * @return the multilanguageText
         */
        public TermBase getTerm() {
            return term;
        }

        /*
         * (non-Javadoc)
         *
         * @see
         * eu.etaxonomy.taxeditor.forms.AbstractCdmFormElement#propertyChange(org
         * .eclipse.jface.util.PropertyChangeEvent)
         */
        /** {@inheritDoc} */
        @Override
        public void propertyChange(PropertyChangeEvent event) {
            if (event == null) {
                return;
            }
            Object eventSource = event.getSource();

            if (eventSource == element_abbrevLabel) {
                String abbrevLabel = ((TextWithLabelElement) eventSource)
                        .getText();
                selectedRepresentation.setAbbreviatedLabel(abbrevLabel);
                firePropertyChangeEvent(new CdmPropertyChangeEvent(this, event));
            } else if (eventSource == element_Label){
                String label = ((TextWithLabelElement) eventSource)
                        .getText();
                selectedRepresentation.setLabel(label);
                firePropertyChangeEvent(new CdmPropertyChangeEvent(this, event));
            } else if (eventSource == element_text){
                String text = ((TextWithLabelElement) eventSource)
                        .getText();
                selectedRepresentation.setText(text);
                firePropertyChangeEvent(new CdmPropertyChangeEvent(this, event));
            } else if (eventSource == button){
            	firePropertyChangeEvent(new CdmPropertyChangeEvent(this, event));
            } else if (eventSource == combo_language){
            	if (combo_language.getSelection() != null){
            		element_Label.setEnabled(true);
            		element_abbrevLabel.setEnabled(true);
            		element_text.setEnabled(true);
            		 boolean removePossible = term.getRepresentations().size() > 1 ;
                     removeRepresentation.setEnabled(removePossible);
            	} else{
            		 element_Label.setEnabled(false);
                     element_abbrevLabel.setEnabled(false);
                     element_text.setEnabled(false);
                     removeRepresentation.setEnabled(false);
            	}
            	firePropertyChangeEvent(new CdmPropertyChangeEvent(this, event));
            }
        }

        /**
         * @return the selectedRepresentation
         */
        public Representation getSelectedRepresentation() {
            return selectedRepresentation;
        }

        /**
         * @param selectedRepresentation the selectedRepresentation to set
         */
        public void setSelectedRepresentation(Representation selectedRepresentation) {
            if (selectedRepresentation == null){
                selectedRepresentation = Representation.NewInstance("", "", "", null);
            }
            this.selectedRepresentation = selectedRepresentation;
        }
        
        private class DeleteListener extends SelectionAdapter {

    		private final RepresentationElement element;

    		public DeleteListener(RepresentationElement element) {
    			this.element = element;
    		}

    		@Override
    		public void widgetSelected(SelectionEvent e) {
    			term.removeRepresentation(selectedRepresentation);
    			firePropertyChangeEvent(new CdmPropertyChangeEvent(
    					this, e));
    			updateControls();
    		}
    	}
    }


