/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.element;

import java.net.MalformedURLException;
import java.net.URI;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;

import eu.etaxonomy.taxeditor.l10n.Messages;
import eu.etaxonomy.taxeditor.model.ImageResources;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.store.internal.TaxeditorStorePlugin;

/**
 * @author n.hoffmann
 * @created Dec 20, 2010
 * @version 1.0
 */
public class UriWithLabelElement extends AbstractUriWithExceptionLabelElement<URI> {

    private Button btnOpenBrowser;

    protected UriWithLabelElement(CdmFormFactory formFactory, ICdmFormElement parentElement, String labelString,
            URI initialObject, Integer textHeight, int style) {
        super(formFactory, parentElement, labelString, initialObject, textHeight, style);

	}

    /**
     * {@inheritDoc}
     */
    @Override
    protected void init(CdmFormFactory formFactory, String labelString, URI initialObject, Integer textHeight, int style) {

        //label
        initLabel(formFactory, labelString, false, getLayoutComposite());

        //composite(uri + button)
        Composite textAndButton = formFactory.createComposite(getLayoutComposite(), style);
        addControl(textAndButton);
        textAndButton.setLayout(LayoutConstants.LAYOUT(2, false));
        textAndButton.setLayoutData(LayoutConstants.FILL_HORIZONTALLY());

        //uri text
        initText(formFactory, null, textHeight, null, false, style, textAndButton);

        //button
        btnOpenBrowser = formFactory.createButton(textAndButton, "", SWT.NONE); //$NON-NLS-1$
        btnOpenBrowser.setImage(ImageResources.getImage(ImageResources.WEB));
        btnOpenBrowser.setToolTipText(Messages.UriWithLabelElement_OPEN_EXTERNAL_BROWSER);
        btnOpenBrowser.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                String errorTitle = Messages.UriWithLabelElement_INVALID_URL;
                String errorText = Messages.UriWithLabelElement_COULD_NOT_OPEN_BROWSER;

                URI uri = parseText();
                if(uri!=null){
                    try {
                        PlatformUI.getWorkbench().getBrowserSupport().getExternalBrowser().openURL(uri.toURL());
                    } catch (PartInitException pie) {
                        MessagingUtils.informationDialog(errorTitle, new Status(IStatus.WARNING, TaxeditorStorePlugin.PLUGIN_ID, errorText, pie));
                    } catch (MalformedURLException mue) {
                        MessagingUtils.informationDialog(errorTitle, new Status(IStatus.WARNING, TaxeditorStorePlugin.PLUGIN_ID, errorText, mue));
                    } catch (IllegalArgumentException iae) {
                        MessagingUtils.informationDialog(errorTitle, new Status(IStatus.WARNING, TaxeditorStorePlugin.PLUGIN_ID, errorText, iae));
                    }
                }
                else{
                    MessagingUtils.informationDialog(errorTitle, new Status(IStatus.WARNING, TaxeditorStorePlugin.PLUGIN_ID, errorText, null));
                }
            }
        });
        btnOpenBrowser.setLayoutData(LayoutConstants.RIGHT());

        initExceptionLabel(getLayoutComposite(), formFactory, initialObject);
    }



    /**
     * {@inheritDoc}
     */
    @Override
    public void setParsedText(URI object) {
        if(object != null){
            super.setText(object.toString());
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected URI getParsedText() throws Exception {
        return new URI(super.getText());
    }

}
