/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.mvc;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;

import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.mvc.interfaces.CdmCompositeController;
import eu.etaxonomy.taxeditor.ui.mvc.interfaces.ICdmComposite;

/**
 * Basic implementation of {@link ICdmComposite}.
 * @author pplitzner
 * @date 11.02.2014
 *
 * @param <T> The {@link CdmCompositeController} for this composite.
 */
public abstract class AbstractCdmComposite<T extends CdmCompositeController> extends Composite implements ICdmComposite {

    protected T controller;

    /**
     * @param parent
     * @param style
     */
    public AbstractCdmComposite(Composite parent, int style) {
        super(parent, style);
    }

    protected void initChildController(CdmFormFactory formFactory, ICdmFormElement parentElement){
        Control[] children = this.getChildren();
        for (int i = 0; i < children.length; i++) {
            if(children[i] instanceof ICdmComposite){
                ICdmComposite cdmComposite = (ICdmComposite)children[i];
                cdmComposite.initController(formFactory, parentElement);
                formFactory.adapt(cdmComposite.getController());
                parentElement.addElement(cdmComposite.getController());
            }
        }
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.ui.mvc.interfaces.CdmComposite#initController(eu.etaxonomy.taxeditor.ui.element.CdmFormFactory, eu.etaxonomy.taxeditor.ui.element.ICdmFormElement)
     */
    @Override
    public void initController(CdmFormFactory formFactory, ICdmFormElement parentElement) {
        initInternalController(formFactory, parentElement);
        initChildController(formFactory, parentElement);
    }

    /**
     * @param formFactory
     * @param parentElement
     * @return
     */
    protected abstract void initInternalController(CdmFormFactory formFactory, ICdmFormElement parentElement);

    @Override
    public T getController(){
        return controller;
    }

}
