/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.mvc.element;

import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.widgets.Text;
import org.joda.time.DateTime;

import eu.etaxonomy.taxeditor.ui.element.AbstractCdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.IEnableableFormElement;
import eu.etaxonomy.taxeditor.ui.mvc.interfaces.CdmCompositeController;

/**
 * @author pplitzner
 * @date 16.06.2014
 *
 */
public class DateElementController extends AbstractCdmFormElement implements IEnableableFormElement, CdmCompositeController, ModifyListener{

    private final Text textDate;
    private DateTime dateTime;

    /**
     * @param dateTimeElement
     * @param formFactory
     * @param parentElement
     * @param initialDateTime
     * @param none
     */
    public DateElementController(DateElement dateTimeElement, CdmFormFactory formFactory, ICdmFormElement parentElement, DateTime initialDateTime, int none) {
        super(formFactory, parentElement);
        this.textDate = dateTimeElement.getTextDate();
        this.textDate.setText(initialDateTime!=null?initialDateTime.toString("yyyy-MM-dd"):"");
        addControl(textDate);
        textDate.addModifyListener(this);
    }

    /* (non-Javadoc)
     * @see org.eclipse.swt.events.ModifyListener#modifyText(org.eclipse.swt.events.ModifyEvent)
     */
    @Override
    public void modifyText(ModifyEvent e) {
        try {
            String text = textDate.getText();
            DateTime parsedDateTime = DateTime.parse(text);
            this.dateTime = parsedDateTime;
            firePropertyChangeEvent(new CdmPropertyChangeEvent(this, e));
        } catch (IllegalArgumentException iae) {
            //nothing
        }
    }

    public DateTime getDateTime(){
        return dateTime;
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.ui.element.IRelevantFormElement#setIrrelevant(boolean)
     */
    @Override
    public void setIrrelevant(boolean irrelevant) {
        // TODO Auto-generated method stub

    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.ui.element.IEnableableFormElement#setEnabled(boolean)
     */
    @Override
    public void setEnabled(boolean enabled) {
        textDate.setEnabled(enabled);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.ui.element.IEnableableFormElement#isEnabled()
     */
    @Override
    public boolean isEnabled() {
        return textDate.isEnabled();
    }

}
