/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.classification;

import org.apache.commons.lang.StringUtils;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.common.CdmUtils;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.ITaxonTreeNode;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.CheckboxElement;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.LayoutConstants;
import eu.etaxonomy.taxeditor.ui.element.MultilanguageTextElement;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;
import eu.etaxonomy.taxeditor.ui.selection.TaxonNodeSelectionElement;

/**
 *
 * @author n.hoffmann
 * @created Sep 27, 2010
 * @version 1.0
 */
public class TaxonNodeDetailElement extends AbstractCdmDetailElement<ITaxonTreeNode> {

    private boolean createNew = false;

	private EntitySelectionElement<Classification> selection_classification;

	private Classification classification;

	private TaxonNodeSelectionElement selection_parentTaxonNode;

	private ITaxonTreeNode parentTreeNode;

	private EntitySelectionElement<Taxon> selection_reuseExistingTaxon;
	private EntitySelectionElement<Reference> selection_SecRef;

	private Taxon taxon;

	private TextWithLabelElement textNewTaxonName;

	private TaxonNodeAgentRelationCollectionSection selectionNodeAgentRelation;

	private CheckboxElement checkbox_openInEditor;

	private CheckboxElement checkbox_unplaced;

	private CheckboxElement checkbox_excluded;

	private MultilanguageTextElement multiLanguageTextExcludedNotes;

	private boolean openInEditor;

	private boolean complete;

	private EntitySelectionElement<TaxonNameBase> selection_reuseExistingName;

	public TaxonNodeDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement, boolean isCreateNew) {
		super(formFactory, formElement);
		createNew = isCreateNew;
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
	        ITaxonTreeNode entity, int style) {
		selection_classification = formFactory
				.createSelectionElement(Classification.class,
						getConversationHolder(), formElement, "Classification",
						null, EntitySelectionElement.DELETABLE, style);
		selection_parentTaxonNode = formFactory
				.createTaxonNodeSelectionElement(getConversationHolder(), formElement, "Parent", null,
						EntitySelectionElement.DELETABLE, style);

		selection_reuseExistingTaxon = formFactory
				.createSelectionElement(Taxon.class,
						getConversationHolder(), formElement,
						"Reuse existing taxon", null,
						EntitySelectionElement.DELETABLE, style);

		selection_reuseExistingName = formFactory
				.createSelectionElement(TaxonNameBase.class,
						getConversationHolder(), formElement,
						"Reuse existing name", null,
						EntitySelectionElement.DELETABLE, style);
		selection_SecRef = formFactory
                .createSelectionElement(Reference.class,getConversationHolder(), formElement, "Secundum Reference", null,
                        EntitySelectionElement.DELETABLE, style);
		if (isCreateNew()){
		    textNewTaxonName = formFactory.createTextWithLabelElement(formElement,"New Taxon", "", style);
		    textNewTaxonName.setFocus();
		} else{
		    textNewTaxonName = formFactory.createTextWithLabelElement(formElement,"Taxon", "", style);

		}

		if (isCreateNew()){
            setParentTreeNode(entity);
        } else{
            setTreeNode(entity);
            complete = true;
        }
		if (entity instanceof TaxonNode) {
		    checkbox_unplaced = formFactory.createCheckbox(formElement,
		            "Taxon is unplaced", ((TaxonNode) entity).isUnplaced(), style);
		}

		if (!isCreateNew()){
            selectionNodeAgentRelation = formFactory.createTaxonNodeAgentRelationCollectionSection(formElement, getConversationHolder(), style);
            selectionNodeAgentRelation.setEntity((TaxonNode)entity);
            selectionNodeAgentRelation.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
        }
		preFillTaxonName();

		if (entity instanceof TaxonNode) {
		    checkbox_excluded = formFactory.createCheckbox(formElement,
		            "Taxon is excluded", ((TaxonNode) entity).isExcluded(), style);
		    multiLanguageTextExcludedNotes = formFactory.createMultiLanguageTextElement(formElement, "Excluded Notes", ((TaxonNode)entity).getExcludedNote(), 50, style);
		    multiLanguageTextExcludedNotes.setEnabled(((TaxonNode) entity).isExcluded());
		}
		checkbox_openInEditor = formFactory.createCheckbox(formElement,
		        "Open in Editor", true, style);
		setOpenInEditor(true);
	}

	private void preFillTaxonName() {
        if(getEntity() instanceof TaxonNode ){
            TaxonNode node = (TaxonNode)getEntity();
            if(node.getTaxon()!=null){
                Taxon taxon = HibernateProxyHelper.deproxy(node.getTaxon(), Taxon.class);
                if(taxon.getName()!=null && taxon.getName().isInstanceOf(NonViralName.class)){
                    NonViralName<?> name = HibernateProxyHelper.deproxy(node.getTaxon().getName(), NonViralName.class);
                    if (!isCreateNew()){
                        textNewTaxonName.setText(name.getNameCache());
                    } else if( ! name.isSupraGeneric() && name.getRank() != null){
                        String taxonName = "";
                        if(name.isGenus() || name.isInfraGeneric()|| name.isSpeciesAggregate() ){
                            taxonName = name.getGenusOrUninomial();
                        }
                        else if(name.isSpecies() || name.isInfraSpecific() ){
                            taxonName = CdmUtils.concat(" ", name.getGenusOrUninomial(),name.getSpecificEpithet());
                        }
                        if (StringUtils.isNotBlank(taxonName)){
                        	textNewTaxonName.setText(taxonName + " ");
                        	if(textNewTaxonName.getMainControl() instanceof Text){
                        		Text text = (Text)textNewTaxonName.getMainControl();
                        		text.setSelection(textNewTaxonName.getText().length());
                        	}
                        }
                    }
                }
            }
        }
    }

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == selection_classification) {
			setClassification(selection_classification.getEntity());
		} else if (eventSource == selection_parentTaxonNode) {
			setParentTreeNode(selection_parentTaxonNode.getEntity());
		} else if (eventSource == selection_reuseExistingTaxon) {
				boolean enabled = selection_reuseExistingTaxon.getEntity() == null;
				selection_reuseExistingName.setEnabled(enabled);
				if (!enabled){
                    setTaxon(selection_reuseExistingTaxon.getEntity());
                }else{
			        textNewTaxonName.setText(null);
			    }
				complete = !textNewTaxonName.getText().isEmpty();


		} else if (eventSource == selection_reuseExistingName) {
		    boolean enabled = selection_reuseExistingName.getEntity() == null;
			setTaxon(selection_reuseExistingName.getEntity());
			selection_reuseExistingTaxon.setEnabled(enabled);
			textNewTaxonName.setEnabled(enabled);

			complete = !textNewTaxonName.getText().isEmpty();
		} else if (eventSource == textNewTaxonName) {
			boolean enabled = CdmUtils.isBlank(textNewTaxonName.getText());
			selection_reuseExistingTaxon.setEnabled(enabled);
			selection_reuseExistingName.setEnabled(enabled);

			complete = CdmUtils.isNotBlank(textNewTaxonName.getText());
		} else if (eventSource == checkbox_excluded) {
		    boolean isExcluded = checkbox_excluded.getSelection();
            ((TaxonNode) getEntity()).setExcluded(isExcluded);
            multiLanguageTextExcludedNotes.setEnabled(isExcluded);
		} else if (eventSource == checkbox_unplaced) {
		    ((TaxonNode) getEntity()).setUnplaced(checkbox_unplaced.getSelection());
		} else if (eventSource == checkbox_openInEditor) {
			setOpenInEditor(checkbox_openInEditor.getSelection());
		} else if (eventSource == selectionNodeAgentRelation){
		   boolean allComplete = true;
		   for (ICdmFormElement element : selectionNodeAgentRelation.getElements()){
		       allComplete &=((TaxonNodeAgentRelationCollectionElement)element).isComplete();
		   }
		    complete = !isCreateNew() && allComplete;
		}
	}

	public Classification getClassification() {
		return classification;
	}

	public boolean isOpenInEditor() {
		return openInEditor;
	}

	public ITaxonTreeNode getParentTreeNode() {
		return parentTreeNode;
	}

	private void setClassification(Classification classification) {
		this.classification = classification;
		setParentTreeNode(classification);
	}

	private void setParentTreeNode(ITaxonTreeNode parentTreeNode) {
		this.parentTreeNode = parentTreeNode;

		if (parentTreeNode instanceof Classification) {
			classification = (Classification) parentTreeNode;
			selection_classification.setEntity(classification);
			selection_parentTaxonNode.setEntity(null);
			selection_parentTaxonNode.setClassification(classification);
			selection_SecRef.setEntity(classification.getReference());
		} else if (parentTreeNode instanceof TaxonNode) {
			classification = HibernateProxyHelper
					.deproxy(((TaxonNode) parentTreeNode).getClassification());
			selection_classification.setEntity(classification);
			selection_parentTaxonNode.setEntity((TaxonNode) parentTreeNode);
			selection_parentTaxonNode.setClassification(classification);
			selection_SecRef.setEntity(((TaxonNode)parentTreeNode).getTaxon().getSec());
		} else if(parentTreeNode == null){
			this.parentTreeNode = selection_classification.getEntity();
		}
	}

	private void setTreeNode(ITaxonTreeNode treeNode) {
        classification = HibernateProxyHelper
                    .deproxy(((TaxonNode) treeNode).getClassification());
        selection_classification.setEntity(classification);
        selection_parentTaxonNode.setEntity(((TaxonNode) treeNode).getParent());
        selection_parentTaxonNode.setClassification(((TaxonNode) treeNode).getParent().getClassification());
        selection_SecRef.setEntity(((TaxonNode)treeNode).getTaxon().getSec());
	}

	private void setTaxon(Taxon taxon) {
		this.taxon = taxon;
		if (isCreateNew()){
		    textNewTaxonName.setText(taxon.getName().getTitleCache());
		}
		selection_SecRef.setEntity(taxon.getSec());
	}

	private void setTaxon(TaxonNameBase taxonName) {
		Reference secundum = null;
		if (getParentTreeNode() != null) {
			if (this.selection_SecRef.getEntity() != null){
				secundum = this.selection_SecRef.getEntity();
			}
		}
		if (taxonName != null){
		    taxon = Taxon.NewInstance(taxonName, secundum);
		    if (textNewTaxonName.getText() == null || !taxonName.getTitleCache().trim().equals(textNewTaxonName.getText().trim())){
		    	 textNewTaxonName.setText(taxonName.getTitleCache());
		    }
//		    if (!taxonName.getTitleCache().trim().equals(textNewTaxonName.getText().trim())){
//		        textNewTaxonName.setText(taxonName.getTitleCache());
//		    }
		} else {
		    textNewTaxonName.setText(null);
		}
	}

	private void setOpenInEditor(boolean openInEditor) {
		this.openInEditor = openInEditor;
	}

	public String getTaxonName() {
        return textNewTaxonName.getText();
    }
	public Taxon getTaxon() {
        return taxon;
    }

	public Reference getReference(){
	    return selection_SecRef.getSelection();
	}

	public Control getMainControl(){
	    return textNewTaxonName.getMainControl();
	}

	public boolean isComplete() {
	    boolean allComplete = true;
	    if (!isCreateNew()){
	        for (ICdmFormElement element : selectionNodeAgentRelation.getElements()){
	            allComplete &=((TaxonNodeAgentRelationCollectionElement)element).isComplete();
	        }
	        complete = allComplete;
	    }
		return complete;
	}

    public boolean isCreateNew() {
        return createNew;
    }

}
