/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.description;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.description.DescriptionElementSource;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.ui.element.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.IEntityElement;
import eu.etaxonomy.taxeditor.ui.section.supplemental.AbstractOriginalSourceElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 *
 * @author n.hoffmann
 * @created Nov 16, 2009
 * @version 1.0
 */
public class DescriptionElementSourceElement extends
		AbstractOriginalSourceElement<DescriptionElementSource> implements
		IEntityElement<DescriptionElementSource> {

	private EntitySelectionElement<TaxonNameBase> selection_name;

	public DescriptionElementSourceElement(CdmFormFactory cdmFormFactory,
			AbstractFormSection formElement, DescriptionElementSource element,
			SelectionListener removeListener, int style) {
		super(cdmFormFactory, formElement, element, removeListener, style);
		formFactory.createSelectionArbitrator(this);
	}

	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement formElement, int style) {
		super.createControls(formElement, style);
		selection_name = formFactory
				.createSelectionElement(TaxonNameBase.class,
						getConversationHolder(), formElement, "Name in Source",
						null, EntitySelectionElement.ALL, SWT.NULL);
	}

	/** {@inheritDoc} */
	@Override
	public void setEntity(DescriptionElementSource entity) {
		super.setEntity(entity);
		text_idInSource.setText(entity.getIdInSource());
		text_idNamespace.setText(entity.getIdNamespace());

		selection_reference.setEntity(entity.getCitation());
		text_referenceDetail.setText(entity.getCitationMicroReference());
		text_originaleNameString.setText(entity.getOriginalNameString());
		selection_name.setEntity(entity.getNameUsedInSource());
		combo_origsourcetype.setSelection(entity.getType());
	}

	/** {@inheritDoc} */
	@Override
	public void setSelected(boolean selected) {

	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == text_idInSource) {
			getEntity().setIdInSource(text_idInSource.getText());
		} else if (eventSource == text_idNamespace) {
			getEntity().setIdNamespace(text_idNamespace.getText());
		} else if (eventSource == selection_reference) {
			getEntity().setCitation(selection_reference.getSelection());
		} else if (eventSource == text_referenceDetail) {
			getEntity().setCitationMicroReference(
					text_referenceDetail.getText());
		} else if (eventSource == text_originaleNameString) {
			getEntity().setOriginalNameString(
					text_originaleNameString.getText());
		} else if (eventSource == selection_name) {
			getEntity().setNameUsedInSource(selection_name.getSelection());
		}
		else if(eventSource == combo_origsourcetype){
		    getEntity().setType(combo_origsourcetype.getSelection());
		}

	}

}
