/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.description;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.common.DefinedTerm;
import eu.etaxonomy.cdm.model.description.IModifiable;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.occurrence.dna.AbstractUnboundEntityCollectionSection;

/**
 * <p>ModifierSection class.</p>
 *
 * @author n.hoffmann
 * @created Sep 15, 2010
 * @version 1.0
 */
public class ModifierSection extends AbstractUnboundEntityCollectionSection<IModifiable, DefinedTerm> {

	/**
	 * <p>Constructor for ModifierSection.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement} object.
	 * @param style a int.
	 */
	public ModifierSection(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement,
			int style) {
		super(formFactory, conversation, parentElement, "Modifiers", style);
	}

	/** {@inheritDoc} */
	@Override
	public DefinedTerm createNewElement() {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public void addElement(DefinedTerm element) {
		getEntity().addModifier(element);
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(DefinedTerm element) {
		getEntity().removeModifier(element);
	}

	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No modifiers yet.";
	}

	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Add a modifier.";
	}

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.ui.section.occurrence.dna.AbstractUnboundEntityCollectionSection#getEntityCollection(java.lang.Object)
     */
    @Override
    protected Collection<DefinedTerm> getEntityCollection(IModifiable entity) {
        return entity.getModifiers();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public DefinedTerm addExisting() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        return false;
    }
}
