package eu.etaxonomy.taxeditor.ui.section.description;


import java.util.Comparator;

import eu.etaxonomy.cdm.model.common.OriginalSourceBase;
import eu.etaxonomy.cdm.model.common.OriginalSourceType;
import eu.etaxonomy.cdm.model.reference.Reference;

/**
 * @author pplitzner
 * @date Apr 13, 2016
 *
 */
public class SourceComparator implements Comparator<OriginalSourceBase> {
    @Override
    public int compare(OriginalSourceBase o1, OriginalSourceBase o2) {
        int id1 = o1.getId();
        int id2 = o2.getId();
        OriginalSourceType type1 = o1.getType();
        OriginalSourceType type2 = o2.getType();
        Reference citation1 = o1.getCitation();
        Reference citation2 = o2.getCitation();

        int result = 0;

        // the newly created should always be on top
        if (id1 == 0){
            if(id2!=0) {
                result = -1;
            }
            else{
                result = 0;
            }
        } else if(id2==0){
            result = 1;
        }

        // sort by type (Primary taxonomic > Primary Media > others
        // alphabetically by reference title cache)
        else if (type1 == null){
            if(type2==null){
                result = 0;
            }
            else{
                result = 1;
            }
        } else if (type2 == null){
            result = -1;
        } else if(type1.equals(type2)){
            result = 0;
        } else if (type1.equals(OriginalSourceType.PrimaryTaxonomicSource)){
            result = -1;
        } else if (type2.equals(OriginalSourceType.PrimaryTaxonomicSource)){
            result = 1;
        } else if (type1.equals(OriginalSourceType.PrimaryMediaSource)){
            result = -1;
        } else if (type2.equals(OriginalSourceType.PrimaryMediaSource)){
            result = 1;
        }

        //sort by citation title cache if types are equal
        if (result == 0){
            if(citation1!=null && citation2!=null){
                result = citation1.getTitleCache().compareTo(citation2.getTitleCache());
            }

            if(o2.getCreated()!=null && o1.getCreated()!=null){
                result = o2.getCreated().compareTo(o1.getCreated());
            }
            if (result == 0){
                //default fallback
                return o1.getId() - o2.getId();
            }
        }
        return result;


    }
}
