/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.description;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.description.QuantitativeData;
import eu.etaxonomy.cdm.model.description.StatisticalMeasurementValue;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;

/**
 * <p>StatisticalMeasurementValueSection class.</p>
 *
 * @author n.hoffmann
 * @created Sep 15, 2010
 * @version 1.0
 */
public class StatisticalMeasurementValueSection extends
		AbstractEntityCollectionSection<QuantitativeData, StatisticalMeasurementValue> {

	/**
	 * <p>Constructor for StatisticalMeasurementValueSection.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement} object.
	 * @param style a int.
	 */
	public StatisticalMeasurementValueSection(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement,
			int style) {
		super(formFactory, conversation, parentElement, "Statistical Measurement Value", style);
	}

	/** {@inheritDoc} */
	@Override
	public Collection<StatisticalMeasurementValue> getCollection(
			QuantitativeData entity) {
		return entity.getStatisticalValues();
	}

	/** {@inheritDoc} */
	@Override
	public StatisticalMeasurementValue createNewElement() {
		return StatisticalMeasurementValue.NewInstance();
	}

	/** {@inheritDoc} */
	@Override
	public void addElement(StatisticalMeasurementValue element) {
		getEntity().addStatisticalValue(element);
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(StatisticalMeasurementValue element) {
		getEntity().removeStatisticalValue(element);
	}

	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No statistical values yet.";
	}

	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Create new statistical value";
	}

    /**
     * {@inheritDoc}
     */
    @Override
    public StatisticalMeasurementValue addExisting() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        return false;
    }
}
