/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.description.detail;

import java.util.Map;

import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.common.LanguageString;
import eu.etaxonomy.cdm.model.description.IndividualsAssociation;
import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationBase;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * @author n.hoffmann
 * @created Jun 10, 2010
 * @version 1.0
 */
public class IndividualsAssociationDetailElement extends
		AbstractDetailedDescriptionDetailElement<IndividualsAssociation> {

	private TextWithLabelElement text_description;
	private EntitySelectionElement<SpecimenOrObservationBase> selection_derivedUnit;

	public IndividualsAssociationDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement, IndividualsAssociation entity,
			int style) {
		super(formFactory, formElement, entity, style);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			IndividualsAssociation entity, int style) {
		selection_derivedUnit = formFactory
				.createSelectionElement(SpecimenOrObservationBase.class,
						getConversationHolder(), formElement, "Occurrence/Unit",
						CdmBase.deproxy(entity.getAssociatedSpecimenOrObservation(),SpecimenOrObservationBase.class),
						EntitySelectionElement.ALL, style);

		text_description = formFactory.createMultiLineTextWithLabel(
				formElement, "Relationship to the unit:", 200, style);
		Map<Language, LanguageString> descriptions = entity.getDescription();

		if (descriptions.get(CdmStore.getDefaultLanguage()) != null) {
			text_description.setText(descriptions.get(
					CdmStore.getDefaultLanguage()).getText());
		}
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == selection_derivedUnit) {
			getEntity().setAssociatedSpecimenOrObservation(
					selection_derivedUnit.getEntity());
		} else if (eventSource == text_description) {
			getEntity().putDescription(CdmStore.getDefaultLanguage(), text_description.getText());
		}

	}
}
