/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.group;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.common.Group;
import eu.etaxonomy.cdm.model.common.User;
import eu.etaxonomy.taxeditor.ui.dialog.selection.UserSelectionDialog;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;

/**
 * @author n.hoffmann
 * @created Mar 9, 2011
 * @version 1.0
 */
public class MemberDetailSection extends AbstractEntityCollectionSection<Group, User> {

	/**
	 * @param formFactory
	 * @param conversation
	 * @param parentElement
	 * @param title
	 * @param style
	 */
	public MemberDetailSection(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement,
			int style) {
		super(formFactory, conversation, parentElement, "Members", style);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#getCollection(java.lang.Object)
	 */
	@Override
	public Collection<User> getCollection(Group entity) {
		return entity.getMembers();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#createNewElement()
	 */
	@Override
	public User createNewElement() {
		User selection = UserSelectionDialog.select(getLayoutComposite().getShell(), getConversationHolder(), null);
		return selection;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#addElement(eu.etaxonomy.cdm.model.common.IVersionableEntity)
	 */
	@Override
	public void addElement(User element) {
		getEntity().addMember(element);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#removeElement(eu.etaxonomy.cdm.model.common.IVersionableEntity)
	 */
	@Override
	public void removeElement(User element) {
		getEntity().removeMember(element);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#getEmptyString()
	 */
	@Override
	public String getEmptyString() {
		return "No members yet.";
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#getTooltipString()
	 */
	@Override
	protected String getTooltipString() {
		return "Add a memeber to this group";
	}

    /**
     * {@inheritDoc}
     */
    @Override
    public User addExisting() {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        // TODO Auto-generated method stub
        return false;
    }

	

}
