/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.name;

import java.util.Arrays;

import eu.etaxonomy.cdm.model.agent.TeamOrPersonBase;
import eu.etaxonomy.cdm.model.name.NomenclaturalCode;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.name.TaxonNameFactory;
import eu.etaxonomy.cdm.model.name.ZoologicalName;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.NumberWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractIdentifiableEntityDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * <p>
 * AuthorshipDetailElement class.
 * </p>
 *
 * @author n.hoffmann
 * @created Mar 4, 2010
 * @version 1.0
 */
public class AuthorshipDetailElement extends
	AbstractIdentifiableEntityDetailElement<NonViralName> {

    private EntitySelectionElement<TeamOrPersonBase> selectionExBasionymAuthor;
    private EntitySelectionElement<TeamOrPersonBase> selectionBasionymAuthor;
    private EntitySelectionElement<TeamOrPersonBase> selectionExCombinationAuthor;
    private EntitySelectionElement<TeamOrPersonBase> selectionCombinationAuthor;

    private NumberWithLabelElement text_publicationYear;
    private NumberWithLabelElement text_originalPublicationYear;
	/**
	 * <p>
	 * Constructor for AuthorshipDetailElement.
	 * </p>
	 *
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement}
	 *            object.
	 * @param style
	 *            a int.
	 */
	public AuthorshipDetailElement(CdmFormFactory cdmFormFactory,
			ICdmFormElement formElement, int style) {
		super(cdmFormFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			NonViralName entity, int style) {
	    if (isAdvancedView || PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_AUTHORSHIP_CACHE)){
	        toggleable_cache = formFactory.createToggleableTextField(this,
				"Authorship Cache", entity.getAuthorshipCache(),
				entity.isProtectedAuthorshipCache(), style);
	        addElement(toggleable_cache);
	   }
	    NomenclaturalCode code = entity.getNomenclaturalCode();

	    if (isAdvancedView || PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_NAME_DETAILS_SECTION_AUTHORSHIP)){
            selectionCombinationAuthor = formFactory.createSelectionElementWithAbbreviatedTitle(TeamOrPersonBase.class,
    				getConversationHolder(),
    				formElement, "Author",
    				entity.getCombinationAuthorship(),
    				EntitySelectionElement.ALL, style);
    		addElement(selectionCombinationAuthor);
    		selectionExCombinationAuthor = formFactory.createSelectionElementWithAbbreviatedTitle(TeamOrPersonBase.class,
    				getConversationHolder(),
    				formElement, "Ex Author",
    				entity.getExCombinationAuthorship(),
    				EntitySelectionElement.ALL, style);
    		addElement(selectionExCombinationAuthor);
    		if (code != null){
                if (code.equals(NomenclaturalCode.ICZN)){
                    text_publicationYear = formFactory.createNumberTextWithLabelElement(formElement, "Publication Year", ((ZoologicalName)entity).getPublicationYear(), style);

                }
             }
    		selectionBasionymAuthor = formFactory.createSelectionElementWithAbbreviatedTitle(TeamOrPersonBase.class, getConversationHolder(),
                    formElement, "Basionym Author", entity.getBasionymAuthorship(),
                    EntitySelectionElement.ALL, style);
    		addElement(selectionBasionymAuthor);
    		selectionExBasionymAuthor = formFactory.createSelectionElementWithAbbreviatedTitle(TeamOrPersonBase.class, getConversationHolder(),
    		        formElement, "Ex Basionym Author",entity.getExBasionymAuthorship(),
    		        EntitySelectionElement.ALL, style);

    		addElement(selectionExBasionymAuthor);
    		 if (code != null){
    	            if (code.equals(NomenclaturalCode.ICZN)){

    	                text_originalPublicationYear = formFactory.createNumberTextWithLabelElement(formElement, "Orig. Publication Year", ((ZoologicalName)entity).getOriginalPublicationYear(), style);

    	            }
    	         }

	    }

	}

	/** {@inheritDoc} */
	@Override
	public void updateContent() {
		if (getEntity() == null) {
			setEntity(TaxonNameFactory.NewNonViralInstance(null));
		}

		super.updateContent();
		if (toggleable_cache != null){
    		toggleable_cache.setEnabled(getEntity().isProtectedAuthorshipCache());


    		if (this.isIrrelevant()) {
    			setIrrelevant(isIrrelevant());
    		} else {
    			setIrrelevant(toggleable_cache.getState(),
    					Arrays.asList(new Object[] { toggleable_cache }));
    		}
		}
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == toggleable_cache) {
			getEntity().setAuthorshipCache(toggleable_cache.getText(),
					toggleable_cache.getState());
			if (!isIrrelevant()){
				setIrrelevant(toggleable_cache.getState(),
						Arrays.asList(new Object[] { toggleable_cache }));
			}
		} else if (eventSource == selectionCombinationAuthor) {
			getEntity().setCombinationAuthorship(
					selectionCombinationAuthor.getSelection());
		} else if (eventSource == selectionExCombinationAuthor) {
			getEntity().setExCombinationAuthorship(
					selectionExCombinationAuthor.getSelection());
		} else if (eventSource == selectionBasionymAuthor) {
			getEntity().setBasionymAuthorship(
					selectionBasionymAuthor.getSelection());
		} else if (eventSource == selectionExBasionymAuthor) {
			getEntity().setExBasionymAuthorship(
					selectionExBasionymAuthor.getSelection());
		} else if (eventSource == text_originalPublicationYear) {
            ((ZoologicalName)getEntity()).setOriginalPublicationYear(text_originalPublicationYear.getInteger());
        } else if (eventSource == text_publicationYear) {
            ((ZoologicalName)getEntity()).setPublicationYear(text_publicationYear.getInteger());
        }

//		if (eventSource != toggleable_cache) {
//			toggleable_cache.setText(getEntity().getAuthorshipCache());
//		}

//		 we have to notify the parent if this is embedded in the nonviral name
//		 section
//		 maybe we can handle this a little bit more elegant
//		if (getParentElement() instanceof AbstractCdmDetailSection)
			firePropertyChangeEvent(new CdmPropertyChangeEvent(
					getParentElement(), null));
	}

	@Override
	public void updateToggleableCacheField() {
	    if (toggleable_cache != null){
    		if(! getEntity().isProtectedAuthorshipCache()){
    			toggleable_cache.setText(getEntity().getAuthorshipCache());
    		}
	    }
	}
}
