/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.name;

import java.util.Collection;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.wizard.WizardDialog;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NameRelationship;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;
import eu.etaxonomy.taxeditor.ui.section.ITaxonBaseDetailSection;

/**
 * <p>NameRelationshipDetailSection class.</p>
 *
 * @author n.hoffmann
 * @created Mar 18, 2010
 * @version 1.0
 */
public class NameRelationshipDetailSection extends AbstractEntityCollectionSection<TaxonNameBase, NameRelationship> implements ITaxonBaseDetailSection{

	private TaxonBase taxonBase;

	/**
	 * <p>Constructor for NameRelationshipDetailSection.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement} object.
	 * @param style a int.
	 */
	public NameRelationshipDetailSection(CdmFormFactory formFactory, ConversationHolder conversation,
			ICdmFormElement parentElement, int style) {
		super(formFactory, conversation, parentElement, "Name Relationships", style);
	}

	/** {@inheritDoc} */
	@Override
	public void addElement(NameRelationship element) {
		//getEntity().addRelationship(element);
	}

	/** {@inheritDoc} */
	@Override
	public NameRelationship createNewElement() {

		NameRelationshipWizard wizard = new NameRelationshipWizard(this);
		WizardDialog dialog = new WizardDialog(StoreUtil.getShell(), wizard);
		int status = dialog.open();

		if(status == IStatus.OK) {
            return wizard.getNameRelationship();
        }

		return null;
	}

	/** {@inheritDoc} */
	@Override
	public Collection<NameRelationship> getCollection(TaxonNameBase entity) {
		Collection<NameRelationship> allNameRelationships = entity.getRelationsFromThisName();
		allNameRelationships.addAll(entity.getRelationsToThisName());
		return allNameRelationships;
	}

	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No name relationships yet.";
	}

	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Add a new name relationship from this name.";
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(NameRelationship element) {
		getEntity().removeNameRelationship(element);
	}

	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#setTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	/** {@inheritDoc} */
	@Override
    public void setTaxonBase(TaxonBase entity) {
		this.taxonBase = entity;
		NonViralName name = (NonViralName) HibernateProxyHelper.deproxy(entity.getName());
		setEntity(name);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#getTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	@Override
	public TaxonBase getTaxonBase() {
		return taxonBase;
	}

    /**
     * {@inheritDoc}
     */
    @Override
    public NameRelationship addExisting() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        return false;
    }
}
