/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.name;

import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.cdm.model.common.TermType;
import eu.etaxonomy.cdm.model.name.NameRelationship;
import eu.etaxonomy.cdm.model.name.NameRelationshipType;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.ui.AbstractEntityCollectionElementWizardPage;
import eu.etaxonomy.taxeditor.ui.combo.TermComboElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * <p>
 * NameRelationshipWizardPage class.
 * </p>
 *
 * @author n.hoffmann
 * @created Jun 1, 2010
 * @version 1.0
 */
public class NameRelationshipWizardPage extends AbstractEntityCollectionElementWizardPage implements
		IPropertyChangeListener {

	private EntitySelectionElement<TaxonNameBase> selection_relatedTo;

	private TermComboElement<NameRelationshipType> combo_relationshipType;

	private final TaxonNameBase entity;

	private NameRelationshipType type;

	private TaxonNameBase toName;

	/**
	 * <p>
	 * Constructor for NameRelationshipWizardPage.
	 * </p>
	 *
	 * @param callingSection
	 *            a
	 *            {@link eu.etaxonomy.taxeditor.ui.section.name.NameRelationshipDetailSection}
	 *            object.
	 */
	protected NameRelationshipWizardPage(
			NameRelationshipDetailSection callingSection) {
		super("NameRelationshipWizardPage");
		setTitle("New Name Relationship");
		setDescription(callingSection.getEntity().getTitleCache());
		this.entity = callingSection.getEntity();
		this.formFactory = callingSection.getFormFactory();

		formFactory.addPropertyChangeListener(this);
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see
	 * org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets
	 * .Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControl(Composite parent) {
	    super.createControl(parent);

		combo_relationshipType = formFactory.createDefinedTermComboElement(TermType.NameRelationshipType,
						rootElement, "Name Relationship Type", null, SWT.NULL);

		selection_relatedTo = formFactory
				.createSelectionElement(TaxonNameBase.class,
						((NameRelationshipWizard) getWizard())
								.getConversationHolder(), rootElement,
						"Related to",this.entity, EntitySelectionElement.ALL,
						SWT.NULL, true);

	}

	/**
	 * <p>
	 * getNameRelationship
	 * </p>
	 *
	 * @return a {@link eu.etaxonomy.cdm.model.name.NameRelationship} object.
	 */
	public NameRelationship getNameRelationship() {
		return entity.addRelationshipToName(toName, type, null, null, null);
	}

	/** {@inheritDoc} */
	@Override
	public void propertyChange(PropertyChangeEvent event) {
		if (event == null) {
			return;
		}
		Object eventSource = event.getSource();
		if (eventSource == combo_relationshipType) {
			type = combo_relationshipType.getSelection();
		} else if (eventSource == selection_relatedTo) {
			toName = selection_relatedTo.getEntity();
		}

		boolean complete = type != null && toName != null;
		setPageComplete(complete);
	}

}
