/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.name;

import java.net.URI;

import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.TaxonNameDescription;
import eu.etaxonomy.cdm.model.media.Media;
import eu.etaxonomy.cdm.model.media.MediaRepresentation;
import eu.etaxonomy.cdm.model.media.MediaRepresentationPart;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.taxeditor.ui.element.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.ISelectableElement;
import eu.etaxonomy.taxeditor.ui.element.SelectionArbitrator;
import eu.etaxonomy.taxeditor.ui.element.UriWithLabelElement;
import eu.etaxonomy.taxeditor.ui.openurl.IOpenUrlEnabled;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;

/**
 * <p>ProtologueElement class.</p>
 *
 * @author n.hoffmann
 * @created Nov 5, 2009
 * @version 1.0
 */
public class ProtologueElement extends AbstractEntityCollectionElement<DescriptionElementBase> implements ISelectableElement, IOpenUrlEnabled{

	private final SelectionArbitrator selectionArbitrator;

	private UriWithLabelElement protologueUriText;
	private MediaRepresentationPart mediaRepresentationPart;
	private Media media;
	private MediaRepresentation mediaRepresentation;

	/**
	 * <p>Constructor for ProtologueElement.</p>
	 *
	 * @param element a {@link eu.etaxonomy.cdm.model.description.DescriptionElementBase} object.
	 * @param removeListener a {@link org.eclipse.swt.events.SelectionListener} object.
	 * @param style a int.
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory} object.
	 * @param formElement a {@link eu.etaxonomy.taxeditor.ui.element.AbstractFormSection} object.
	 */
	public ProtologueElement(CdmFormFactory cdmFormFactory, AbstractFormSection formElement, DescriptionElementBase element,
			SelectionListener removeListener, int style) {
		super(cdmFormFactory, formElement, element, removeListener, null, style);
		selectionArbitrator = cdmFormFactory.createSelectionArbitrator(this);
	}

	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement element, int style) {
		protologueUriText = formFactory.createUriWithLabelElement(element, "Protologue URI", null, style);

		formFactory.createOpenUrlSelectorElement(element, "Query BHL for Reference Image", this, style);
	}

	/** {@inheritDoc} */
	@Override
	public void setEntity(DescriptionElementBase element) {
		this.entity = element;

		if(element.getMedia().size() == 0){
			element.addMedia(Media.NewInstance());
		}
		media = element.getMedia().iterator().next();

		if(media.getRepresentations().size() == 0){
			media.addRepresentation(MediaRepresentation.NewInstance());
		}
		mediaRepresentation = media.getRepresentations().iterator().next();

		if(mediaRepresentation.getParts().size() == 0){
			mediaRepresentation.addRepresentationPart(MediaRepresentationPart.NewInstance(null, null));
		}

		mediaRepresentationPart = mediaRepresentation.getParts().iterator().next();

		if(mediaRepresentationPart.getUri() != null){
			protologueUriText.setText(mediaRepresentationPart.getUri().toString());
		}
	}

	/**
	 * <p>Getter for the field <code>selectionArbitrator</code>.</p>
	 *
	 * @return a {@link eu.etaxonomy.taxeditor.ui.element.SelectionArbitrator} object.
	 */
	@Override
    public SelectionArbitrator getSelectionArbitrator() {
		return selectionArbitrator;
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if(eventSource == protologueUriText && protologueUriText.getText()!=null){
		    mediaRepresentationPart.setUri(protologueUriText.parseText());
		}
	}

	@Override
	public void setOpenUrl(URI uri) {
		protologueUriText.setText(uri.toString());
		firePropertyChangeEvent(new CdmPropertyChangeEvent(protologueUriText, null));
	}

	@Override
	public Reference getReference() {
		return (Reference) getName().getNomenclaturalReference();
	}

	@Override
	public String getDetail() {
		return getName().getNomenclaturalMicroReference();
	}

	private TaxonNameBase getName(){
		TaxonNameDescription description = (TaxonNameDescription) entity.getInDescription();

		TaxonNameBase taxonName = description.getTaxonName();

		return taxonName;
	}
}
