/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.occurrence;

import org.eclipse.ui.forms.widgets.ExpandableComposite;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.GatheringEventUnitElement;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.LayoutConstants;
import eu.etaxonomy.taxeditor.ui.element.MinMaxTextSection;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;

/**
 * <p>
 * GatheringEventDetailElement class.
 * </p>
 *
 * @author n.hoffmann
 * @created Jun 24, 2010
 * @version 1.0
 */
public class GatheringEventDetailElement extends
		AbstractCdmDetailElement<DerivedUnitFacade> {

	private GatheringEventUnitElement element_elevation;

	private GatheringEventUnitElement element_distToGround;

	private GatheringEventUnitElement element_distToWater;

	private TextWithLabelElement text_collectingMethod;

	private TextWithLabelElement text_gatheringEventDescription;

	private CollectingAreasDetailSection section_collectingAreas;

	/**
	 * <p>
	 * Constructor for GatheringEventDetailElement.
	 * </p>
	 *
	 * @param formFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement}
	 *            object.
	 */
	public GatheringEventDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement, DerivedUnitFacade entity, int style) {

	    text_collectingMethod = formFactory.createTextWithLabelElement(formElement, "Collecting Method", entity.getCollectingMethod(), style);

        text_gatheringEventDescription = formFactory.createTextWithLabelElement(
        		formElement, "Gathering Event Description", entity.getGatheringEventDescription(), style);

		element_distToGround = formFactory.createGatheringEventUnitElement(
				formElement, "Dist. To Ground : ", entity, MinMaxTextSection.UnitType.DIST_TO_GROUND,  style);

		element_distToWater = formFactory.createGatheringEventUnitElement(
				formElement, "Dist. To Watersurface : ", entity, MinMaxTextSection.UnitType.DIST_TO_WATER,  style);


        if(!PreferencesUtil.getPreferenceStore().getBoolean(IPreferenceKeys.SHOW_COLLECTING_AREAS_IN_GENERAL_SECTION)){
            section_collectingAreas = formFactory.createCollectingAreasDetailSection(getConversationHolder(), formElement, ExpandableComposite.TWISTIE);
            section_collectingAreas.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
            section_collectingAreas.setEntity(entity);
        }

	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == text_collectingMethod) {
			getEntity().setCollectingMethod(text_collectingMethod.getText());
		} else if (eventSource == text_gatheringEventDescription) {
			getEntity().setGatheringEventDescription(
					text_gatheringEventDescription.getText());
		}
	}
}
