/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.occurrence;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.cdm.model.occurrence.DerivedUnit;
import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationType;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;

/**
 * <p>SpecimenCollectionDetailSection class.</p>
 *
 * @author n.hoffmann
 * @created Oct 14, 2010
 * @version 1.0
 */
public class SpecimenCollectionDetailSection extends
		AbstractEntityCollectionSection<DerivedUnitFacade, DerivedUnit> {

	/**
	 * <p>Constructor for SpecimenCollectionDetailSection.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement} object.
	 * @param style a int.
	 */
	public SpecimenCollectionDetailSection(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement, int style) {
		super(formFactory, conversation, parentElement, "Duplicates", style);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#getCollection(java.lang.Object)
	 */
	/** {@inheritDoc} */
	@Override
	public Collection<DerivedUnit> getCollection(DerivedUnitFacade entity) {
		return entity.getDuplicates();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#createNewElement()
	 */
	/** {@inheritDoc} */
	@Override
	public DerivedUnit createNewElement() {
		return DerivedUnit.NewInstance(SpecimenOrObservationType.PreservedSpecimen);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#addElement(eu.etaxonomy.cdm.model.common.IVersionableEntity)
	 */
	/** {@inheritDoc} */
	@Override
	public void addElement(DerivedUnit element) {
		getEntity().addDuplicate(element);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#removeElement(eu.etaxonomy.cdm.model.common.IVersionableEntity)
	 */
	/** {@inheritDoc} */
	@Override
	public void removeElement(DerivedUnit element) {
		getEntity().removeDuplicate(element);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#getEmptyString()
	 */
	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No duplicates yet.";
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#getTooltipString()
	 */
	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Add a duplicate";
	}

    /**
     * {@inheritDoc}
     */
    @Override
    public DerivedUnit addExisting() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        return false;
    }

}
