/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.reference;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * <p>
 * NomenclaturalReferenceDetailElement class.
 * </p>
 *
 * @author n.hoffmann
 * @created Mar 12, 2010
 * @version 1.0
 */
public class NomenclaturalReferenceDetailElement extends
		AbstractCdmDetailElement<TaxonNameBase> {

	private EntitySelectionElement<Reference> selection_nomenclaturalReference;
	private TextWithLabelElement text_referenceDetail;

	/**
	 * <p>
	 * Constructor for NomenclaturalReferenceDetailElement.
	 * </p>
	 *
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement}
	 *            object.
	 * @param style
	 *            a int.
	 */
	public NomenclaturalReferenceDetailElement(CdmFormFactory cdmFormFactory,
			ICdmFormElement formElement, int style) {
		super(cdmFormFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			TaxonNameBase entity, int style) {
		selection_nomenclaturalReference = formFactory
				.createSelectionElementWithAbbreviatedTitle(Reference.class,
						getConversationHolder(), formElement, "Reference",
						(Reference) entity.getNomenclaturalReference(),
						EntitySelectionElement.ALL, style);
		text_referenceDetail = formFactory.createTextWithLabelElement(
				formElement, "Reference Detail",
				entity.getNomenclaturalMicroReference(), style);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == selection_nomenclaturalReference) {
			getEntity().setNomenclaturalReference(
					selection_nomenclaturalReference.getSelection());
		} else if (eventSource == text_referenceDetail) {
			getEntity().setNomenclaturalMicroReference(
					text_referenceDetail.getText());
		}
	}
}
