/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.supplemental;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.common.ReferencedEntityBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.taxeditor.ui.element.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.ISelectableElement;
import eu.etaxonomy.taxeditor.ui.element.SelectionArbitrator;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * @author n.hoffmann
 * @created Mar 25, 2010
 * @version 1.0
 */
public abstract class AbstractReferencedEntityElement<T extends ReferencedEntityBase>
		extends AbstractEntityCollectionElement<T> implements ISelectableElement {

	private SelectionArbitrator selectionArbitrator;
	
	protected EntitySelectionElement<Reference> selection_reference;
	protected TextWithLabelElement text_referenceDetail;

	public AbstractReferencedEntityElement(CdmFormFactory formFactory,
			AbstractFormSection section, T entity,
			SelectionListener removeListener, int style) {
		super(formFactory, section, entity, removeListener, null, style);
		// make this element selectable
		if(formFactory.getSelectionProvider() != null){
			selectionArbitrator = formFactory.createSelectionArbitrator(this);
		}
	}

	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement formElement, int style) {
		selection_reference = formFactory
				.createSelectionElement(Reference.class,
						getConversationHolder(), formElement, "Reference",
						null, EntitySelectionElement.ALL, style);
		text_referenceDetail = formFactory.createTextWithLabelElement(
				formElement, "Reference Detail", null, SWT.NULL);
	}

	@Override
	public void setEntity(T entity) {
		this.entity = entity;

		selection_reference.setEntity(entity.getCitation());
		text_referenceDetail.setText(entity.getCitationMicroReference());
	}
	
	@Override
    public SelectionArbitrator getSelectionArbitrator() {
		return selectionArbitrator;
	}

}
