/**
 * 
 */
package eu.etaxonomy.taxeditor.ui.section.supplemental;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.common.AnnotatableEntity;
import eu.etaxonomy.cdm.model.common.Annotation;
import eu.etaxonomy.cdm.model.common.AnnotationType;
import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;

/**
 * <p>AnnotationSection class.</p>
 *
 * @author n.hoffmann
 * @created Nov 5, 2009
 * @version 1.0
 */
public class AnnotationSection extends AbstractEntityCollectionSection<AnnotatableEntity, Annotation>{

	/**
	 * <p>Constructor for AnnotationSection.</p>
	 *
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.element.ICdmFormElement} object.
	 * @param style a int.
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.element.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 */
	public AnnotationSection(CdmFormFactory cdmFormFactory, ConversationHolder conversation, ICdmFormElement parentElement, int style) {
		super(cdmFormFactory, conversation, parentElement, "Annotations", style);
	}

	/** {@inheritDoc} */
	@Override
	public Annotation createNewElement() {
		String text = "";
		AnnotationType type = AnnotationType.EDITORIAL();
		Language language = CdmStore.getDefaultLanguage();
		
		return Annotation.NewInstance(text, type, language);
	}

	/** {@inheritDoc} */
	@Override
	public Collection<Annotation> getCollection(AnnotatableEntity entity) {
		return entity.getAnnotations();
	}

	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No annotations yet.";
	}

	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Create a new annotation";
	}

	/** {@inheritDoc} */
	@Override
	public void addElement(Annotation element) {
		getEntity().addAnnotation(element);
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(Annotation element) {
		getEntity().removeAnnotation(element);
	}

    /**
     * {@inheritDoc}
     */
    @Override
    public Annotation addExisting() {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        // TODO Auto-generated method stub
        return false;
    }	
}
