/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.supplemental.identifier;

import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.common.DefinedTerm;
import eu.etaxonomy.cdm.model.common.Identifier;
import eu.etaxonomy.cdm.model.common.TermType;
import eu.etaxonomy.taxeditor.ui.combo.TermComboElement;
import eu.etaxonomy.taxeditor.ui.element.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;

/**
 *
 * @author pplitzner
 *
 */
public class IdentifierElement extends AbstractEntityCollectionElement<Identifier> {

	private TextWithLabelElement textIdentifier;

	private TermComboElement<DefinedTerm> comboIdentifierType;

    public IdentifierElement(CdmFormFactory formFactory,
            AbstractFormSection section, Identifier entity,
            SelectionListener removeListener, int style) {
        super(formFactory, section, entity, removeListener, null, style);
    }

    /** {@inheritDoc} */
    @Override
    public void setEntity(Identifier entity) {
        this.entity = entity;
        textIdentifier.setText(entity.getIdentifier());
        comboIdentifierType.setSelection(entity.getType());
    }

	/** {@inheritDoc} */
	@Override
    public void createControls(ICdmFormElement formElement, int style) {
	    comboIdentifierType = formFactory.createDefinedTermComboElement(TermType.IdentifierType, formElement, "Type", null, style);
		textIdentifier = formFactory.createTextWithLabelElement(formElement, "Identifier", null, style);
	}

	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == textIdentifier) {
			getEntity().setIdentifier(textIdentifier.getText());
		} else if (eventSource == comboIdentifierType) {
			getEntity().setType(comboIdentifierType.getSelection());
		}
	}

}
