/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.taxon;

import java.util.Arrays;

import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;

import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.SynonymType;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.cdm.persistence.hibernate.permission.Role;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.combo.TermComboElement;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.CheckboxElement;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractIdentifiableEntityDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * @author n.hoffmann
 * @created Feb 26, 2010
 * @version 1.0
 */
public class TaxonBaseDetailElement extends AbstractIdentifiableEntityDetailElement<TaxonBase> {

	private CheckboxElement checkbox_doubtful;

	private CheckboxElement checkbox_useNameCache;

	private EntitySelectionElement<Reference> selection_secundum;

	private TextWithLabelElement text_secundum_microreference;

	private TextWithLabelElement text_appendedPhrase;

	private CheckboxElement checkbox_published;

    private TermComboElement<SynonymType> combo_relationshipType;
    private CheckboxElement checkProParte;
    private CheckboxElement checkPartial;

	public TaxonBaseDetailElement(CdmFormFactory cdmFormFactory,
			ICdmFormElement formElement, int style) {
		super(cdmFormFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement, TaxonBase entity, int style) {
			toggleable_cache = formFactory.createToggleableTextField(formElement,
					"Title Cache", entity.getTitleCache(),
					entity.isProtectedTitleCache(), style);

		//TODO RL
		boolean rl=true;

		text_appendedPhrase = formFactory.createTextWithLabelElement(
					formElement, "Appended Phrase", entity.getAppendedPhrase(),
					SWT.WRAP);



		selection_secundum = formFactory.createSelectionElement(Reference.class,
				getConversationHolder(), formElement, "Secundum",
				entity.getSec(), EntitySelectionElement.ALL,
				style);

		text_secundum_microreference = formFactory.createTextWithLabelElement(
                formElement, "Detail",
               entity.getSecMicroReference(),null,
                SWT.WRAP);


		checkbox_useNameCache = formFactory.createCheckbox(formElement,
					"Exclude Authorship", entity.isUseNameCache(), style);
		checkbox_doubtful = formFactory.createCheckbox(formElement,
					entity.getClass().getSimpleName() + " is doubtful", entity.isDoubtful(), style);


		if (entity instanceof Taxon) {
			checkbox_published = formFactory.createCheckbox(formElement,
					"Taxon is published", ((Taxon) entity).isPublish(), style);
		}

		if(entity instanceof Synonym){
		    //#6198 removed type as it is currently not handled correctly in the editor
//		    combo_relationshipType = formFactory.createDefinedTermComboElement(TermType.SynonymType, formElement, "Synonym Type", ((Synonym) entity).getType(), style);
	        checkProParte = formFactory.createCheckbox(formElement, "Pro Parte Synonym", ((Synonym) entity).isProParte(), style);
	        checkPartial= formFactory.createCheckbox(formElement, "Partial Synonym", ((Synonym) entity).isPartial(), style);
		}
	}

    private void updateCheckboxPublish() {
        if(getEntity() instanceof Taxon){
            checkbox_published.setEnabled(
            		CdmStore.currentAuthentiationHasOneOfRoles(Role.ROLE_PUBLISH, Role.ROLE_ADMIN)
            		);
        }
    }

	@Override
    protected void updateControlStates() {
        super.updateControlStates();
        updateCheckboxPublish();
    }

    /** {@inheritDoc} */
	@Override
	protected void updateContent() {
		super.updateContent();
		toggleable_cache.setEnabled(getEntity().isProtectedTitleCache());
		setIrrelevant(toggleable_cache.getState(),
				Arrays.asList(new Object[] { toggleable_cache, checkbox_published}));
	}

	@Override
	protected void handleTitleCacheRelevantChange(PropertyChangeEvent event) {
		String title = getEntity().generateTitle();
		getEntity().setTitleCache(title);
		super.handleTitleCacheRelevantChange(event);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource== toggleable_cache) {
			handleToggleableCacheField();
		} else if (eventSource == checkbox_doubtful) {
			getEntity().setDoubtful(checkbox_doubtful.getSelection());
		} else if (eventSource == checkbox_useNameCache) {
			getEntity().setUseNameCache(checkbox_useNameCache.getSelection());
		} else if (eventSource == selection_secundum) {
			getEntity().setSec(selection_secundum.getSelection());
		} else if (eventSource == text_appendedPhrase) {
			getEntity().setAppendedPhrase(text_appendedPhrase.getText());
		} else if (eventSource == text_secundum_microreference) {
            getEntity().setSecMicroReference(text_secundum_microreference.getText());
		} else if (eventSource == checkbox_published) {
		    ((Taxon)getEntity()).setPublish(checkbox_published.getSelection());
		} else if(eventSource == combo_relationshipType){
            ((Synonym) getEntity()).setType(combo_relationshipType.getSelection());
        } else if(eventSource == checkPartial){
            ((Synonym) getEntity()).setPartial(checkPartial.getSelection());
        } else if(eventSource == checkProParte){
            ((Synonym) getEntity()).setProParte(checkProParte.getSelection());
        }
	}
	@Override
	protected void handleToggleableCacheField() {
        boolean pushedState = toggleable_cache.getState();

        getEntity().setTitleCache(toggleable_cache.getText(), pushedState);
        setIrrelevant(pushedState, Arrays.asList(new Object[] { toggleable_cache, checkbox_published}));
        updateToggleableCacheField();
    }
}
