/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.section.taxon;

import org.eclipse.ui.IEditorInput;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.taxeditor.model.TaxonRelationshipTypeInverseContainer;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.combo.TermComboElement;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.element.CheckboxElement;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * @author n.hoffmann
 * @date Dec 1, 2011
 *
 */
public class TaxonRelationshipDetailElement extends AbstractCdmDetailElement<TaxonRelationship> {

	private TermComboElement<TaxonRelationshipTypeInverseContainer> combo_taxonRelationshipType;
	
	private EntitySelectionElement<Taxon> selection_relatedTaxon;
	
	private CheckboxElement checkBoxDoubtful;

	public TaxonRelationshipDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
	}

	@Override
	protected void createControls(ICdmFormElement formElement,
			TaxonRelationship entity, int style) {
		combo_taxonRelationshipType = formFactory.createTermComboElement(
				TaxonRelationshipTypeInverseContainer.class, 
				formElement, "Relationship Type", 
				getTaxonRelationshipTypeInverseContainer(), style);
		combo_taxonRelationshipType.setEnabled(false);
		selection_relatedTaxon = formFactory.createSelectionElement(
				Taxon.class, getConversationHolder(), 
				formElement, "Related Taxon", getRelatedTaxon(), 
				EntitySelectionElement.SELECTABLE, style);
		checkBoxDoubtful = formFactory.createCheckbox(formElement, "Relation is doubtful", entity.isDoubtful(), style);
	}
	
	private Taxon getRelatedTaxon() {
		return TaxonRelationshipTypeInverseContainer.RelatedTaxon(getSourceTaxon(), getEntity());
	}

	private TaxonRelationshipTypeInverseContainer getTaxonRelationshipTypeInverseContainer(){
		return TaxonRelationshipTypeInverseContainer.CreateFromSource(getSourceTaxon(), getEntity());
	}
	
	private Taxon getSourceTaxon(){
		IEditorInput editorInput = StoreUtil.getActiveEditorInput();
		return (Taxon) editorInput.getAdapter(Taxon.class);
	}

	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == selection_relatedTaxon){
			boolean inverse = getTaxonRelationshipTypeInverseContainer().isInverse();
			Taxon relatedTaxon = selection_relatedTaxon.getEntity();
			if(inverse){
				getEntity().setFromTaxon(relatedTaxon);
			}else{
				getEntity().setToTaxon(relatedTaxon);
			}
		}
		else if(eventSource==checkBoxDoubtful){
		    getEntity().setDoubtful(checkBoxDoubtful.getSelection());
		}
		firePropertyChangeEvent(new CdmPropertyChangeEvent(this, null));
	}
}
