/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.section.vocabulary;

import org.eclipse.ui.forms.widgets.ExpandableComposite;

import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.CheckboxElement;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.LayoutConstants;

/**
 * @author l.morris
 * @date 20 Dec 2011
 *
 */
public class FeatureDetailElement extends DefinedTermDetailElement<Feature> {

    private ICdmFormElement parentFormElement;

    private CheckboxElement supportsTextData;

    private CheckboxElement supportsQuantitativeData;

    private CheckboxElement supportsDistribution;

    private CheckboxElement supportsIndividualAssociation;

    private CheckboxElement supportsTaxonInteraction;

    private CheckboxElement supportsCategoricalData;

    private CheckboxElement supportsCommonTaxonName;

    private StateVocabularyCollectionSection sectionStateVocabularies;

    private MeasurementUnitCollectionSection sectionMeasurementUnits;

    private StatisticalMeasureCollectionSection sectionStatisticalMeasures;

    private RecommendedModifierVocabulariesCollectionSection sectionModifierVocabularies;

    /**
	 * @param formFactory
	 * @param formElement
	 */
	public FeatureDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.vocabulary.AbstractTermBaseDetailElement#createControls(eu.etaxonomy.taxeditor.ui.element.ICdmFormElement, eu.etaxonomy.cdm.model.common.TermBase, int)
	 */
	@Override
	protected void createControls(ICdmFormElement formElement, Feature entity, int style) {
	    super.createControls(formElement, entity, style);
	    this.parentFormElement = formElement;
	    supportsTextData = formFactory.createCheckbox(formElement, "Supports Text Data", entity.isSupportsTextData(), style);
	    supportsQuantitativeData = formFactory.createCheckbox(formElement, "Supports Quantitative Data", entity.isSupportsQuantitativeData(), style);
	    supportsDistribution = formFactory.createCheckbox(formElement, "Supports Distribution", entity.isSupportsDistribution(), style);
	    supportsIndividualAssociation = formFactory.createCheckbox(formElement, "Supports Individual Association", entity.isSupportsIndividualAssociation(), style);
	    supportsTaxonInteraction = formFactory.createCheckbox(formElement, "Supports Taxon Interaction", entity.isSupportsTaxonInteraction(), style);
	    supportsCategoricalData = formFactory.createCheckbox(formElement, "Supports Categorical Data", entity.isSupportsCategoricalData(), style);
	    supportsCommonTaxonName = formFactory.createCheckbox(formElement, "Supports Common Taxon Name", entity.isSupportsCommonTaxonName(), style);

        if (supportsCategoricalData.getSelection()) {
            sectionStateVocabularies = formFactory.createStateVocabulariesSection(getConversationHolder(),
                    parentFormElement, ExpandableComposite.TWISTIE);
            sectionStateVocabularies.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
            sectionStateVocabularies.setEntity(getEntity());

        }
        if (supportsQuantitativeData.getSelection()) {
            sectionMeasurementUnits = formFactory.createMeasurementUnitCollectionSection(getConversationHolder(),
                    parentFormElement, ExpandableComposite.TWISTIE);
            sectionMeasurementUnits.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
            sectionMeasurementUnits.setEntity(getEntity());

            sectionStatisticalMeasures = formFactory.createStatisticalMeasureCollectionSection(getConversationHolder(),
                    parentFormElement, ExpandableComposite.TWISTIE);
            sectionStatisticalMeasures.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
            sectionStatisticalMeasures.setEntity(getEntity());
        }
        if (supportsCategoricalData.getSelection() || supportsQuantitativeData.getSelection()) {
            sectionModifierVocabularies = formFactory.createRecommendedModifierVocabulariesCollectionSection(
                    getConversationHolder(), parentFormElement, ExpandableComposite.TWISTIE
                           );
            sectionModifierVocabularies.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
            sectionModifierVocabularies.setEntity(getEntity());
        }
    }

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.vocabulary.DefinedTermDetailElement#handleEvent(java.lang.Object)
	 */
	@Override
	public void handleEvent(Object eventSource) {
	    super.handleEvent(eventSource);
	    if(eventSource == supportsTextData){
	        getEntity().setSupportsTextData(supportsTextData.getSelection());
	    }
	    else if(eventSource == supportsQuantitativeData){
	        getEntity().setSupportsQuantitativeData(supportsQuantitativeData.getSelection());
	        if(supportsQuantitativeData.getSelection()){
                removeElementsAndControls(supportsDistribution);
                sectionMeasurementUnits = formFactory.createMeasurementUnitCollectionSection(getConversationHolder(),
                        parentFormElement, ExpandableComposite.TWISTIE);
                sectionMeasurementUnits.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
                sectionMeasurementUnits.setEntity(getEntity());

                sectionStatisticalMeasures = formFactory.createStatisticalMeasureCollectionSection(
                        getConversationHolder(), parentFormElement, ExpandableComposite.TWISTIE);
                sectionStatisticalMeasures.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
                sectionStatisticalMeasures.setEntity(getEntity());

                if (!supportsCategoricalData.getSelection()) {
                    sectionModifierVocabularies = formFactory.createRecommendedModifierVocabulariesCollectionSection(
                            getConversationHolder(), parentFormElement, ExpandableComposite.TWISTIE);
                    sectionModifierVocabularies.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
                    sectionModifierVocabularies.setEntity(getEntity());
                }
	        }
	        else{
	            if(sectionMeasurementUnits!=null){
	                removeElementsAndControls(sectionMeasurementUnits);
	                removeElementsAndControls(sectionStatisticalMeasures);
	                if(!supportsCategoricalData.getSelection()){
	                    removeElementsAndControls(sectionModifierVocabularies);
	                }
	            }
	        }
	    }
	    else if(eventSource == supportsDistribution){
	        getEntity().setSupportsDistribution(supportsDistribution.getSelection());
	    }
	    else if(eventSource == supportsIndividualAssociation){
	        getEntity().setSupportsIndividualAssociation(supportsIndividualAssociation.getSelection());
	    }
	    else if(eventSource == supportsTaxonInteraction){
	        getEntity().setSupportsTaxonInteraction(supportsTaxonInteraction.getSelection());
	    }
	    else if(eventSource == supportsCategoricalData){
	        getEntity().setSupportsCategoricalData(supportsCategoricalData.getSelection());
            if (supportsCategoricalData.getSelection()) {
                sectionStateVocabularies = formFactory.createStateVocabulariesSection(getConversationHolder(),
                        parentFormElement, ExpandableComposite.TWISTIE);
                sectionStateVocabularies.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
                sectionStateVocabularies.setEntity(getEntity());

                if (!supportsQuantitativeData.getSelection()) {
                    sectionModifierVocabularies = formFactory.createRecommendedModifierVocabulariesCollectionSection(
                            getConversationHolder(), parentFormElement, ExpandableComposite.TWISTIE);
                    sectionModifierVocabularies.setLayoutData(LayoutConstants.FILL_HORIZONTALLY(2, 1));
                    sectionModifierVocabularies.setEntity(getEntity());
                }
            }
	        else{
	            if(sectionStateVocabularies!=null){
	                removeElementsAndControls(sectionStateVocabularies);
	                if(!supportsQuantitativeData.getSelection()){
	                    removeElementsAndControls(sectionModifierVocabularies);
	                }
	            }
	        }
	    }
	    else if(eventSource == supportsCommonTaxonName){
	        getEntity().setSupportsCommonTaxonName(supportsCommonTaxonName.getSelection());
	    }
	}

}
