/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.section.vocabulary;

import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Color;

import eu.etaxonomy.cdm.model.common.TermType;
import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.cdm.model.description.MeasurementUnit;
import eu.etaxonomy.taxeditor.ui.combo.TermComboElement;
import eu.etaxonomy.taxeditor.ui.element.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;

/**
 * @author pplitzner
 * @date Apr 27, 2015
 *
 */
public class MeasurementUnitCollectionElement extends AbstractEntityCollectionElement<MeasurementUnit> {


    private TermComboElement<MeasurementUnit> comboMeasurementUnit;

    /**
     * @param formFactory
     * @param section
     * @param entity
     * @param removeListener
     * @param isChoosableEntity
     * @param backgroundColor
     * @param style
     */
    public MeasurementUnitCollectionElement(CdmFormFactory formFactory, AbstractFormSection section, MeasurementUnit entity,
            SelectionListener removeListener, Color backgroundColor, int style) {
        super(formFactory, section, entity, removeListener, backgroundColor, style);

    }

    @Override
    public void createControls(ICdmFormElement element, int style) {
        comboMeasurementUnit = formFactory.createDefinedTermComboElement(TermType.MeasurementUnit, element, "Measurement unit", null, style);
    }

    @Override
    public void setEntity(MeasurementUnit entity) {
        this.entity = entity;
        if(entity.getId()!=0){
            comboMeasurementUnit.setSelection(entity);
            comboMeasurementUnit.removeEmptyElement();
        }
    }

    @Override
    public void handleEvent(Object eventSource) {
        if(eventSource==comboMeasurementUnit && comboMeasurementUnit.getSelection()!=null){
            if(getParentElement() instanceof MeasurementUnitCollectionSection){
                MeasurementUnitCollectionSection parentElement = (MeasurementUnitCollectionSection) getParentElement();
                Feature feature = parentElement.getEntity();
                feature.removeRecommendedMeasurementUnit(entity);
                MeasurementUnit measurementUnit = comboMeasurementUnit.getSelection();
                feature.addRecommendedMeasurementUnit(measurementUnit);
                entity = measurementUnit;
                //update the parent section to re-set the listeners to the persisted measurement unit
                parentElement.removeElementAndUpdate(null);
            }
        }
    }

}
