/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.section.vocabulary;

import java.text.ParseException;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.ColorDialog;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.forms.widgets.TableWrapData;

import eu.etaxonomy.cdm.model.common.TermVocabulary;
import eu.etaxonomy.cdm.model.description.PresenceAbsenceTerm;
import eu.etaxonomy.taxeditor.l10n.Messages;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.ImageResources;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.LayoutConstants;

/**
 *
 * @author pplitzner
 * @date Nov 24, 2016
 *
 */
public class PresenceAbsenceTermDetailElement extends DefinedTermDetailElement<PresenceAbsenceTerm> implements SelectionListener{

    private Label colorLabel;

    private Color color;

    private Button btnColorChooser;

	public PresenceAbsenceTermDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
	}

	@Override
    protected void createControls(ICdmFormElement formElement, PresenceAbsenceTerm entity, int style) {
	    super.createControls(formElement, entity, style);

	    Label colorTextLabel = new Label(getLayoutComposite(), style);
	    colorTextLabel.setText(Messages.PresenceAbsenceTermDetailElement_LABEL_COLOR);
	    TableWrapData left = LayoutConstants.LEFT();
	    left.valign = TableWrapData.MIDDLE;
	    colorTextLabel.setLayoutData(left);
	    addControl(colorTextLabel);

	    //composite(color label + button)
        Composite colorAndButton = formFactory.createComposite(getLayoutComposite(), style);
        addControl(colorAndButton);
        GridLayout layout = new GridLayout(2, false);
        layout.marginWidth = 0;
        colorAndButton.setLayout(layout);

        colorLabel = new Label(colorAndButton, style|SWT.BORDER);
        colorLabel.setLayoutData(new GridData(16, 16));

        String defaultColor = entity.getDefaultColor();
        if(defaultColor!=null){
            //TODO: Is there any utility method from SWT?
            java.awt.Color awtColor = java.awt.Color.decode("#"+defaultColor); //$NON-NLS-1$
            RGB rgb = new RGB(awtColor.getRed(), awtColor.getGreen(), awtColor.getBlue());
            color = new Color(AbstractUtility.getShell().getDisplay(), rgb);
            colorLabel.setBackground(color);
        }

        //button
        btnColorChooser = formFactory.createButton(colorAndButton, "", SWT.NONE); //$NON-NLS-1$
        btnColorChooser.setImage(ImageResources.getImage(ImageResources.BROWSE_ICON));
        btnColorChooser.setToolTipText(Messages.PresenceAbsenceTermDetailElement_CHOOSE_COLOR);
        btnColorChooser.addSelectionListener(this);
	}

	@Override
	public void handleEvent(Object eventSource) {
	    super.handleEvent(eventSource);
	}

	@Override
	public TermVocabulary getVocabulary() {
		return getEntity() != null ? getEntity().getVocabulary() : null;
	}

    /**
     * {@inheritDoc}
     */
    @Override
    public void widgetSelected(SelectionEvent e) {
        ColorDialog dialog = new ColorDialog(AbstractUtility.getShell());
        if(color!=null){
            dialog.setRGB(color.getRGB());
        }
        RGB rgb = dialog.open();
        if(rgb!=null){
            if(color!=null){
                color.dispose();
            }
            color = new Color(AbstractUtility.getShell().getDisplay(), rgb);
            colorLabel.setBackground(color);
            try {
                String hexCode = String.format("%02x%02x%02x", rgb.red,rgb.green,rgb.blue); //$NON-NLS-1$
                getEntity().setDefaultColor(hexCode);
            } catch (ParseException pe) {
                MessagingUtils.error(PresenceAbsenceTermDetailElement.class, Messages.PresenceAbsenceTermDetailElement_COLOR_NOT_SET, pe);
            }
        }
        firePropertyChangeEvent(new CdmPropertyChangeEvent(this, e));
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void widgetDefaultSelected(SelectionEvent e) {
    }

}
