/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.section.vocabulary;

import org.eclipse.jface.wizard.Wizard;

import eu.etaxonomy.cdm.model.common.Representation;
import eu.etaxonomy.cdm.model.common.TermBase;
import eu.etaxonomy.taxeditor.ui.translation.TermTranslationWizardPage;

/**
 * @author k.luther
 * @date 22.06.2016
 *
 */
public class TermTranslationWizard extends Wizard {
    private TermTranslationWizardPage page;

    private final TermBase term;

    /**
     * <p>Constructor for TranslationWizard.</p>
     *
     * @param multilanguageText a {@link java.util.Map} object.
     */
    public TermTranslationWizard(TermBase term) {
        setWindowTitle("Translation Editor");
        this.term = term;
        setNeedsProgressMonitor(true);
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.wizard.Wizard#addPages()
     */
    /** {@inheritDoc} */
    @Override
    public void addPages() {
        page = new TermTranslationWizardPage(term);
        addPage(page);
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.wizard.Wizard#performFinish()
     */
    /** {@inheritDoc} */
    @Override
    public boolean performFinish() {
        Representation representation = page.getTargetRepresentation();
        
        if (representation.getLanguage() == null){
        	return false;
        }
        if (!representation.getText().equals("") || !representation.getLabel().equals("") || !representation.getAbbreviatedLabel().equals("")) {
            term.addRepresentation(representation);
        }

        return true;
    }
}
