/**
 * Copyright (C) 2014 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.view.dataimport;

import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import java.util.ArrayList;
import java.util.Collection;

import org.apache.http.client.ClientProtocolException;
import org.eclipse.swt.widgets.Display;

import eu.etaxonomy.cdm.ext.occurrence.OccurenceQuery;
import eu.etaxonomy.cdm.ext.occurrence.bioCase.BioCaseQueryServiceWrapper;
import eu.etaxonomy.cdm.io.common.CdmDefaultImport;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportConfigurator;
import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationBase;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author pplitzner
 * @date 25.02.2014
 *
 */
public class BioCaseEditorInput extends DataImportEditorInput<SpecimenOrObservationBase<?>> {

    private final URI endPoint;

    /**
     * Constructs a new BioCaseEditorInput.
     * @param query The {@link OccurenceQuery} object holding all necessary parameters.
     * @param endPoint If the endPoint {@link URI} is <code>null</code> then the default endPoint is used
     * (<i>http://ww3.bgbm.org/biocase/pywrapper.cgi?dsa=Herbar</i>)
     */
    public BioCaseEditorInput(OccurenceQuery query, URI endPoint) {
        super();
        this.query = query;
        this.endPoint = endPoint;
    }

    @Override
    public void query(){
        String errorMessage = "Could not execute query " + query;

        Collection<SpecimenOrObservationBase<?>> results = new ArrayList<SpecimenOrObservationBase<?>>();
        try {
            //FIXME move ABCD import to cdmlib -> this will also get rid of the transient services
            InputStream resultStream;
            resultStream = new BioCaseQueryServiceWrapper().query(query, endPoint);
            Abcd206ImportConfigurator configurator = Abcd206ImportConfigurator.NewInstance(endPoint, null, false);
           /* TransientCdmRepository repo =
                    new TransientCdmRepository(CdmStore.getCurrentApplicationConfiguration());
            configurator.setCdmAppController(repo);
*/
            CdmDefaultImport<Abcd206ImportConfigurator> importer = new CdmDefaultImport<Abcd206ImportConfigurator>();
            importer.invoke(configurator);
           // results = repo.getUnits();
            setResults(results);
        } catch (ClientProtocolException e) {
            logger.error(errorMessage, e);
        } catch (IOException e) {
            logger.error(errorMessage, e);
        }

        setResults(results);

        Display.getDefault().asyncExec(new Runnable() {

            @Override
            public void run() {
                CdmStore.getContextManager().notifyContextRefresh();
            }
        });
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getName()
     */
    @Override
    public String getName() {
        return "[BioCASE] " + query.toString();
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getToolTipText()
     */
    @Override
    public String getToolTipText() {
        return "[BioCASE] " + query.toString();
    }

    /* (non-Javadoc)
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((query == null) ? 0 : query.hashCode());
        return result;
    }

    /* (non-Javadoc)
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        BioCaseEditorInput other = (BioCaseEditorInput) obj;
        if (query == null) {
            if (other.query != null) {
                return false;
            }
        } else if (!query.equals(other.query)) {
            return false;
        }
        return true;
    }
}
