package eu.etaxonomy.taxeditor.view.dataimport;

import java.io.IOException;
import java.net.URI;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.apache.http.client.ClientProtocolException;
import org.apache.log4j.Logger;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.action.Action;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableItem;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.ITermService;
import eu.etaxonomy.cdm.ext.occurrence.OccurenceQuery;
import eu.etaxonomy.cdm.ext.occurrence.bioCase.BioCaseResponse;
import eu.etaxonomy.cdm.ext.occurrence.gbif.DataSetResponse;
import eu.etaxonomy.cdm.ext.occurrence.gbif.GbifDataSetProtocol;
import eu.etaxonomy.cdm.ext.occurrence.gbif.GbifQueryServiceWrapper;
import eu.etaxonomy.cdm.ext.occurrence.gbif.GbifResponse;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportConfigurator;
import eu.etaxonomy.cdm.io.specimen.gbif.in.GbifImportConfigurator;
import eu.etaxonomy.cdm.model.common.DefinedTermBase;
import eu.etaxonomy.taxeditor.store.CdmStore;

public class SaveImportedSpecimenAction extends Action {

    private final Logger logger = Logger.getLogger(SaveImportedSpecimenAction.class);

    private Comparator<GbifResponse> comparator;

    /* (non-Javadoc)
     * @see org.eclipse.jface.action.Action#run()
     */
    @Override
    public void run() {
        final IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
        IWorkbenchPart activePart = window.getActivePage().getActivePart();
        if(activePart instanceof DataImportView<?>){
            DataImportView<?> dataImportView = (DataImportView<?>)activePart;
            Table table = dataImportView.getTable();
            Collection<GbifResponse> checkedResults = new HashSet<GbifResponse>();
            Collection<BioCaseResponse> checkedAbcdResults = new HashSet<BioCaseResponse>();
            Object data;
            Set<String[]> unitIdsGbif = new HashSet<String[]>();
            Set<String[]> unitIdsBioCase = new HashSet<String[]>();
            List<GbifResponse> biocaseResponses = new ArrayList<GbifResponse>();

            for(TableItem item:table.getItems()){
                if(item.getChecked()){
                    //Save Specimen
                	 data = item.getData();
                	 if(data instanceof GbifResponse){
                		 checkedResults.add((GbifResponse)item.getData());
                	 }
                	 if(data instanceof BioCaseResponse){
                	     checkedAbcdResults.add((BioCaseResponse)data);
                     }
                }
            }
            String[] tripleId ;
                for (GbifResponse response:checkedResults){
                	if (response != null){
                		tripleId = response.getTripleID();

                		if (response.getDataSetProtocol().equals(GbifDataSetProtocol.BIOCASE)){
                			biocaseResponses.add(response);

                		}else{
                			unitIdsGbif.add(tripleId);
                		}


                	}
                }
                Collections.sort(biocaseResponses, getComparator());

                Abcd206ImportConfigurator configuratorAbcd;
                List<Abcd206ImportConfigurator> abcdConfigurators = new ArrayList<Abcd206ImportConfigurator>();
                DataSetResponse dataSetResponse;
                OccurenceQuery bioCaseOccurrenceQuery = null;
                URI dataSetUri = null;
                for (BioCaseResponse response:checkedAbcdResults){

                   // if (!response.getDataSetUri().equals(dataSetUri)){
                        dataSetUri = response.getDataSetUri();
                        configuratorAbcd = Abcd206ImportConfigurator.NewInstance(dataSetUri, null, false);
                        configuratorAbcd.addMediaAsMediaSpecimen(true);
                        configuratorAbcd.setIgnoreAuthorship(true);
                        configuratorAbcd.setMoveNewTaxaToDefaultClassification(false);

                        unitIdsBioCase = new HashSet<String[]>();
                        bioCaseOccurrenceQuery = new OccurenceQuery(unitIdsBioCase);
                        configuratorAbcd.setOccurenceQuery(bioCaseOccurrenceQuery);
                        configuratorAbcd.setGetSiblings(true);
                        if (dataImportView.getClassification() != null){
                            configuratorAbcd.setClassificationUuid(dataImportView.getClassification().getUuid());
                        }

                    //}
                    tripleId = response.getTripleID();
                    unitIdsBioCase.add(tripleId);

                }


                if (!unitIdsBioCase.isEmpty()){
                    configuratorAbcd = Abcd206ImportConfigurator.NewInstance(dataSetUri, null, false);
                    configuratorAbcd.addMediaAsMediaSpecimen(true);
                    configuratorAbcd.setIgnoreAuthorship(true);
                    configuratorAbcd.setMoveNewTaxaToDefaultClassification(false);
                    if (configuratorAbcd != null){
                        abcdConfigurators.add(configuratorAbcd);
                    }
//                    unitIdsBioCase = new HashSet<String[]>();
                    bioCaseOccurrenceQuery = new OccurenceQuery(unitIdsBioCase);
                    configuratorAbcd.setOccurenceQuery(bioCaseOccurrenceQuery);
                    configuratorAbcd.setGetSiblings(true);
                    if (dataImportView.getClassification() != null){
                        configuratorAbcd.setClassificationUuid(dataImportView.getClassification().getUuid());
                    }
                }

                for (GbifResponse response: biocaseResponses){
                	try {
						dataSetResponse = new GbifQueryServiceWrapper().queryOriginalDataSet(response);
						dataSetUri = dataSetResponse.getEndpoint();
					} catch (ClientProtocolException e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					} catch (IOException e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
                	if (!response.getDataSetUri().equals(dataSetUri)){
                		configuratorAbcd = Abcd206ImportConfigurator.NewInstance(dataSetUri, null, false);
                		configuratorAbcd.addMediaAsMediaSpecimen(true);
                		configuratorAbcd.setIgnoreAuthorship(true);
                		configuratorAbcd.setMoveNewTaxaToDefaultClassification(false);
                		if (configuratorAbcd != null){
                			abcdConfigurators.add(configuratorAbcd);
                		}
                		unitIdsBioCase = new HashSet<String[]>();
                		bioCaseOccurrenceQuery = new OccurenceQuery(unitIdsBioCase);
                		configuratorAbcd.setOccurenceQuery(bioCaseOccurrenceQuery);
                		configuratorAbcd.setGetSiblings(true);
                		if (dataImportView.getClassification() != null){
                			configuratorAbcd.setClassificationUuid(dataImportView.getClassification().getUuid());
                		}

                	}
                	tripleId = response.getTripleID();
                	unitIdsBioCase.add(tripleId);
                }

                OccurenceQuery query = new OccurenceQuery(unitIdsGbif);
                GbifImportConfigurator configurator = GbifImportConfigurator.newInstance(query);
                configurator.setSourceReferenceTitle("Import Gbif data");



                //  configurator.setQuery(query);

               Job bioCaseJob = CdmStore.getImportManager().createIOServiceJob(abcdConfigurators);
               CdmStore.getImportManager().run(bioCaseJob);

               Job gbifJob = CdmStore.getImportManager().createIOServiceJob(configurator);
               CdmStore.getImportManager().run(gbifJob);



            }
        }


    private void persistTerm(DefinedTermBase<?> term, ITermService termService, ConversationHolder conversation){
        if(term!=null){
            //if the term does not exist in the DB save it
            if(termService.find(term.getUuid())==null){
                termService.saveOrUpdate(term);
            }
        }
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.action.Action#getText()
     */
    @Override
    public String getText() {
        return "Import";
    }

    private Comparator<GbifResponse> getComparator(){
    	if (comparator == null){
    		comparator = new GbifResponseComparator();
    	}
    	return comparator;
    }


}
