/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.view.dataimport;

import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import java.util.ArrayList;
import java.util.Collection;

import org.apache.http.client.ClientProtocolException;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import eu.etaxonomy.cdm.ext.occurrence.bioCase.BioCaseQueryServiceWrapper;
import eu.etaxonomy.cdm.ext.occurrence.bioCase.BioCaseResponse;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206DataHolder;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportConfigurator;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportParser;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206ImportState;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Abcd206XMLFieldGetter;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.AbcdParseUtility;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.Identification;
import eu.etaxonomy.cdm.io.specimen.abcd206.in.UnitAssociationWrapper;

/**
 * @author pplitzner
 * @date Sep 3, 2014
 *
 */
public class SpecimenImportView extends DataImportView<BioCaseResponse> {

    public static final String ID = "eu.etaxonomy.taxeditor.view.dataimport.SpecimenImportView"; //$NON-NLS-1$

    private URI endPoint;

    public SpecimenImportView() {
    }

    /**
     * @param endPoint
     */
    public void setEndpoint(URI endPoint) {
        this.endPoint = endPoint;
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.view.dataimport.DataImportView#getTextForTableItem(java.lang.Object)
     */
    @Override
    protected String getTextForTableItem(BioCaseResponse item) {
        //TODO: could be defined in user preferences...
        String name = null;
        if(!((Abcd206DataHolder)item.getAbcdDataHolder()).getIdentificationList().isEmpty()){
           Identification identification =  ((Abcd206DataHolder)item.getAbcdDataHolder()).getIdentificationList().iterator().next();
           name = identification.getScientificName();
        }
        if (name != null){
            return name +" - "+((Abcd206DataHolder)item.getAbcdDataHolder()).getCollectionCode() + " - "+ ((Abcd206DataHolder)item.getAbcdDataHolder()).getFieldNumber() + " - "+ ((Abcd206DataHolder)item.getAbcdDataHolder()).getKindOfUnit();
        }else {
            return ((Abcd206DataHolder)item.getAbcdDataHolder()).getCollectionCode() + " - "+ ((Abcd206DataHolder)item.getAbcdDataHolder()).getFieldNumber() + " - "+ ((Abcd206DataHolder)item.getAbcdDataHolder()).getKindOfUnit();
        }
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.view.dataimport.DataImportView#query()
     */
    @Override
    public void query() {
        String errorMessage = "Could not execute query " + query;

        Collection<BioCaseResponse> results = new ArrayList<BioCaseResponse>();
        try {
            //FIXME move ABCD import to cdmlib -> this will also get rid of the transient services
            InputStream resultStream;
            resultStream = new BioCaseQueryServiceWrapper().query(query, endPoint);
            Abcd206ImportConfigurator configurator = Abcd206ImportConfigurator.NewInstance(null, null);
            configurator.setSourceUri(endPoint);

            //            TransientCdmRepository repo =
//                    new TransientCdmRepository(CdmStore.getCurrentApplicationConfiguration());
            //configurator.setCdmAppController(repo);

            //TODO: do not query all data but with the selected triple IDs -> see GbifResponseImportView
            configurator.setAddMediaAsMediaSpecimen(true);
            configurator.setAllowReuseOtherClassifications(true);
            configurator.setMoveNewTaxaToDefaultClassification(false);
            UnitAssociationWrapper unitAssociationWrapper = AbcdParseUtility.parseUnitsNodeList(resultStream, null);
            NodeList unitsList = unitAssociationWrapper.getAssociatedUnits();
            Abcd206DataHolder dataHolder = new Abcd206DataHolder();
            Abcd206XMLFieldGetter abcdFieldGetter = new Abcd206XMLFieldGetter(dataHolder, unitAssociationWrapper.getPrefix());
            Abcd206ImportState state = new Abcd206ImportState(configurator);
            state.setDataHolder(dataHolder);
            BioCaseResponse response = null;
            if (unitsList != null){
                for (int i = 0; i <unitsList.getLength(); i++){
                    Element item = (Element) unitsList.item(i);
                    //dataHolder = new Abcd206DataHolder();
                    Abcd206ImportParser.setUnitPropertiesXML(item, abcdFieldGetter, state);
                    String[] tripleIdBioCase = new String[3];
                    tripleIdBioCase[0] =dataHolder.getUnitID();
                    tripleIdBioCase[1] = dataHolder.getInstitutionCode();
                    tripleIdBioCase[2] = dataHolder.getCollectionCode();

                    response = new BioCaseResponse(dataHolder, endPoint, tripleIdBioCase );
                    results.add(response);
                }
            }

//            Job job = CdmStore.getImportManager().createIOServiceJob(configurator, resultStream, SOURCE_TYPE.INPUTSTREAM);
//            CdmStore.getImportManager().run(job);

            setResults(results);
        } catch (ClientProtocolException e) {
            logger.error(errorMessage, e);
        } catch (IOException e) {
            logger.error(errorMessage, e);
        }

       // setResults(results);

    }



}
