/**
 * Copyright (C) 2015 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.view.sessions;

import java.util.List;

import net.sf.ehcache.Cache;
import net.sf.ehcache.Element;

import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.StyledCellLabelProvider;
import org.eclipse.jface.viewers.StyledString;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerCell;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.SashForm;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Dialog;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.dialogs.FilteredTree;
import org.eclipse.ui.dialogs.PatternFilter;
import org.eclipse.wb.swt.SWTResourceManager;

import eu.etaxonomy.taxeditor.remoting.cache.CdmModelFieldPropertyFromClass;
import eu.etaxonomy.taxeditor.remoting.cache.CdmRemoteCacheManager;
import eu.etaxonomy.taxeditor.remoting.cache.EntityCacherDebugResult;
import eu.etaxonomy.taxeditor.remoting.cache.EntityCacherDebugResult.CdmEntityInfo;
import eu.etaxonomy.taxeditor.session.ICdmEntitySession;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author cmathew
 * @date 17 Feb 2015
 *
 */
public class InspectSessionsDialog extends Dialog {

    protected Object result;
    protected Shell shlInspectSessions;
    private Text txtDebugInfo;
    private Label lblDebugInformation;

    private final Cache cdmlibModelCache;

    private final ICdmEntitySession activeSession;

    private TreeViewer treeViewer;
    private Button btnClose;
    EntityCacherDebugResult ecdr;
    private SashForm sashForm;
    private Composite compositeDebug;
    /**
     * Create the dialog.
     * @param parent
     * @param style
     */
    public InspectSessionsDialog(Shell parent, int style) {
        super(parent, style);
        setText("Inspect Active Session");
        cdmlibModelCache = CdmRemoteCacheManager.getInstance().getCdmModelGetMethodsCache();
        activeSession = CdmStore.getCurrentSessionManager().getActiveSession();
        ecdr = activeSession.debug();
    }

    /**
     * Open the dialog.
     * @return the result
     */
    public Object open() {

        createContents();
        setDebugInfoText();
        treeViewer.setContentProvider(new SessionsTreeContentProvider());
        treeViewer.setLabelProvider(new SessionsTreeLabelProvider());
        treeViewer.setInput(getRootElements());
        shlInspectSessions.open();
        shlInspectSessions.layout();
        Display display = getParent().getDisplay();
        while (!shlInspectSessions.isDisposed()) {
            if (!display.readAndDispatch()) {
                display.sleep();
            }
        }
        return result;
    }

    /**
     * Create contents of the dialog.
     */
    private void createContents() {
        shlInspectSessions = new Shell(getParent(), SWT.DIALOG_TRIM | SWT.RESIZE);
        shlInspectSessions.setSize(641, 631);
        shlInspectSessions.setText("Inspect Sessions");
        shlInspectSessions.setLayout(new GridLayout(1, false));

        sashForm = new SashForm(shlInspectSessions, SWT.VERTICAL);
        sashForm.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));

        PatternFilter filter = new PatternFilter();
        FilteredTree tree = new FilteredTree(sashForm, SWT.MULTI | SWT.H_SCROLL | SWT.BORDER
                | SWT.V_SCROLL, filter, true);
        treeViewer = tree.getViewer();
        //treeViewer = new TreeViewer(sashForm, SWT.BORDER);
        //Tree tree = treeViewer.getTree();

        compositeDebug = new Composite(sashForm, SWT.NONE);
        compositeDebug.setLayout(new GridLayout(1, false));

        lblDebugInformation = new Label(compositeDebug, SWT.NONE);
        lblDebugInformation.setAlignment(SWT.CENTER);
        lblDebugInformation.setLayoutData(new GridData(SWT.CENTER, SWT.CENTER, true, false, 1, 1));
        lblDebugInformation.setFont(SWTResourceManager.getFont("Ubuntu", 10, SWT.NORMAL));
        lblDebugInformation.setText("Debug Information");

        txtDebugInfo = new Text(compositeDebug, SWT.BORDER | SWT.READ_ONLY | SWT.H_SCROLL | SWT.V_SCROLL | SWT.CANCEL | SWT.MULTI);
        txtDebugInfo.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
        sashForm.setWeights(new int[] {338, 184});

        btnClose = new Button(shlInspectSessions, SWT.NONE);
        btnClose.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                shlInspectSessions.dispose();
            }
        });
        GridData gd_btnClose = new GridData(SWT.LEFT, SWT.CENTER, false, false, 1, 1);
        gd_btnClose.widthHint = 70;
        btnClose.setLayoutData(gd_btnClose);
        btnClose.setText("Close");

    }

    private void setDebugInfoText() {
        txtDebugInfo.setText(ecdr.toString());
    }
    private CdmEntityInfo[] getRootElements() {

        List<CdmEntityInfo> rootElemnts = ecdr.getRootElements();
        return rootElemnts.toArray(new CdmEntityInfo[rootElemnts.size()]);
    }

    class SessionsTreeContentProvider implements ITreeContentProvider {



        /* (non-Javadoc)
         * @see org.eclipse.jface.viewers.IContentProvider#dispose()
         */
        @Override
        public void dispose() {

        }

        /* (non-Javadoc)
         * @see org.eclipse.jface.viewers.IContentProvider#inputChanged(org.eclipse.jface.viewers.Viewer, java.lang.Object, java.lang.Object)
         */
        @Override
        public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {


        }

        /* (non-Javadoc)
         * @see org.eclipse.jface.viewers.ITreeContentProvider#getElements(java.lang.Object)
         */
        @Override
        public Object[] getElements(Object inputElement) {
            return (CdmEntityInfo[])inputElement;
        }

        /* (non-Javadoc)
         * @see org.eclipse.jface.viewers.ITreeContentProvider#getChildren(java.lang.Object)
         */
        @Override
        public Object[] getChildren(Object parentElement) {
            List<CdmEntityInfo> children = ((CdmEntityInfo)parentElement).getChildren();
            return children.toArray();
        }

        /* (non-Javadoc)
         * @see org.eclipse.jface.viewers.ITreeContentProvider#getParent(java.lang.Object)
         */
        @Override
        public Object getParent(Object element) {
            CdmEntityInfo cei = (CdmEntityInfo)element;
            return cei.getParent();
        }

        /* (non-Javadoc)
         * @see org.eclipse.jface.viewers.ITreeContentProvider#hasChildren(java.lang.Object)
         */
        @Override
        public boolean hasChildren(Object element) {
            List<CdmEntityInfo> children = ((CdmEntityInfo)element).getChildren();
            if(children != null && !children.isEmpty()) {
                return true;
            } else {
                return false;
            }
        }

        public CdmModelFieldPropertyFromClass getFromCdmlibModelCache(String className) {
            Element e = cdmlibModelCache.get(className);
            if (e == null) {
                return null;
            } else {
                return (CdmModelFieldPropertyFromClass) e.getObjectValue();
            }
        }

    }

    class SessionsTreeLabelProvider extends StyledCellLabelProvider implements ILabelProvider {

        @Override
        public void update(ViewerCell cell) {
            CdmEntityInfo cei = (CdmEntityInfo)cell.getElement();
            StyledString text = new StyledString();
            if(cei != null) {
                text.append(cei.getLabel());
            }
            cell.setText(text.toString());
            cell.setStyleRanges(text.getStyleRanges());
            super.update(cell);
        }

        /* (non-Javadoc)
         * @see org.eclipse.jface.viewers.ILabelProvider#getImage(java.lang.Object)
         */
        @Override
        public Image getImage(Object element) {
            // TODO Auto-generated method stub
            return null;
        }

        /* (non-Javadoc)
         * @see org.eclipse.jface.viewers.ILabelProvider#getText(java.lang.Object)
         */
        @Override
        public String getText(Object element) {
            CdmEntityInfo cei = (CdmEntityInfo)element;
            return cei.getLabel();
        }
    }
}


