/**
* Copyright (C) 2013 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.view.specimenSearch;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.DateTime;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.forms.widgets.FormToolkit;
import org.eclipse.ui.forms.widgets.TableWrapData;
import org.eclipse.ui.forms.widgets.TableWrapLayout;

/**
 * @author pplitzner
 * @date 03.09.2013
 *
 */
public class SpecimenSearchComposite extends Composite {
    private final FormToolkit formToolkit = new FormToolkit(Display.getDefault());
    private final Text textTaxonName;
    private final Text textCollector;
    private final Text textCollectorNumber;
    private final Text textAccessionNumber;
    private final Text textLocality;
    private final Text textHerbarium;
    private final Text textCountry;
    private final DateTime dateFrom;
    private final DateTime dateTo;
    private final Button btnShowDate;

    /**
     * Create the composite.
     * @param parent
     * @setBackgroundMode(SWT.INHERIT_DEFAULT);
        param style
     */
    public SpecimenSearchComposite(Composite parent, int style) {
        super(parent, style);
        {
            TableWrapLayout tableWrapLayout = new TableWrapLayout();
            tableWrapLayout.numColumns = 2;
            setLayout(tableWrapLayout);
        }

        Label lblTaxonName = new Label(this, SWT.NONE);
        lblTaxonName.setText("Taxon Name");

        textTaxonName = new Text(this, SWT.NONE);
        textTaxonName.setLayoutData(new TableWrapData(TableWrapData.FILL_GRAB, TableWrapData.TOP, 1, 1));

        Label lblCollectors = new Label(this, SWT.NONE);
        lblCollectors.setText("Collector(s)");

        textCollector = new Text(this, SWT.NONE);
        textCollector.setLayoutData(new TableWrapData(TableWrapData.FILL_GRAB, TableWrapData.TOP, 1, 1));
        formToolkit.adapt(textCollector, true, true);

        Label lblCollectorsNumber = new Label(this, SWT.NONE);
        lblCollectorsNumber.setText("Collector(s) Number");

        textCollectorNumber = new Text(this, SWT.NONE);
        textCollectorNumber.setLayoutData(new TableWrapData(TableWrapData.FILL_GRAB, TableWrapData.TOP, 1, 1));
        formToolkit.adapt(textCollectorNumber, true, true);

        Label lblAccessionNumber = new Label(this, SWT.NONE);
        lblAccessionNumber.setText("Accession Number");

        textAccessionNumber = new Text(this, SWT.NONE);
        textAccessionNumber.setLayoutData(new TableWrapData(TableWrapData.FILL_GRAB, TableWrapData.TOP, 1, 1));
        formToolkit.adapt(textAccessionNumber, true, true);

        Label lblHerbarium = new Label(this, SWT.NONE);
        lblHerbarium.setText("Collection");

        textHerbarium = new Text(this, SWT.NONE);
        textHerbarium.setLayoutData(new TableWrapData(TableWrapData.FILL_GRAB, TableWrapData.TOP, 1, 1));

        Label lblCountry = new Label(this, SWT.NONE);
        lblCountry.setText("Country");

        textCountry = new Text(this, SWT.NONE);
        textCountry.setLayoutData(new TableWrapData(TableWrapData.FILL_GRAB, TableWrapData.TOP, 1, 1));

        Label lblLocality = new Label(this, SWT.NONE);
        lblLocality.setText("Locality");

        textLocality = new Text(this, SWT.NONE);
        textLocality.setLayoutData(new TableWrapData(TableWrapData.FILL_GRAB, TableWrapData.TOP, 1, 1));
        formToolkit.adapt(textLocality, true, true);

        Label lblCollectionDate = new Label(this, SWT.NONE);
        lblCollectionDate.setText("Collection Date");

        btnShowDate = new Button(this, SWT.CHECK);

        Label lblFrom = new Label(this, SWT.NONE);
        lblFrom.setLayoutData(new TableWrapData(TableWrapData.RIGHT, TableWrapData.TOP, 1, 1));
        lblFrom.setText("from");

        dateFrom = new DateTime(this, SWT.SHORT);
        dateFrom.setLayoutData(new TableWrapData(TableWrapData.FILL, TableWrapData.TOP, 1, 1));
        formToolkit.paintBordersFor(dateFrom);

        Label lblTo = new Label(this, SWT.NONE);
        lblTo.setLayoutData(new TableWrapData(TableWrapData.RIGHT, TableWrapData.TOP, 1, 1));
        lblTo.setText("to");

        dateTo = new DateTime(this, SWT.SHORT);
        dateTo.setLayoutData(new TableWrapData(TableWrapData.FILL, TableWrapData.TOP, 1, 1));
        formToolkit.paintBordersFor(dateTo);

    }

    @Override
    protected void checkSubclass() {
        // Disable the check that prevents subclassing of SWT components
    }

    public Text getTextTaxonName() {
        return textTaxonName;
    }
    public Text getTextCollector() {
        return textCollector;
    }
    public Text getTextCollectorNumber() {
        return textCollectorNumber;
    }
    public Text getTextAccessionNumber() {
        return textAccessionNumber;
    }
    public Text getTextHerbarium() {
        return textHerbarium;
    }
    public Text getTextCountry() {
        return textCountry;
    }
    public Text getTextLocality() {
        return textLocality;
    }
    public DateTime getDateFrom() {
        return dateFrom;
    }
    public DateTime getDateTo() {
        return dateTo;
    }
    public Button getBtnShowDate() {
        return btnShowDate;
    }
}
