/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.view.supplementaldata;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TreeNode;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.part.EditorPart;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.cdm.ext.occurrence.gbif.GbifResponse;
import eu.etaxonomy.cdm.model.description.PolytomousKeyNode;
import eu.etaxonomy.taxeditor.l10n.Messages;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.FeatureNodeContainer;
import eu.etaxonomy.taxeditor.model.IPartContentHasSupplementalData;
import eu.etaxonomy.taxeditor.view.AbstractCdmEditorViewPart;


/**
 * <p>SupplementalDataViewPart class.</p>
 *
 * @author n.hoffmann
 * @created Jun 10, 2010
 * @version 1.0
 */
public class SupplementalDataViewPart extends AbstractCdmEditorViewPart {

	/** Constant <code>ID="eu.etaxonomy.taxeditor.editor.view.supp"{trunked}</code> */
	public static final String ID = "eu.etaxonomy.taxeditor.view.supplementalData"; //$NON-NLS-1$

	private SupplementalDataViewer viewer;

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.WorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public void createViewer(Composite parent) {
		viewer = new SupplementalDataViewer(parent, this);
	}


	/** {@inheritDoc} */
	@Override
	protected void selectionChanged_internal(IWorkbenchPart part, ISelection selection) {
		if(AbstractUtility.getActiveEditor() == null){
			showEmptyPage();
			return;
		}

        if(part == this){
            return;
        }

        if(!(selection instanceof IStructuredSelection)){
            return;
        }

        IStructuredSelection structuredSelection = (IStructuredSelection) selection;

		if((part instanceof EditorPart || part instanceof IPartContentHasSupplementalData)) {
			if(structuredSelection.size() != 1){
				showEmptyPage();
				return;
			}

			// do not show supplemental data for feature nodes
			if(structuredSelection.getFirstElement() instanceof FeatureNodeContainer){
				showEmptyPage();
				return;
			}
			else if(structuredSelection.getFirstElement() instanceof DerivedUnitFacade){
				return;
			}
			else if(structuredSelection.getFirstElement() instanceof PolytomousKeyNode){
			    structuredSelection = new StructuredSelection(((PolytomousKeyNode)structuredSelection.getFirstElement()).getKey());
            }
			else if(structuredSelection.getFirstElement() instanceof TreeNode){
				structuredSelection = new StructuredSelection(((TreeNode)structuredSelection.getFirstElement()).getValue());
			}
			else if(structuredSelection.getFirstElement() instanceof GbifResponse){
			    structuredSelection = new StructuredSelection(((GbifResponse)structuredSelection.getFirstElement()).getDerivedUnitFacade().innerDerivedUnit());
			}
			showViewer(part, structuredSelection);
		}else{
			showEmptyPage();
		}
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		super.dispose();
		selectionService.removePostSelectionListener(this);
	}


	/** {@inheritDoc} */
	@Override
	public Viewer getViewer() {
		return viewer;
	}

	/**
	 * <p>onComplete</p>
	 *
	 * @return a boolean.
	 */
	@Override
    public boolean onComplete() {
		// TODO Auto-generated method stub
		return false;
	}


	@Override
	protected String getViewName() {
		return Messages.SupplementalDataViewPart_VIEWER_NAME;
	}
}
