/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.section.occurrence.dna;

import java.util.ArrayList;
import java.util.Collection;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.ToolBarManager;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.ImageData;
import org.eclipse.swt.widgets.Control;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.taxeditor.model.ImageResources;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;

/**
 * This class extends the functionality of
 * {@link AbstractEntityCollectionSection} by creating an
 * {@link AbstractEntityCollectionElement} for an ELEMENT which is not directly
 * added the the model ENTITY.<br>
 * <br>
 * This is useful if the ELEMENT is created after the creation of the
 * AbstractEntityCollectionElement itself and not in this class and also if you
 * do not want to create empty elements. <br>
 * <br>
 * <b>Note:</b> In sub classes: do <b>not</b> override {@link #getCollection(Object)}. Use
 * {@link #getEntityCollection(Object)} instead
 *
 * @author pplitzner
 * @date 21.01.2014
 */
public abstract class AbstractUnboundEntityCollectionSection<ENTITY, ELEMENT> extends AbstractEntityCollectionSection<ENTITY, ELEMENT> {

    private boolean addUnboundElement = false;

    /**
     * @param formFactory
     * @param conversation
     * @param parentElement
     * @param title
     * @param style
     */
    public AbstractUnboundEntityCollectionSection(CdmFormFactory formFactory, ConversationHolder conversation, ICdmFormElement parentElement, String title, int style) {
        super(formFactory, conversation, parentElement, title, style);
    }

    /**
     * @deprecated this method should not be extended in sub classes of {@link AbstractUnboundEntityCollectionSection}.<br>
     */
    @Deprecated
    @Override
    public Collection<ELEMENT> getCollection(ENTITY entity) {
        Collection<ELEMENT> elements = getEntityCollection(entity);
        if(addUnboundElement){
            //cloning to avoid saving the dummy element
            Collection<ELEMENT> clonedElements = new ArrayList<ELEMENT>();
            clonedElements.addAll(elements);
            clonedElements.add(createNewElement()); //add dummy element which is not bound to entity
            return clonedElements;
        }
        return elements;
    }

    @Override
    protected Control createToolbar() {
        ToolBarManager toolBarManager = new ToolBarManager(SWT.FLAT);

        Action addAction = new Action("add", IAction.AS_PUSH_BUTTON){
            /* (non-Javadoc)
             * @see org.eclipse.jface.action.Action#run()
             */
            @Override
            public void run() {
                addUnboundElement = true;
                if(! getSection().isExpanded()) {
                    getSection().setExpanded(true);
                }
                internalUpdateSection(false);
                addUnboundElement = false;
            }
        };
        addAction.setImageDescriptor(new ImageDescriptor() {

            @Override
            public ImageData getImageData() {
                return ImageResources.getImage(ImageResources.ADD_ICON).getImageData();
            }
        });
        addAction.setToolTipText(getTooltipString());

        toolBarManager.add(addAction);

        return toolBarManager.createControl(this);
    }

    /**
     * Get all the elements that are represented by this section.
     * @param entity the entity which is represented by the parent section
     * @return a collection of the elements belonging to the entity
     */
    protected abstract Collection<ELEMENT> getEntityCollection(ENTITY entity);

}
