/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.ui.section.occurrence.dna;

import eu.etaxonomy.cdm.model.agent.AgentBase;
import eu.etaxonomy.cdm.model.common.DefinedTerm;
import eu.etaxonomy.cdm.model.common.TermType;
import eu.etaxonomy.cdm.model.molecular.AmplificationResult;
import eu.etaxonomy.cdm.model.molecular.Cloning;
import eu.etaxonomy.taxeditor.ui.combo.TermComboElement;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.element.TimePeriodElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * @author pplitzner
 * @date 15.01.2014
 *
 */
public class AmplificationCloningDetailElement extends AbstractCdmDetailElement<AmplificationResult> {
    private TextWithLabelElement textCloningStrain;
    private TimePeriodElement date;
    private EntitySelectionElement<AgentBase> selectionCloningStaff;
    private TermComboElement<DefinedTerm> comboCloningMaterialOrMethod;


    /**
     * @param formFactory
     * @param formElement
     */
    public AmplificationCloningDetailElement(CdmFormFactory formFactory, ICdmFormElement formElement) {
        super(formFactory, formElement);
    }

    /*
     * (non-Javadoc)
     *
     * @see
     * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#createControls
     * (eu.etaxonomy.taxeditor.forms.ICdmFormElement, java.lang.Object, int)
     */
    @Override
    protected void createControls(ICdmFormElement formElement, AmplificationResult entity, int style) {
        Cloning cloning = entity.getCloning();
        textCloningStrain = formFactory.createTextWithLabelElement(formElement, "Cloning Strain", cloning==null?"":cloning.getStrain(), style);
        date = formFactory.createTimePeriodElement(formElement, "Cloning Date", cloning==null?null:cloning.getTimeperiod(), style);
        selectionCloningStaff = formFactory.createSelectionElement(AgentBase.class, getConversationHolder(), formElement, "Cloning Staff", cloning==null?null:cloning.getActor(), EntitySelectionElement.ALL, style);
        comboCloningMaterialOrMethod = formFactory.createDefinedTermComboElement(TermType.MaterialOrMethod, formElement, "Cloning Mat. & Meth.", cloning==null?null:cloning.getDefinedMaterialOrMethod(), style);
    }

    /*
     * (non-Javadoc)
     *
     * @see
     * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#handleEvent(java
     * .lang.Object)
     */
    @Override
    public void handleEvent(Object eventSource) {
        if(eventSource==textCloningStrain || eventSource==date|| eventSource==selectionCloningStaff || eventSource==comboCloningMaterialOrMethod){
            Cloning cloning = getEntity().getCloning();
            if(cloning==null){
                cloning = Cloning.NewInstance();
                getEntity().setCloning(cloning);
            }
            if(eventSource==textCloningStrain){
                cloning.setStrain(textCloningStrain.getText());
            }
            else if(eventSource==date){
                cloning.setTimeperiod(date.getTimePeriod());
            }
            else if(eventSource==selectionCloningStaff){
                cloning.setActor(selectionCloningStaff.getSelection());
            }
            else if(eventSource==comboCloningMaterialOrMethod){
                cloning.setDefinedMaterialOrMethod(comboCloningMaterialOrMethod.getSelection());
            }
        }
    }

}
