/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.occurrence.dna;

import java.util.Collection;
import java.util.Collections;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.common.IdentifiableEntity;
import eu.etaxonomy.cdm.model.common.Identifier;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.view.derivateSearch.DerivateLabelProvider;

/**
 *
 * @author pplitzner
 * @date Oct 16, 2014
 *
 */
public class CurrentSampleDesignationDetailSection extends AbstractSampleDesignationDetailSection {

	public CurrentSampleDesignationDetailSection(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement,
			int style) {
		super(formFactory, conversation, parentElement, "Current Sample Designation", style);
	}

	@Override
	public void refresh() {
		internalUpdateSection(false);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#getCollection(java.lang.Object)
	 */
	@Override
	public Collection<Identifier> getCollection(IdentifiableEntity<?> entity) {
	    Identifier currentSampleDesignation = DerivateLabelProvider.getCurrentSampleDesignation(entity);
	    if(currentSampleDesignation!=null){
	        return Collections.singleton(currentSampleDesignation);
	    }
	    else{
	        return Collections.emptyList();
	    }
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#getTooltipString()
	 */
	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Create new current sample designation";
	}

	   /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#addElement(eu.etaxonomy.cdm.model.common.IVersionableEntity)
     */
    /** {@inheritDoc} */
    @Override
    public void addElement(Identifier sampleDesignation) {
        //The current sample designation is always the first one found.
        //The following are recent sample designations with the most recent being
        //the second one found and so on
        getEntity().addIdentifier(0, sampleDesignation);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Identifier addExisting() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        return false;
    }

}
