/**
 * Copyright (C) 2013 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
 
package eu.etaxonomy.taxeditor.ui.section.occurrence.dna;

import eu.etaxonomy.cdm.model.agent.AgentBase;
import eu.etaxonomy.cdm.model.agent.Institution;
import eu.etaxonomy.cdm.model.common.TimePeriod;
import eu.etaxonomy.cdm.model.molecular.DnaSample;
import eu.etaxonomy.cdm.model.occurrence.PreservationMethod;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.element.NumberWithLabelElement;
import eu.etaxonomy.taxeditor.ui.element.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.element.TimePeriodElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.EntitySelectionElement;

/**
 * @author pplitzner
 * @date 16.12.2013
 *
 */
public class DnaSamplePreparationPreservationDetailElement extends AbstractCdmDetailElement<DnaSample> {

    private EntitySelectionElement<Institution> selectionInstitution;
    private EntitySelectionElement<AgentBase> selectionStaff;
    private TimePeriodElement datePreparationDate;
    private NumberWithLabelElement numberPreservationTemperature;
    private TextWithLabelElement txtMaterialOrMethods;

    /**
     * @param formFactory
     * @param formElement
     */
    public DnaSamplePreparationPreservationDetailElement(CdmFormFactory formFactory, ICdmFormElement formElement) {
        super(formFactory, formElement);
    }

    /*
     * (non-Javadoc)
     *
     * @see
     * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#createControls
     * (eu.etaxonomy.taxeditor.forms.ICdmFormElement, java.lang.Object, int)
     */
    @Override
    protected void createControls(ICdmFormElement formElement, DnaSample entity, int style) {
        Institution institution = null;
        AgentBase<?> staff = null;
        TimePeriod preparationDate = null;
        if(entity.getDerivedFrom()!=null){
            institution = entity.getDerivedFrom().getInstitution();
            staff = entity.getDerivedFrom().getActor();
            preparationDate = entity.getDerivedFrom().getTimeperiod();
        }

        Double temperature = null;
        String materialOrMethodText = null;
        if(entity.getPreservation()!=null){
            temperature = entity.getPreservation().getTemperature();
        }
        if(entity.getDerivedFrom()!=null){
            materialOrMethodText = entity.getDerivedFrom().getDescription();
        }
        selectionInstitution = formFactory.createSelectionElement(Institution.class, getConversationHolder(), formElement, "Institution", institution, EntitySelectionElement.ALL, style);
        selectionStaff = formFactory.createSelectionElement(AgentBase.class, getConversationHolder(), formElement, "Staff", staff, EntitySelectionElement.ALL, style);
        datePreparationDate = formFactory.createTimePeriodElement(formElement, "Preparation date", preparationDate, style);
        numberPreservationTemperature = formFactory.createNumberTextWithLabelElement(formElement, "Preservation Temp. [C°]", temperature, style);
        txtMaterialOrMethods = formFactory.createTextWithLabelElement(formElement, "Materials && Methods", materialOrMethodText, style);

    }

    /*
     * (non-Javadoc)
     *
     * @see
     * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#handleEvent(java
     * .lang.Object)
     */
    @Override
    public void handleEvent(Object eventSource) {
        if(eventSource==datePreparationDate){
            if(getEntity().getDerivedFrom()!=null){
                getEntity().getDerivedFrom().setTimeperiod(datePreparationDate.getTimePeriod());
            }
        }
        else if(eventSource==selectionInstitution){
            if(getEntity().getDerivedFrom()!=null){
                getEntity().getDerivedFrom().setInstitution(selectionInstitution.getSelection());
            }
        }
        else if(eventSource==selectionStaff){
            if(getEntity().getDerivedFrom()!=null){
                getEntity().getDerivedFrom().setActor(selectionStaff.getSelection());
            }
        }
        else if(eventSource==numberPreservationTemperature && numberPreservationTemperature.getText()!=null){
            addPreservationMethod().setTemperature(numberPreservationTemperature.getDouble());
        }
        else if(eventSource==txtMaterialOrMethods && getEntity().getDerivedFrom()!=null){
            getEntity().getDerivedFrom().setDescription(txtMaterialOrMethods.getText());
        }
    }

    private PreservationMethod addPreservationMethod(){
        PreservationMethod preservationMethod = getEntity().getPreservation();
        if(preservationMethod==null){
            preservationMethod = PreservationMethod.NewInstance();
            getEntity().setPreservation(preservationMethod);
        }
        return preservationMethod;
    }
}
