/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.occurrence.dna;

import java.util.Collection;
import java.util.LinkedList;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.common.IdentifiableEntity;
import eu.etaxonomy.cdm.model.common.Identifier;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;
import eu.etaxonomy.taxeditor.view.derivateSearch.DerivateLabelProvider;

/**
 * @author n.hoffmann
 * @created May 11, 2011
 * @version 1.0
 */
public class SampleDesignationHistoryDetailSection extends AbstractSampleDesignationDetailSection {

	/**
	 * @param formFactory
	 * @param conversation
	 * @param parentElement
	 * @param style
	 */
	public SampleDesignationHistoryDetailSection(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement,
			int style) {
		super(formFactory, conversation, parentElement, "Sample Designation History", style);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#getCollection(java.lang.Object)
	 */
	@Override
	public Collection<Identifier> getCollection(IdentifiableEntity<?> entity) {
	    LinkedList<Identifier> sampleDesignations = new LinkedList<Identifier>();
	    for (Identifier identifier : entity.getIdentifiers()) {
	        if(identifier.getType()!=null && identifier.getType().equals(DerivateLabelProvider.getSampleDesignationTerm())){
	            sampleDesignations.add(identifier);
	        }
	    }
	    if(sampleDesignations.size()>0){
	        sampleDesignations.removeFirst();//first is the current sample designation
	    }
	    return sampleDesignations;
	}

	@Override
	public void refresh() {
		internalUpdateSection(false);
	}


	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#getTooltipString()
	 */
	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Add a sample designation to the history";
	}

	/* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#addElement(eu.etaxonomy.cdm.model.common.IVersionableEntity)
     */
    /** {@inheritDoc} */
    @Override
    public void addElement(Identifier sampleDesignation) {
        //The current sample designation is always the first one found.
        //The following are recent sample designations with the most recent being
        //the second one found and so on
        Identifier currentSampleDesignation = DerivateLabelProvider.getCurrentSampleDesignation(getEntity());
        int indexOfCurrentSampleDesignation = getEntity().getIdentifiers().indexOf(currentSampleDesignation);
        getEntity().addIdentifier(indexOfCurrentSampleDesignation+1, sampleDesignation);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Identifier addExisting() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        return false;
    }

}
