/**
 * Copyright (C) 2014 EDIT
 * European Distributed Institute of Taxonomy
 * http://www.e-taxonomy.eu
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.ui.section.occurrence.dna;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.molecular.Sequence;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.model.reference.ReferenceFactory;
import eu.etaxonomy.taxeditor.ui.element.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.element.ICdmFormElement;

/**
 * This section visualizes {@link Reference}s belonging to a {@link Sequence} and alllows adding/removing them.
 * @author pplitzner
 * @date 07.01.2014
 *
 */
public class SequenceReferenceCollectionDetailSection extends AbstractUnboundEntityCollectionSection<Sequence, Reference> {

    public SequenceReferenceCollectionDetailSection(CdmFormFactory formFactory,
            ConversationHolder conversation, ICdmFormElement parentElement, int style) {
        super(formFactory, conversation, parentElement, "References", style);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.ui.section.occurrence.dna.AbstractNullEntityCollectionSection#getEntityCollection(java.lang.Object)
     */
    /** {@inheritDoc} */
    @Override
    protected Collection<Reference> getEntityCollection(Sequence entity) {
        return entity.getCitations();
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection#createNewElement()
     */
    /** {@inheritDoc} */
    @Override
    public Reference createNewElement() {
        return ReferenceFactory.newGeneric();
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#addElement(eu.etaxonomy.cdm.model.common.IVersionableEntity)
     */
    /** {@inheritDoc} */
    @Override
    public void addElement(Reference element) {
        //never gets called
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#removeElement(eu.etaxonomy.cdm.model.common.IVersionableEntity)
     */
    /** {@inheritDoc} */
    @Override
    public void removeElement(Reference element) {
        getEntity().removeCitation(element);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#getEmptyString()
     */
    /** {@inheritDoc} */
    @Override
    public String getEmptyString() {
        return "No references yet.";
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionSection#getTooltipString()
     */
    /** {@inheritDoc} */
    @Override
    protected String getTooltipString() {
        return "Add a reference";
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Reference addExisting() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean allowAddExisting() {
        return false;
    }


}
